(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    582415,      11801]
NotebookOptionsPosition[    565553,      11295]
NotebookOutlinePosition[    568768,      11401]
CellTagsIndexPosition[    568613,      11393]
WindowFrame->Normal
ContainsDynamic->True *)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Mathematica 6: data analysis, visualization and interaction", "Title",
 CellChangeTimes->{
  3.383299843109375*^9, {3.430091933*^9, 3.430091960625*^9}, 
   3.43009200590625*^9}],

Cell["Roberto Cavaliere - roberto@wolfram.com", "Author",
 CellChangeTimes->{{3.38329984959375*^9, 3.383299851234375*^9}, {
  3.392159159625*^9, 3.39215916215625*^9}, {3.430099658421875*^9, 
  3.430099659734375*^9}}],

Cell["\<\
Wolfram Research - www.wolfram.com
\
\>", "Affiliation",
 CellChangeTimes->{{3.383299853234375*^9, 3.383299858140625*^9}, {
   3.3834750358125*^9, 3.38347504465625*^9}, 3.430091966796875*^9, {
   3.43009964734375*^9, 3.43009966453125*^9}}],

Cell[CellGroupData[{

Cell["Introduction", "Section",
 CellChangeTimes->{{3.3608526396718802`*^9, 3.3608526408750014`*^9}, {
  3.430092146875*^9, 3.430092186421875*^9}}],

Cell["\<\
Mathematica's capabilities in statistics-related areas have steadily grown. \
It includes industrial-strength versions of the usual statistics and \
visualization capabilities, together with many important unique capabilities, \
made possible by its broad overall scope and extensibility, immense \
interconnected web of algorithms and integrated programming language and \
interface framework. 
Mathematica provides integrated support both for classical statistics and for \
modern large-scale data analysis. Incorporating the latest numeric and \
computational geometry algorithms, Mathematica provides high-accuracy and \
high-reliability statistical results for datasets of almost unlimited size. 

Beyond the internal algorithms and data analysis functionalities, Mathematica \
provides additional facilities useful in typical data analysis processes. For \
instance, it imports and exports data in more than one hundred standard \
formats, allowing the data exchange with other applications. It has a \
built-in high-level interface to all standard SQL databases, that allows \
immediate searching, reading and writing of arbitrary data and expressions. \
It gives access to a library of carefully cured and continually updated data \
maintained by Wolfram Research; for instance Financial Data, Chemical Data, \
Country and City Data and lots more.

Finally, Mathematica automates the generation of compelling visualizations - \
and new technology in Mathematica 6 allows any output or computation to \
immediately become interactive and dynamic. Its integrated notebook \
mechanism, enable to create documents which can store a complete, formatted, \
editable, executable history of an analysis, complete with live graphics, \
interactive controls and arbitrary typeset tabular, mathematical and other \
material. \
\>", "Text",
 CellChangeTimes->{{3.430092120171875*^9, 3.430092144109375*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["This talk", "Section",
 CellChangeTimes->{{3.3608526396718802`*^9, 3.3608526408750014`*^9}, {
  3.430092146875*^9, 3.43009220959375*^9}}],

Cell[TextData[{
 "Introduction to ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " basic philosophy"
}], "Subsection",
 ShowCellBracket->False,
 CellChangeTimes->{{3.3608526513593802`*^9, 3.36085266121875*^9}, {
  3.3610011781931*^9, 3.361001234723989*^9}, {3.3658412961875*^9, 
  3.3658413009218802`*^9}, {3.383381778703125*^9, 3.38338179803125*^9}, {
  3.430092218921875*^9, 3.43009222396875*^9}, {3.430155654*^9, 
  3.430155656796875*^9}}],

Cell[TextData[{
 "Show a little of the technology in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 6"
}], "Subsection",
 ShowCellBracket->False,
 CellChangeTimes->{{3.360852665812501*^9, 3.360852682*^9}, {
  3.365841256281249*^9, 3.3658413198906302`*^9}, {3.43010124390625*^9, 
  3.430101256859375*^9}, {3.4301556593125*^9, 3.4301556614375*^9}}],

Cell[TextData[{
 "Give same examples of how ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " works and what can do"
}], "Subsection",
 ShowCellBracket->False,
 CellChangeTimes->{{3.3608526937343802`*^9, 3.3608527113906302`*^9}, {
  3.360998061424721*^9, 3.360998062455971*^9}, {3.43010126990625*^9, 
  3.4301013214375*^9}, {3.430155648265625*^9, 3.430155662296875*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "What is ",
 StyleBox["Mathematica?",
  FontSlant->"Italic"]
}], "Section",
 CellChangeTimes->{{3.3608525402968802`*^9, 3.3608525448125014`*^9}, {
  3.36085331053125*^9, 3.3608533148593802`*^9}, {3.3834744743125*^9, 
  3.3834744751875*^9}}],

Cell[CellGroupData[{

Cell["One view...", "Subsection",
 CellChangeTimes->{{3.360910953893591*^9, 3.36091098536214*^9}, {
  3.360998299439481*^9, 3.360998299892571*^9}, {3.361001250098891*^9, 
  3.361001250505131*^9}}],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
 ImageSize->{650, 448},
 ImageMargins->0]
}, Open  ]],

Cell[CellGroupData[{

Cell["Use dichotomy: application and language", "Subsection",
 CellChangeTimes->{{3.360910991971471*^9, 3.36091099300271*^9}, {
  3.36091109718955*^9, 3.360911099955151*^9}, {3.36091162089264*^9, 
  3.360911626923929*^9}}],

Cell["An application (use raw, immediately, yourself)", "Subsubsection",
 CellChangeTimes->{{3.36091110701761*^9, 3.360911129954961*^9}, {
   3.36091158707993*^9, 3.36091160862694*^9}, 3.361010577395071*^9}],

Cell["A language (encapsulated, extend use, for you or others).", \
"Subsubsection",
 CellChangeTimes->{{3.36091110701761*^9, 3.360911129954961*^9}, {
   3.36091158707993*^9, 3.36091160862694*^9}, 3.361010577395071*^9, 
   3.361075270454921*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "But really...what IS ",
 StyleBox["Mathematica?",
  FontSlant->"Italic"]
}], "Section",
 CellChangeTimes->{{3.3672312837856317`*^9, 3.367231290176257*^9}, {
  3.383382501625*^9, 3.3833825070625*^9}, {3.383386497203125*^9, 
  3.383386503671875*^9}, {3.383392808796875*^9, 3.383392836421875*^9}}],

Cell["A Complete system", "Subsection",
 ShowCellBracket->False,
 CellChangeTimes->{{3.38339880015625*^9, 3.38339881084375*^9}}],

Cell[CellGroupData[{

Cell["Fully integrated across all functionality", "Subsection",
 CellChangeTimes->{{3.3672319346651187`*^9, 3.367231943649953*^9}, {
  3.367314566153596*^9, 3.367314576825539*^9}, {3.383398761296875*^9, 
  3.383398782359375*^9}, {3.383474460890625*^9, 3.383474466640625*^9}}],

Cell["\<\
As a straightforward example of data import and processing, I will show an \
example of working with image data.
Import a JPEG image showing a picture of bacteria and limestone accretions in \
the runoff from a geothermal hot spring.\
\>", "Text",
 ShowCellBracket->True,
 CellChangeTimes->{3.430155679625*^9}],

Cell[BoxData[
 RowBox[{"Show", "[", " ", 
  RowBox[{
   RowBox[{"Import", "[", 
    RowBox[{
     RowBox[{"ToFileName", "[", 
      RowBox[{
       RowBox[{"NotebookDirectory", "[", "]"}], ",", "\"\<Bacteria.JPG\>\""}],
       "]"}], ",", "\"\<JPG\>\""}], "]"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "400"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.367310556952222*^9, 3.3673105629835105`*^9}, {
  3.38338283459375*^9, 3.383382838296875*^9}, {3.383476097453125*^9, 
  3.383476114453125*^9}, {3.3921592760625*^9, 3.392159279640625*^9}, {
  3.430092704609375*^9, 3.43009270603125*^9}, {3.432252652609375*^9, 
  3.43225268709375*^9}}],

Cell["\<\
Extract a part of the image data from the Graphics object. The image data \
consists of a matrix of triples giving the values for each color channel at \
each pixel.\
\>", "Text",
 ShowCellBracket->True,
 CellChangeTimes->{{3.383476222375*^9, 3.383476222640625*^9}}],

Cell[BoxData[
 RowBox[{"imagedata", "  ", "=", " ", 
  RowBox[{
   RowBox[{"Import", "[", 
    RowBox[{
     RowBox[{"ToFileName", "[", 
      RowBox[{
       RowBox[{"NotebookDirectory", "[", "]"}], ",", "\"\<Bacteria.JPG\>\""}],
       "]"}], ",", "\"\<Data\>\""}], "]"}], "[", 
   RowBox[{"[", 
    RowBox[{
     RowBox[{"1", ";;", "100"}], ",", 
     RowBox[{"51", ";;", "150"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.3555611084847*^9, 3.3555611418927402`*^9}, {
   3.3555612249021*^9, 3.35556126362779*^9}, {3.355562182649269*^9, 
   3.3555621835605807`*^9}, {3.35556240502904*^9, 3.35556240521931*^9}, {
   3.3673105758585935`*^9, 3.367310590139934*^9}, {3.392159327828125*^9, 
   3.39215932871875*^9}, {3.39231599153125*^9, 3.392316002265625*^9}, {
   3.430092692546875*^9, 3.430092693765625*^9}, 3.4300943375625*^9, 
   3.43225270040625*^9}],

Cell["\<\
Show the part of the data that was extracted with the true colors.\
\>", "Text",
 ShowCellBracket->True],

Cell[BoxData[
 RowBox[{"imgdetail", "=", 
  RowBox[{"Graphics", "[", 
   RowBox[{"Raster", "[", 
    RowBox[{"imagedata", "/", "256."}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.3555612963748717`*^9, 3.355561331936011*^9}, {
  3.355562188407551*^9, 3.35556218912859*^9}, {3.35556241020648*^9, 
  3.35556241209921*^9}, {3.383385641359375*^9, 3.38338566353125*^9}, {
  3.383476207796875*^9, 3.38347620796875*^9}}],

Cell[TextData[{
 "What I would like to do is get the size and location of the limestone \
accretion.  There are many ways to approach this.  The idea I show below is \
certainly not the best, but it demonstrates well the ability to explore using \
the mathematics and interactivity of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ".",
 "\n",
 "Compute the mean color of all the pixels shown in the image."
}], "Text",
 ShowCellBracket->True,
 CellChangeTimes->{3.430155690375*^9}],

Cell[BoxData[
 RowBox[{"meancolor", " ", "=", " ", 
  RowBox[{"Mean", "[", 
   RowBox[{"Mean", "[", "imagedata", "]"}], "]"}]}]], "Input",
 ShowCellBracket->True,
 CellChangeTimes->{{3.38339910975*^9, 3.383399118875*^9}, {
  3.43009436959375*^9, 3.430094371328125*^9}}],

Cell["\<\
I am interested in highlighting those points with color different than the \
most prevalent dull yellow.  Thinking of the color as a vector in 3-space, I \
want to highlight the points with different color directions.  This can be \
done by taking the norm of the cross product with the mean color.
Compute the norm of the cross product of the color vector at each point with \
the mean color and normalize it so that the maximum value is 1.\
\>", "Text",
 ShowCellBracket->True,
 CellChangeTimes->{3.4301556944375*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"orthogonal", " ", "=", " ", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Norm", "[", 
       RowBox[{"Cross", "[", 
        RowBox[{"meancolor", ",", " ", "#"}], "]"}], "]"}], "&"}], ",", " ", 
     "imagedata", ",", 
     RowBox[{"{", "2", "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"orthogonal", " ", "/=", " ", 
   RowBox[{"Max", "[", "orthogonal", "]"}]}], ";"}]}], "Input",
 ShowCellBracket->True],

Cell["Show a surface plot of the resulting data.", "Text",
 ShowCellBracket->True],

Cell[BoxData[
 RowBox[{"ListPlot3D", "[", 
  RowBox[{"orthogonal", ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"Mesh", "\[Rule]", "False"}]}], "]"}]], "Input",
 ShowCellBracket->True,
 CellChangeTimes->{{3.35556152002647*^9, 3.35556154552313*^9}, {
  3.35563455460915*^9, 3.35563457210501*^9}, {3.36731062774955*^9, 
  3.3673107133750987`*^9}}],

Cell["Define a Gaussian model function.", "Text",
 ShowCellBracket->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Gaussian", "[", 
    RowBox[{"a_", ",", 
     RowBox[{"{", 
      RowBox[{"x0_", ",", "y0_"}], "}"}]}], "]"}], "[", 
   RowBox[{"{", 
    RowBox[{"x_", ",", "y_"}], "}"}], "]"}], ":=", 
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{
    RowBox[{"-", "a"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"x", "-", "x0"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"y", "-", "y0"}], ")"}], "2"]}], ")"}]}]]}]], "Input",
 ShowCellBracket->True],

Cell["\<\
Compute a nonlinear least-squares best fit for a Gaussian to the data.\
\>", "Text",
 ShowCellBracket->True],

Cell[BoxData[
 RowBox[{"xydata", " ", "=", " ", 
  RowBox[{"Flatten", "[", 
   RowBox[{
    RowBox[{"MapIndexed", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Flatten", "[", 
        RowBox[{"{", 
         RowBox[{"#2", ",", "#1"}], "}"}], "]"}], "&"}], ",", " ", 
      "orthogonal", ",", 
      RowBox[{"{", "2", "}"}]}], "]"}], ",", "1"}], "]"}]}]], "Input",
 ShowCellBracket->True,
 CellChangeTimes->{3.43009447840625*^9}],

Cell[BoxData[
 RowBox[{"fit", " ", "=", " ", 
  RowBox[{"FindFit", "[", 
   RowBox[{"xydata", ",", " ", 
    RowBox[{
     RowBox[{"Gaussian", "[", 
      RowBox[{"a", ",", " ", 
       RowBox[{"{", 
        RowBox[{"x0", ",", " ", "y0"}], "}"}]}], "]"}], "[", 
     RowBox[{"{", 
      RowBox[{"x", ",", "y"}], "}"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"a", ",", ".1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"x0", ",", " ", "50"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"y0", ",", " ", "60"}], "}"}]}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y"}], "}"}]}], "]"}]}]], "Input",
 ShowCellBracket->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Gaussian", "[", 
    RowBox[{"a", ",", " ", 
     RowBox[{"{", 
      RowBox[{"x0", ",", " ", "y0"}], "}"}]}], "]"}], "[", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y"}], "}"}], "]"}], " ", "/.", " ", "fit"}]], "Input",
 ShowCellBracket->True],

Cell["Show contours for the data and the fit.", "Text",
 ShowCellBracket->True],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"imgdetail", ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"Gaussian", "[", 
         RowBox[{"a", ",", " ", 
          RowBox[{"{", 
           RowBox[{"x0", ",", " ", "y0"}], "}"}]}], "]"}], "[", 
        RowBox[{"{", 
         RowBox[{"y", ",", "x"}], "}"}], "]"}], " ", "/.", " ", "fit"}], 
      "]"}], ",", "  ", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "100"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "0", ",", "100"}], "}"}], ",", 
     RowBox[{"Contours", "->", 
      RowBox[{"{", "0.5", "}"}]}], ",", 
     RowBox[{"ContourShading", "\[Rule]", "False"}], ",", 
     RowBox[{"PlotRange", "->", "All"}]}], "]"}], ",", "\[IndentingNewLine]", 
   "\n", 
   RowBox[{"ListContourPlot", "[", 
    RowBox[{"orthogonal", ",", 
     RowBox[{"Contours", "->", 
      RowBox[{"{", "0.5", "}"}]}], ",", 
     RowBox[{"ContourShading", "\[Rule]", "False"}], ",", 
     RowBox[{"PlotRange", "->", "All"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.35556197624248*^9, 3.35556214013815*^9}, {
  3.35556259766604*^9, 3.35556269978288*^9}, {3.3673110536897755`*^9, 
  3.3673110585648074`*^9}, {3.3834762635*^9, 3.383476301640625*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Why \"The New Era\"?", "Section",
 CellChangeTimes->{{3.35373632824467*^9, 3.35373635942977*^9}, 
   3.36085308270313*^9, 3.36103287232813*^9}],

Cell[CellGroupData[{

Cell["\"Instantly dynamic\": new, unique and important", "Subsection",
 CellChangeTimes:>{{3.35373640039538*^9, 3.35373643901741*^9}, {
   3.35373662284781*^9, 3.35373665501866*^9}, {3.35373685030928*^9, 
   3.35373685119988*^9}, 3.35452520841722*^9, {3.35452550221304*^9, 
   3.35452553452678*^9}}],

Cell["\<\
Means a whole new era of modelling, simulation and development.\
\>", "Subsubsection",
 CellChangeTimes->{{3.35452550987555*^9, 3.35452553833404*^9}, {
  3.35452657017169*^9, 3.35452661392126*^9}, {3.35452779307317*^9, 
  3.35452779651044*^9}, {3.43015571359375*^9, 3.430155721328125*^9}}],

Cell[CellGroupData[{

Cell["Analogy: what can be done with DOS v Vista/MacOSX", "Subsubsection",
 CellChangeTimes->{{3.35452550987555*^9, 3.35452553833404*^9}, {
   3.35452657017169*^9, 3.35452661392126*^9}, 3.35452779307317*^9, {
   3.38347745078125*^9, 3.383477455828125*^9}}],

Cell[BoxData[" "], "Input",
 CellChangeTimes->{3.430155810515625*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Revolutionary concept of \"personal development environment\"", \
"Subsection",
 CellChangeTimes:>{{3.354426262291*^9, 3.35442629149412*^9}, {
   3.35442633338475*^9, 3.35442633950975*^9}, {3.35442650158787*^9, 
   3.35442654311912*^9}, 3.35452521001555*^9, {3.35452599187555*^9, 
   3.3545260273477*^9}}],

Cell[TextData[StyleBox["Taking non-developers and enabling development", \
"Text"]], "Subsubsection",
 CellChangeTimes:>{{3.354426262291*^9, 3.35442629149412*^9}, {
   3.35442633338475*^9, 3.35442633950975*^9}, {3.35442650158787*^9, 
   3.35442654311912*^9}, 3.35452521001555*^9, {3.35452599187555*^9, 
   3.35452601028954*^9}, {3.35452780579906*^9, 3.35452784105106*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Analogy: Google making everyone personal librarian", \
"Text"]], "Subsubsection",
 CellChangeTimes:>{{3.354426262291*^9, 3.35442629149412*^9}, {
   3.35442633338475*^9, 3.35442633950975*^9}, {3.35442650158787*^9, 
   3.35442654311912*^9}, 3.35452521001555*^9, {3.35452599187555*^9, 
   3.35452601028954*^9}, {3.35452780579906*^9, 3.35452784506387*^9}, 
   3.35453017386581*^9}],

Cell[BoxData[" "], "Input",
 CellChangeTimes->{3.43015581271875*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Completing the \"fully integrated\" vision", "Subsection",
 CellChangeTimes->{{3.354426262291*^9, 3.35442629149412*^9}, {
   3.35442633338475*^9, 3.35442633950975*^9}, {3.35442650158787*^9, 
   3.35442654311912*^9}, 3.35452521001555*^9, {3.35452599187555*^9, 
   3.3545260273477*^9}, {3.383400470265625*^9, 3.383400484140625*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"parts", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<Programming\>\"", ",", "\"\<Numerics\>\"", ",", "\"\<Symbolics\>\"", 
     ",", "\"\<Documents\>\"", ",", "\"\<Text\>\"", ",", "\"\<Graphics\>\""}],
     "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Apply", "[", 
  RowBox[{"Mouseover", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"GraphPlot", "[", 
      RowBox[{"#", ",", 
       RowBox[{"DirectedEdges", "\[Rule]", "True"}], ",", 
       RowBox[{"VertexLabeling", "\[Rule]", "True"}], ",", 
       RowBox[{"Method", "\[Rule]", "\"\<CircularEmbedding\>\""}], ",", 
       RowBox[{"MultiedgeStyle", "\[Rule]", "0.04"}], ",", 
       RowBox[{"SelfLoopStyle", "\[Rule]", "None"}], ",", 
       RowBox[{"ImageSize", "\[Rule]", "400"}]}], "]"}], "&"}], "/@", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"DeleteCases", "[", 
         RowBox[{
          RowBox[{"Flatten", "@", 
           RowBox[{"Outer", "[", 
            RowBox[{"Rule", ",", "parts", ",", "parts"}], "]"}]}], ",", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"HoldPattern", "[", 
             RowBox[{"\"\<Graphics\>\"", "\[Rule]", "_"}], "]"}], "|", 
            RowBox[{"HoldPattern", "[", 
             RowBox[{"\"\<Documents\>\"", "\[Rule]", "\"\<Graphics\>\""}], 
             "]"}]}], ")"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\"\<Interfaces\>\"", "\[Rule]", "\"\<Programming\>\""}], 
          ",", 
          RowBox[{"\"\<Programming\>\"", "->", "\"\<Interfaces\>\""}]}], 
         "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"AppendTo", "[", 
        RowBox[{"parts", ",", "\"\<Interfaces\>\""}], "]"}], ";", 
       RowBox[{"Flatten", "@", 
        RowBox[{"Outer", "[", 
         RowBox[{"Rule", ",", "parts", ",", "parts"}], "]"}]}]}]}], "}"}]}]}],
   "]"}]}], "Input",
 CellChangeTimes->{{3.38339319028125*^9, 3.383393213125*^9}, {
  3.383393248203125*^9, 3.383393277703125*^9}, {3.383393340734375*^9, 
  3.383393357078125*^9}, {3.383393390359375*^9, 3.383393416796875*^9}, {
  3.383393464375*^9, 3.383393468375*^9}, {3.383393561078125*^9, 
  3.38339357803125*^9}, {3.383393611328125*^9, 3.383393620265625*^9}, {
  3.383393684140625*^9, 3.383393692359375*^9}, {3.3833938531875*^9, 
  3.383393897328125*^9}, {3.38339396478125*^9, 3.383394047421875*^9}, {
  3.383394423203125*^9, 3.383394470296875*^9}, {3.38339462159375*^9, 
  3.383394621890625*^9}, {3.383394690984375*^9, 3.383394695109375*^9}, {
  3.3833947308125*^9, 3.3833947411875*^9}, {3.383394963*^9, 
  3.383394964265625*^9}, {3.383395000140625*^9, 3.38339502896875*^9}, {
  3.383395079609375*^9, 3.3833950843125*^9}, {3.383395125796875*^9, 
  3.383395128390625*^9}, {3.383395376953125*^9, 3.38339537725*^9}, {
  3.38339545103125*^9, 3.383395487*^9}, {3.383395541578125*^9, 
  3.383395563140625*^9}, {3.383400552796875*^9, 3.383400586046875*^9}, {
  3.383400701328125*^9, 3.383400765859375*^9}, {3.38340080753125*^9, 
  3.383400875640625*^9}, {3.383400906421875*^9, 3.38340093675*^9}, {
  3.383476924*^9, 3.383476932359375*^9}, {3.4301558236875*^9, 
  3.430155852125*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Mathematica'",
  FontSlant->"Italic"],
 "s basic concept: everything is an expression"
}], "Section",
 CellChangeTimes->{{3.430095582109375*^9, 3.4300955836875*^9}, {
  3.430095615671875*^9, 3.43009563915625*^9}}],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " is built on a simple and efficient concept: everything is (internally) \
represented as an expression having the form ",
 StyleBox["Name[arguments, options]",
  FontWeight->"Bold"],
 ". \nAll objects we can use inside ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " is converted to an expression or expression of expressions (nesting). This \
makes ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " an extremely powerful and flexible language, and at the same time this is \
the \"trick\" for an immediate understanding of how the system works.\nThe \
version 6 has fully integrated this concept also for those elements, such \
graphics, that apparently have a different shape.\nTo explore the internal \
representation of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " objects, we have some functions like FullForm, InputForm TreeForm and so \
on.\nHere in the internal form of a rational number"
}], "Text",
 CellChangeTimes->{{3.404037299953125*^9, 3.404037336765625*^9}, {
  3.40403741684375*^9, 3.40403772046875*^9}, {3.404037787109375*^9, 
  3.404037862484375*^9}, {3.4040379009375*^9, 3.404037910203125*^9}, {
  3.404037954125*^9, 3.40403795775*^9}, {3.404276389828125*^9, 
  3.4042765214375*^9}, {3.430095659296875*^9, 3.430095863078125*^9}, {
  3.430095894640625*^9, 3.4300958960625*^9}, {3.4301558778125*^9, 
  3.430155879125*^9}, {3.430155909828125*^9, 3.4301559224375*^9}, {
  3.430155964453125*^9, 3.43015600725*^9}}],

Cell[BoxData[
 RowBox[{"FullForm", "[", 
  FractionBox["1", "3"], "]"}]], "Input",
 CellChangeTimes->{{3.40427652334375*^9, 3.404276529328125*^9}, {
  3.4167180995*^9, 3.41671810125*^9}}],

Cell[BoxData[
 RowBox[{"TreeForm", "[", 
  FractionBox["1", "3"], "]"}]], "Input",
 CellChangeTimes->{{3.40427653175*^9, 3.404276536875*^9}, {
  3.416718105828125*^9, 3.416718106609375*^9}}],

Cell["A binomial", "Text",
 CellChangeTimes->{{3.430156016265625*^9, 3.430156021859375*^9}}],

Cell[BoxData[
 RowBox[{"FullForm", "[", 
  RowBox[{"a", "+", 
   RowBox[{"b", " ", "x"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4167181118125*^9, 3.416718116953125*^9}}],

Cell[BoxData[
 RowBox[{"TreeForm", "[", 
  RowBox[{"a", "+", 
   RowBox[{"b", " ", "x"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4167181118125*^9, 3.41671812228125*^9}}],

Cell["A graphic", "Text",
 CellChangeTimes->{{3.43015602784375*^9, 3.430156031953125*^9}}],

Cell[BoxData[
 RowBox[{"gr", "=", 
  RowBox[{"Graphics", "[", 
   RowBox[{"{", 
    RowBox[{"Blue", ",", " ", 
     RowBox[{"Circle", "[", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}], "]"}]}], "}"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.404276540609375*^9, 3.4042765531875*^9}, {
  3.4058323299375*^9, 3.4058323344375*^9}}],

Cell[BoxData[
 RowBox[{"FullForm", "[", "gr", "]"}]], "Input",
 CellChangeTimes->{{3.43015603925*^9, 3.430156044015625*^9}}],

Cell[BoxData[
 RowBox[{"TreeForm", "[", "gr", "]"}]], "Input",
 CellChangeTimes->{{3.404276555109375*^9, 3.40427655740625*^9}}],

Cell["\<\
Knowing the internal form is also useful to manage our results without to \
find complex alternatives or re-write pieces of code. If I want to replace \
the circle with a disk, I can use a replacement rule specifying that he \
objects Circle have to be replaced by the object Disk.  \
\>", "Text",
 CellChangeTimes->{{3.4301560496875*^9, 3.43015625090625*^9}}],

Cell[BoxData[
 RowBox[{"ReplaceAll", "[", 
  RowBox[{"gr", ",", 
   RowBox[{"Circle", "\[Rule]", "Disk"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.405832290359375*^9, 3.40583230359375*^9}, {
  3.405832340953125*^9, 3.405832341296875*^9}}],

Cell[TextData[{
 "Even the front end (the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " user interface module) manages objects with the same philosofy. "
}], "Text",
 CellChangeTimes->{{3.430095928828125*^9, 3.430095966*^9}, {
  3.43015626371875*^9, 3.43015626384375*^9}}],

Cell["\<\
Here is a dynamic object enabling the manipulation of a polynomial expansion\
\>", "Text",
 CellChangeTimes->{{3.404227306921875*^9, 3.404227309390625*^9}, {
  3.416718155625*^9, 3.416718178453125*^9}, {3.43009597015625*^9, 
  3.4300959898125*^9}}],

Cell[BoxData[
 RowBox[{"man", "=", 
  RowBox[{"Manipulate", "[", 
   RowBox[{
    RowBox[{"Expand", "[", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"x", "-", "2"}], ")"}], "n"], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"n", ",", "2", ",", "10", ",", "1"}], "}"}]}], "]"}]}]], "Input",\

 CellChangeTimes->{{3.40403862184375*^9, 3.40403864975*^9}, {
  3.404039126140625*^9, 3.404039159875*^9}, {3.4042766238125*^9, 
  3.404276624421875*^9}, {3.4045908891875*^9, 3.40459088971875*^9}, {
  3.416718182015625*^9, 3.4167181829375*^9}}],

Cell["I can ask for the InputForm and the TreeForm as well", "Text",
 CellChangeTimes->{{3.43015628340625*^9, 3.430156294140625*^9}}],

Cell[BoxData[
 RowBox[{"FullForm", "[", "man", "]"}]], "Input",
 CellChangeTimes->{{3.4301563088125*^9, 3.430156317390625*^9}}],

Cell[BoxData[
 RowBox[{"TreeForm", "[", "man", "]"}]], "Input",
 CellChangeTimes->{{3.4042766046875*^9, 3.404276627234375*^9}}],

Cell["\<\
So, if I want to change the x variable, I can use ReplaceAll once again\
\>", "Text",
 CellChangeTimes->{{3.4301563356875*^9, 3.4301563645625*^9}}],

Cell[BoxData[
 RowBox[{"ReplaceAll", "[", 
  RowBox[{"man", ",", 
   RowBox[{"x", "\[Rule]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"z", "-", "1"}], ")"}], "^", "2"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.404276628703125*^9, 3.4042766408125*^9}}],

Cell["Another example.", "Text",
 CellChangeTimes->{{3.430096024609375*^9, 3.430096026640625*^9}, 
   3.4301563746875*^9}],

Cell["\<\
Here is a list of points of the function Sin and the ListPlot image\
\>", "Text",
 CellChangeTimes->{{3.41672127171875*^9, 3.416721290828125*^9}, {
  3.430096029546875*^9, 3.43009603665625*^9}, {3.43015638896875*^9, 
  3.43015640525*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"Sin", "[", "x", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", 
       RowBox[{"6", "Pi"}], ",", "0.02"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ListPlot", "[", "data", "]"}]}], "Input"],

Cell["\<\
With an easy replacemente rule, I generate a list of triple, where starting \
from the couple {x, y} the third value is a function of the first two\
\>", "Text",
 CellChangeTimes->{{3.4167212941875*^9, 3.416721321140625*^9}, {
  3.430096043640625*^9, 3.430096091046875*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"ReplaceAll", "[", 
    RowBox[{"data", " ", ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x_", ",", "y_"}], "}"}], "->", 
      RowBox[{"{", 
       RowBox[{"x", ",", "y", ",", 
        RowBox[{"Sin", "[", 
         RowBox[{"x", " ", "y"}], "]"}]}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ListPointPlot3D", "[", "data", "]"}]}], "Input",
 CellChangeTimes->{{3.41672135503125*^9, 3.416721358640625*^9}, {
   3.42034745596875*^9, 3.420347463125*^9}, 3.430096105*^9}],

Cell["A more useful example", "Text",
 CellChangeTimes->{{3.4300987025*^9, 3.430098710265625*^9}}],

Cell[TextData[{
 "In astronomical field, sometimes it is needed to plot functions with \
reversed x axes (x values decreases from left to right). The flexibility of \
",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " allows to obtain this kind of result without to increase the complexity or \
the number of funtions already built-in."
}], "Text",
 CellChangeTimes->{{3.430098714109375*^9, 3.430098786734375*^9}, {
  3.43015644878125*^9, 3.430156501609375*^9}}],

Cell[BoxData[
 RowBox[{"s", "=", 
  RowBox[{"FullGraphics", "[", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Cos", "[", "x", "]"}], "+", "x"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "10"}], "}"}]}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"ReplaceAll", "[", 
  RowBox[{"s", ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x_Real", ",", "y_Real"}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "x"}], ",", "y"}], "}"}]}]}], "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Dynamic interaction: a completely new feature in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 6"
}], "Section",
 CellChangeTimes->{{3.4040246500395*^9, 3.40402465100825*^9}, 
   3.40403727878125*^9, {3.43010159103125*^9, 3.43010160190625*^9}}],

Cell[CellGroupData[{

Cell["Examples", "Subsection",
 CellChangeTimes->{{3.404196851953125*^9, 3.404196852953125*^9}, {
  3.43010163775*^9, 3.430101638859375*^9}}],

Cell["\<\
Here I generate two results, apparently identical: the solution of an \
equation with three parameters and the \"Dynamic\" version of the same \
solution\
\>", "Text",
 CellChangeTimes->{{3.41672257853125*^9, 3.416722581265625*^9}, {
  3.43010164059375*^9, 3.43010165415625*^9}, {3.430156529421875*^9, 
  3.43015659771875*^9}}],

Cell[BoxData[
 RowBox[{"Panel", "[", 
  RowBox[{"Row", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"a", " ", 
          SuperscriptBox["x", "2"]}], "+", 
         RowBox[{"b", " ", "x"}], "+", "c"}], "\[Equal]", "0"}], ",", "x"}], 
      "]"}], ",", 
     RowBox[{"Spacer", "[", "50", "]"}], ",", 
     RowBox[{"Dynamic", "[", 
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"a", " ", 
           SuperscriptBox["x", "2"]}], "+", 
          RowBox[{"b", " ", "x"}], "+", "c"}], "\[Equal]", "0"}], ",", "x"}], 
       "]"}], "]"}]}], "}"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.430156599796875*^9, 3.430156645484375*^9}}],

Cell["\<\
Now we can assign any value to one or more of the variable included in the \
solution, and see how the above cell change accordingly\
\>", "Text",
 CellChangeTimes->{{3.417335359625*^9, 3.41733540859375*^9}, {
  3.43010165946875*^9, 3.43010168459375*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a", "=", "0"}], ",", 
   RowBox[{"b", "=", "1"}], ",", 
   RowBox[{"c", "=", 
    RowBox[{"-", "2"}]}]}], "}"}]], "Input",
 CellChangeTimes->{{3.41672258403125*^9, 3.416722593640625*^9}, {
  3.417335353578125*^9, 3.417335375375*^9}}],

Cell["\<\
As you have seen, the first result is static, while the second one changes \
when a/b/c are changed. We can use some facilities to set their values. For \
instance a SetterBar\
\>", "Text",
 CellChangeTimes->{{3.416722651328125*^9, 3.416722672484375*^9}, {
  3.430101692609375*^9, 3.430101704390625*^9}, {3.430156729359375*^9, 
  3.430156771234375*^9}}],

Cell[BoxData[
 RowBox[{"SetterBar", "[", 
  RowBox[{
   RowBox[{"Dynamic", "[", "a", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.416722614171875*^9, 3.416722640234375*^9}}],

Cell["\<\
Here I arrange three controls, with SetterBar, one for each parameter\
\>", "Text",
 CellChangeTimes->{{3.430156680453125*^9, 3.430156712890625*^9}}],

Cell[BoxData[
 RowBox[{"Panel", "[", "\[IndentingNewLine]", 
  RowBox[{"Column", "[", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Row", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<Imposta a \>\"", ",", 
        RowBox[{"SetterBar", "[", 
         RowBox[{
          RowBox[{"Dynamic", "[", "a", "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "5"}], ",", "5"}], "]"}]}], "]"}]}], "}"}], "]"}], 
     ",", 
     RowBox[{"Row", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<Imposta b \>\"", ",", 
        RowBox[{"SetterBar", "[", 
         RowBox[{
          RowBox[{"Dynamic", "[", "b", "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "5"}], ",", "5"}], "]"}]}], "]"}]}], "}"}], "]"}], 
     ",", 
     RowBox[{"Row", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<Imposta c \>\"", ",", " ", 
        RowBox[{"SetterBar", "[", 
         RowBox[{
          RowBox[{"Dynamic", "[", "c", "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "5"}], ",", "5"}], "]"}]}], "]"}]}], "}"}], "]"}]}], 
    "}"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.416722678515625*^9, 3.416722806703125*^9}, {
  3.4301017121875*^9, 3.430101712875*^9}}],

Cell["\<\
Manipulate is a \"macro\" that allow an immediate generation of a special box \
where parameters can be manipulated by controllers.\
\>", "Text",
 CellChangeTimes->{{3.404227306921875*^9, 3.404227323015625*^9}, {
  3.41671823309375*^9, 3.41671823615625*^9}, {3.43010171884375*^9, 
  3.43010172209375*^9}, {3.430156793546875*^9, 3.43015684175*^9}}],

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Style", "[", 
    RowBox[{
     RowBox[{"Column", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Row", "[", 
          RowBox[{"{", 
           RowBox[{"\"\<Discriminant \[Rule]  \>\"", ",", " ", 
            RowBox[{"ToString", "[", 
             RowBox[{
              RowBox[{"b", "^", "2"}], "-", 
              RowBox[{"4", "a", " ", "c"}]}], "]"}]}], "}"}], "]"}], ",", 
         RowBox[{"Row", "[", 
          RowBox[{"{", 
           RowBox[{"\"\<Solutions \[Rule]  \>\"", ",", 
            RowBox[{"Reduce", "[", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"a", " ", 
                 RowBox[{"x", "^", "2"}]}], "+", 
                RowBox[{"b", " ", "x"}], " ", "+", "c"}], " ", "\[Equal]", 
               "0"}], ",", "x", ",", "Reals"}], "]"}]}], "}"}], "]"}]}], 
        "}"}], ",", 
       RowBox[{"Spacings", "\[Rule]", "2"}]}], "]"}], ",", "Large"}], "]"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"a", ",", 
     RowBox[{"-", "5"}], ",", "5", ",", "1", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"b", ",", 
     RowBox[{"-", "5"}], ",", "5", ",", "1", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"c", ",", 
     RowBox[{"-", "5"}], ",", "5", ",", "1", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.404197796171875*^9, 3.40419785065625*^9}, {
   3.404197886859375*^9, 3.40419802465625*^9}, {3.40419806715625*^9, 
   3.404198232578125*^9}, 3.4041983421875*^9, {3.4041984445625*^9, 
   3.40419852034375*^9}, {3.404198614609375*^9, 3.4041986224375*^9}, {
   3.430101751453125*^9, 3.430101757296875*^9}}],

Cell[TextData[{
 "Another nice and useful new feature is Mouseover. It allow to overlap two \
objects and shows the first or the second depending on the position of the \
mouse pointer (outside or inside the object's box). \nHere is a ",
 StyleBox["double face ",
  FontSlant->"Italic"],
 "graphic, representing a ListPlot of a random data set and the BinCounts of \
its values. Mmove the mous pointer inside/outside the image to see the \"side \
B\""
}], "Text",
 CellChangeTimes->{{3.404227306921875*^9, 3.404227323015625*^9}, {
  3.41671823309375*^9, 3.416718253453125*^9}, {3.4301017695*^9, 
  3.430101772171875*^9}, {3.430156852328125*^9, 3.430156975375*^9}, {
  3.430157033796875*^9, 3.430157073859375*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"RandomReal", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "10"}], "}"}], ",", "1000"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Needs", "[", "\"\<BarCharts`\>\"", "]"}], ";"}], "\n", 
 RowBox[{"Mouseover", "[", 
  RowBox[{
   RowBox[{"ListPlot", "[", "data", "]"}], ",", 
   RowBox[{"BarChart", "[", 
    RowBox[{"BinCounts", "[", 
     RowBox[{"data", ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "10", ",", "1"}], "}"}]}], "]"}], "]"}]}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.40419486503125*^9, 3.40419486940625*^9}, {
   3.40419497184375*^9, 3.40419501678125*^9}, {3.404195061953125*^9, 
   3.404195062078125*^9}, {3.404195219203125*^9, 3.40419521928125*^9}, {
   3.404195753578125*^9, 3.404195754359375*^9}, {3.40422771990625*^9, 
   3.404227751078125*^9}, 3.4301570201875*^9}],

Cell["Another example", "Text",
 CellChangeTimes->{{3.43015708103125*^9, 3.430157086203125*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"RandomReal", "[", 
    RowBox[{"1", ",", 
     RowBox[{"{", 
      RowBox[{"100", ",", "2"}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Mouseover", "[", 
   RowBox[{
    RowBox[{"ListPlot", "[", "data", "]"}], ",", 
    RowBox[{"Tooltip", "[", 
     RowBox[{
      RowBox[{"ListLinePlot", "[", 
       RowBox[{"data", "[", 
        RowBox[{"[", 
         RowBox[{"Last", "@", 
          RowBox[{"FindShortestTour", "[", "data", "]"}]}], "]"}], "]"}], 
       "]"}], ",", "\"\<Percorso minimo\>\""}], "]"}]}], "]"}], 
  " "}]}], "Input",
 CellChangeTimes->{3.40419545540625*^9, 3.4301570888125*^9}],

Cell[TextData[{
 "Note that in just one line of code we have used random number generation, a \
graphic function, a quite complex algorithm finding the shortest tour from a \
set of points and an interactivy function controlling the mouse position. \
This is an easy and intuitive example of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " as an integrated system. The same philosophy for several different tasks \
and operations."
}], "Text",
 CellChangeTimes->{{3.4301571015*^9, 3.430157280265625*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2D and 3D graphics: some examples and new feaures", "Section",
 CellChangeTimes->{{3.39231656421875*^9, 3.3923165763125*^9}, {
  3.43010143234375*^9, 3.430101435453125*^9}}],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Sin", "[", 
    SuperscriptBox["\[ExponentialE]", "x"], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "4"}], "}"}]}], "]"}]], "Input"],

Cell["\<\
We can easily manipulate graphics using parameters and manipulators\
\>", "Text",
 CellChangeTimes->{{3.39231658934375*^9, 3.392316624125*^9}}],

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"Sin", "[", 
      RowBox[{"x", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{
          StyleBox["a",
           FontColor->RGBColor[1, 0, 0]], " ", "x"}]}], ")"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "6"}], "}"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     StyleBox["a",
      FontWeight->"Plain",
      FontColor->RGBColor[1, 0, 0]], ",", "0", ",", "2"}], "}"}]}], 
  "]"}]], "Input"],

Cell["Functions of two variables", "Text",
 CellChangeTimes->{{3.392316635828125*^9, 3.39231664275*^9}},
 CellTags->{"S0.4.1", "1.5"}],

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{"x", " ", 
    RowBox[{"Sin", "[", 
     RowBox[{"x", "+", 
      RowBox[{"y", "^", "2"}]}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Orange", ",", 
      RowBox[{"Specularity", "[", 
       RowBox[{"White", ",", "20"}], "]"}]}], "}"}]}], ",", 
   RowBox[{"Mesh", "\[Rule]", "None"}], ",", 
   RowBox[{"PlotPoints", "\[Rule]", "50"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.3823242491520967`*^9, 3.3823243842007003`*^9}, {
  3.3823245909533467`*^9, 3.382324596500293*^9}, {3.382410117632161*^9, 
  3.3824101206634493`*^9}},
 CellID->596132949],

Cell[BoxData[" "], "Input",
 CellChangeTimes->{3.430101972890625*^9}],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "\[CloseCurlyQuote]s plot functions are now fully numeric and as a result \
allow the specification of ",
 Cell[BoxData[
  ButtonBox["WorkingPrecision",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/WorkingPrecision"]], "InlineFormula"],
 ". This will help clean up plots that would otherwise display some noise. ",
 "\n",
 "In this example the imaginary part of the ",
 Cell[BoxData[
  ButtonBox["WeierstrassZeta",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/WeierstrassZeta"]], "InlineFormula"],
 " function is zero on the specified interval but numerical error creeps in \
leading to a lot of noise in the plot."
}], "Text",
 CellChangeTimes->{{3.39122301684375*^9, 3.3912231045*^9}, 3.3923167045625*^9,
    3.4301573025*^9},
 CellTags->"Plot"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    FractionBox["z", 
     SuperscriptBox["10", "15"]], "+", 
    RowBox[{"Im", "[", 
     RowBox[{"WeierstrassZeta", "[", 
      RowBox[{"z", ",", " ", 
       RowBox[{"{", 
        RowBox[{"3", ",", "4"}], "}"}]}], "]"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"z", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.39122316121875*^9, 3.39122317065625*^9}},
 CellTags->"Plot"],

Cell[TextData[{
 "Setting the ",
 Cell[BoxData[
  ButtonBox["WorkingPrecision",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/WorkingPrecision"]], "InlineFormula"],
 " to 32 corrects the situation."
}], "Text",
 CellChangeTimes->{{3.391223177546875*^9, 3.39122319925*^9}, 
   3.392316741875*^9},
 CellTags->"Plot"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"z", "/", 
     SuperscriptBox["10", "15"]}], "+", 
    RowBox[{"Im", "[", 
     RowBox[{"WeierstrassZeta", "[", 
      RowBox[{"z", ",", " ", 
       RowBox[{"{", 
        RowBox[{"3", ",", "4"}], "}"}]}], "]"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"z", ",", "0", ",", "1"}], "}"}], ",", 
   RowBox[{"WorkingPrecision", "\[Rule]", " ", "32"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.377549984277019*^9, 3.377549998858212*^9}},
 CellTags->"Plot"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Plot: ", "Color7"],
 "Singularity Removal"
}], "Section",
 CellChangeTimes->{{3.391225274875*^9, 3.391225277234375*^9}, {
  3.39231675396875*^9, 3.392316756796875*^9}},
 CellTags->"Plot"],

Cell[TextData[{
 "If a function has non-removable singularities at points ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", 
    RowBox[{"i", " "}]], TraditionalForm]]],
 ", the vertical lines that would normally appear in the plot can be avoided \
by including those points in the plot specification. This is similar to \
having ",
 Cell[BoxData[
  ButtonBox["NIntegrate",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/NIntegrate"]], "InlineFormula"],
 " pay special attention to individual points when integrating."
}], "Text",
 CellChangeTimes->{{3.39122528015625*^9, 3.391225350359375*^9}, {
  3.3923167624375*^9, 3.392316765703125*^9}},
 CellTags->"Plot"],

Cell[TextData[{
 "This function has singularities at 0 and ",
 Cell[BoxData[
  FormBox[
   FractionBox["1", "2"], TraditionalForm]]],
 ". "
}], "MathCaption",
 CellChangeTimes->{{3.391225352484375*^9, 3.39122536509375*^9}, 
   3.392316773*^9},
 CellTags->"Plot"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"x", 
     RowBox[{"(", 
      RowBox[{"x", "-", 
       FractionBox["1", "2"]}], ")"}]}]], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Red", ",", "Thick"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.3912253695625*^9, 3.391225440890625*^9}},
 CellTags->"Plot"],

Cell["\<\
If we specify the exclusion values, we can also specify a style to use for \
those values. Giving the two colors, blue and orange, creates a blue line \
with orange points at the end.\
\>", "Text",
 CellChangeTimes->{{3.391225448125*^9, 3.391225544265625*^9}, 
   3.392316793984375*^9, {3.39231685325*^9, 3.392316855671875*^9}, 
   3.392317168359375*^9},
 CellTags->"Plot"],

Cell["\<\
Here we specify the locations of the singularities. In this case the excluded \
values are indicated by blue lines with orange points at the minimum and \
maximum values.\
\>", "MathCaption",
 CellChangeTimes->{{3.391225448125*^9, 3.391225544265625*^9}, 
   3.392316793984375*^9, {3.39231685325*^9, 3.392316855671875*^9}, 
   3.392317168359375*^9},
 CellTags->"Plot"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   FractionBox["1", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"x", "+", 
       FractionBox["1", "4"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"x", "-", 
       FractionBox["1", "2"]}], ")"}]}]], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
   RowBox[{"Exclusions", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x", "\[Equal]", 
       RowBox[{"-", 
        FractionBox["1", "4"]}]}], ",", 
      RowBox[{"x", "\[Equal]", 
       FractionBox["1", "2"]}]}], "}"}]}], ",", 
   RowBox[{"ExclusionsStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Blue", ",", "Orange"}], "}"}]}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"Red", ",", "Thick"}], "}"}], "}"}]}]}], "]"}]], "Input",
 CellTags->"Plot"],

Cell["Similar functions are available for 3D graphics", "MathCaption",
 CellChangeTimes->{{3.3912281764375*^9, 3.3912281840625*^9}, {
  3.3923169066875*^9, 3.39231692*^9}}],

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{
   FractionBox["2", 
    RowBox[{"y", "-", 
     SuperscriptBox["x", "2"]}]], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
   RowBox[{"Mesh", "\[Rule]", "None"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "5"}], ",", 
   RowBox[{"Exclusions", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"y", "\[Equal]", 
      SuperscriptBox["x", "2"]}], "}"}]}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{
   FractionBox["2", 
    RowBox[{"y", "-", 
     SuperscriptBox["x", "2"]}]], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
   RowBox[{"Mesh", "\[Rule]", "None"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "5"}], ",", 
   RowBox[{"Exclusions", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"y", "\[Equal]", 
      SuperscriptBox["x", "2"]}], "}"}]}], ",", 
   RowBox[{"ExclusionsStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Directive", "[", 
      RowBox[{"Opacity", "[", ".5", "]"}], "]"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.391228210390625*^9, 3.391228234515625*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Plot: ", "Color7"],
 "Automatic Removal of Non-Real Values"
}], "Section",
 CellChangeTimes->{{3.391225649265625*^9, 3.39122565421875*^9}, {
  3.392316934171875*^9, 3.392316942203125*^9}},
 CellTags->"Plot"],

Cell[TextData[{
 "The visualization functions in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " are defined to work with real-valued functions. Hence if a function \
becomes complex- or other-valued at some point, those values are excluded. \
With the adaptive sampling algorithm built into these functions, you will \
usually get fairly close to the real-valued barrier. "
}], "Text",
 CellChangeTimes->{{3.391225657984375*^9, 3.39122574359375*^9}, 
   3.392316950046875*^9},
 CellTags->"Plot"],

Cell["\<\
Here is an example of a function that returns complex values on the specified \
domain.\
\>", "MathCaption",
 CellChangeTimes->{{3.3912257494375*^9, 3.391225762953125*^9}, {
   3.391229743375*^9, 3.391229745890625*^9}, 3.392316957078125*^9},
 CellTags->"Plot"],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   SqrtBox[
    RowBox[{"1", "-", 
     SuperscriptBox["x", "2"]}]], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "2"}], ",", "2", ",", "0.1"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   SqrtBox[
    RowBox[{"1", "-", 
     SuperscriptBox["x", "2"]}]], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"Red", ",", "Thick"}], "}"}], "}"}]}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}]], "Input",
 CellTags->"Plot"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Plot: ", "Color7"],
 "Adaptive Refinement"
}], "Section",
 CellChangeTimes->{{3.391225819953125*^9, 3.391225825171875*^9}, 
   3.392316974859375*^9},
 CellTags->"Plot"],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " uses an adaptive algorithm to determine how many points should be included \
in creating the plot. One of the determining factors is how many recursions \
are used to locate points used in the plot. As with other numeric functions, \
recursion leads to higher precision results."
}], "Text",
 CellChangeTimes->{{3.391225832546875*^9, 3.39122589334375*^9}, 
   3.392316980765625*^9},
 CellTags->"Plot"],

Cell[TextData[{
 "This shows all of the points used in the adaptive sampling routine for ",
 Cell[BoxData[
  ButtonBox["Plot",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Plot"]], "InlineFormula"],
 "."
}], "MathCaption",
 CellChangeTimes->{{3.391225895796875*^9, 3.39122592121875*^9}, 
   3.392316988171875*^9},
 CellTags->"Plot"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Sin", "[", "t", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
   RowBox[{"Mesh", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellTags->"Plot"],

Cell[TextData[{
 "Adaptive refinement requires repeated sampling of the function which is \
done recursively. This ",
 Cell[BoxData[
  ButtonBox["Manipulate",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Manipulate"]]],
 " illustrates the process."
}], "MathCaption",
 CellChangeTimes->{{3.391225931640625*^9, 3.39122599334375*^9}, 
   3.392316994171875*^9},
 CellTags->"Plot"],

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\n", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"Sin", "[", "x", " ", "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"x", ",", " ", 
       RowBox[{"-", "\[Pi]"}], ",", "\[Pi]"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"MaxRecursion", "\[Rule]", "n"}], ",", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"Mesh", "\[Rule]", "All"}], ",", 
     RowBox[{"MeshStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"PointSize", "[", "0.015", "]"}]}], "}"}]}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "8"}]}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"n", ",", "0", ",", "10", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.391226009765625*^9, 3.39122601315625*^9}},
 CellTags->"Plot"],

Cell["Here is the same for 3D", "MathCaption",
 CellChangeTimes->{{3.391228269703125*^9, 3.391228300953125*^9}, {
  3.392317001390625*^9, 3.39231701040625*^9}}],

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\n", 
  RowBox[{
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"Sin", "[", 
      RowBox[{"x", " ", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
     RowBox[{"MaxRecursion", "\[Rule]", "r"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "8"}], ",", 
     RowBox[{"Mesh", "\[Rule]", "All"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"r", ",", "0", ",", "\"\<MaxRecursion\>\""}], "}"}], ",", "0", 
     ",", "10", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.391228329109375*^9, 3.39122840978125*^9}}],

Cell[" ", "Spacer",
 CellChangeTimes->{3.385714856042118*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Plot: ", "Color7"],
 "Filling"
}], "Section",
 CellChangeTimes->{3.391229219140625*^9},
 CellTags->"Plot"],

Cell[TextData[{
 "A new option, ",
 Cell[BoxData[
  ButtonBox["Filling",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Filling"]], "InlineFormula"],
 ", can be used to shade regions of a plot. This option essentially replaces \
the functionality that was present in the pre-Version 6 package, ",
 StyleBox["Graphics`FilledPlot`", "MR"],
 "."
}], "Text",
 CellChangeTimes->{{3.391229226328125*^9, 3.391229280015625*^9}, 
   3.39231709409375*^9},
 CellTags->"Plot"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Sin", "[", "x", "]"}], ",", 
     RowBox[{"Cos", "[", "x", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", 
     RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
   RowBox[{"Filling", "\[Rule]", "Automatic"}]}], "]"}]], "Input",
 CellTags->"Plot"],

Cell["\<\
You can fill to the horizontal axis, or the top, or bottom of the plot. \
\>", "MathCaption",
 CellChangeTimes->{{3.391229287078125*^9, 3.39122929865625*^9}, 
   3.392317114546875*^9},
 CellTags->"Plot"],

Cell[BoxData[
 RowBox[{"TabView", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"\"\<Top\>\"", "->", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Sin", "[", "x", "]"}], ",", 
         RowBox[{"Cos", "[", "x", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", 
         RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
       RowBox[{"Filling", "\[Rule]", " ", "Top"}]}], "]"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"\"\<Axis\>\"", "->", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Sin", "[", "x", "]"}], ",", 
         RowBox[{"Cos", "[", "x", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", 
         RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
       RowBox[{"Filling", "\[Rule]", " ", "Axis"}]}], "]"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"\"\<Bottom\>\"", "->", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Sin", "[", "x", "]"}], ",", 
         RowBox[{"Cos", "[", "x", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", 
         RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
       RowBox[{"Filling", "\[Rule]", " ", "Bottom"}]}], "]"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"\"\<Inside\>\"", "->", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Sin", "[", "x", "]"}], ",", 
         RowBox[{"Cos", "[", "x", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", 
         RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
       RowBox[{"Filling", "\[Rule]", " ", 
        RowBox[{"{", 
         RowBox[{"1", "\[Rule]", 
          RowBox[{"{", "2", "}"}]}], "}"}]}]}], "]"}]}]}], "}"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.391229323171875*^9, 3.391229410171875*^9}, {
  3.39122947628125*^9, 3.39122950859375*^9}}],

Cell[TextData[{
 "We add a different style in this example with the option ",
 Cell[BoxData[
  ButtonBox["FillingStyle",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/FillingStyle"]], "InlineFormula"],
 ". The colors change depending on which function value is greater."
}], "MathCaption",
 CellChangeTimes->{{3.39122943090625*^9, 3.39122945178125*^9}, {
   3.39122952609375*^9, 3.39122952934375*^9}, 3.39231712884375*^9},
 CellTags->"Plot"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Sin", "[", "x", "]"}], ",", 
     RowBox[{"Cos", "[", "x", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", 
     RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
   RowBox[{"Filling", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"1", "\[Rule]", 
      RowBox[{"{", "2", "}"}]}], "}"}]}], ",", 
   RowBox[{"FillingStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Yellow", ",", "Green"}], "}"}]}]}], "]"}]], "Input",
 CellTags->"Plot"],

Cell["Here is a 3D equivalent", "MathCaption",
 CellChangeTimes->{{3.391229537421875*^9, 3.39122954721875*^9}, {
  3.392317189828125*^9, 3.39231719434375*^9}}],

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{"Sin", "[", 
    RowBox[{"x", " ", "y"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
   RowBox[{"RegionFunction", "\[Rule]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"0.3", "\[LessEqual]", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"#1", "-", 
           FractionBox["\[Pi]", "2"]}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"#2", "-", 
           FractionBox["\[Pi]", "2"]}], ")"}], "2"]}], "\[LessEqual]", "2"}], 
      "&"}], ")"}]}], ",", 
   RowBox[{"Filling", "\[Rule]", "Bottom"}]}], "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Tooltip and MouseOver", "Section",
 CellChangeTimes->{{3.430097684484375*^9, 3.43009769615625*^9}},
 CellTags->"Plot"],

Cell[TextData[{
 "There is a new function, ",
 Cell[BoxData[
  ButtonBox["Tooltip",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Tooltip"]], "InlineFormula"],
 ", which can be used as a wrapper for the plot arguments. The argument to ",
 Cell[BoxData[
  ButtonBox["Tooltip",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Tooltip"]], "InlineFormula"],
 " will display when the mouse passes over the curves in the plot. You can \
use ",
 Cell[BoxData[
  ButtonBox["Tooltip",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Tooltip"]], "InlineFormula"],
 " to distinguish between vectors as in this example."
}], "Text",
 CellChangeTimes->{{3.391226034078125*^9, 3.391226109984375*^9}, 
   3.392317020984375*^9},
 CellTags->"Plot"],

Cell[BoxData[
 RowBox[{"?", "Tooltip"}]], "Input",
 CellTags->"Plot"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Tooltip", "[", 
      RowBox[{"Sin", "[", "x", "]"}], "]"}], ",", 
     RowBox[{"Tooltip", "[", 
      RowBox[{"Cos", "[", "x", "]"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", 
     RowBox[{"2", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.391226162890625*^9, 3.39122619375*^9}, 
   3.39122984271875*^9, {3.43009487053125*^9, 3.43009488425*^9}},
 CellTags->"Plot"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Tooltip", "[", 
        RowBox[{"#", ",", 
         RowBox[{"TraditionalForm", "[", "#", "]"}]}], "]"}], "&"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Sin", "[", "x", "]"}], ",", 
        RowBox[{"Cos", "[", "x", "]"}], ",", 
        RowBox[{"3", 
         RowBox[{"Sin", "[", "x", "]"}]}], ",", 
        RowBox[{
         RowBox[{"Sin", "[", "x", "]"}], "+", "2"}], ",", 
        RowBox[{
         RowBox[{"Cos", "[", "x", "]"}], "+", "2"}]}], "}"}]}], "]"}], "]"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", 
     RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.43009476771875*^9, 3.430094847390625*^9}, {
  3.4300948999375*^9, 3.430094921796875*^9}, {3.430094954640625*^9, 
  3.430094963109375*^9}}],

Cell["\<\
ContourPlot show automatically Tooltips for contour lines\
\>", "Text",
 CellChangeTimes->{{3.3912288398125*^9, 3.391228874328125*^9}, {
  3.392317027421875*^9, 3.392317057484375*^9}, {3.430157362796875*^9, 
  3.430157364921875*^9}}],

Cell[BoxData[
 RowBox[{"ContourPlot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Sin", "[", 
     RowBox[{"2", "x"}], " ", "]"}], 
    RowBox[{"Sin", "[", 
     RowBox[{"2", "y"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
   RowBox[{"ContourLabels", "\[Rule]", "None"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.39122888253125*^9, 3.3912289071875*^9}}],

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"Tooltip", "[", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"x", "+", 
          RowBox[{"n", " ", "y"}]}], "]"}], ",", 
        RowBox[{"Plot", "[", 
         RowBox[{
          RowBox[{"Sin", "[", 
           RowBox[{"n", " ", "x"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", "0", ",", 
            RowBox[{"2", "Pi"}]}], "}"}], ",", 
          RowBox[{"Filling", "\[Rule]", "Axis"}], ",", 
          RowBox[{"FillingStyle", "\[Rule]", "Pink"}], ",", 
          RowBox[{"ImageSize", "\[Rule]", "200"}]}], "]"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", "3"}], "}"}]}], "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", "0", ",", "3"}], "}"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"Opacity", "[", 
       RowBox[{".7", ",", 
        RowBox[{"Hue", "[", 
         RowBox[{"i", "/", "6"}], "]"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "4"}], "}"}]}], "]"}]}]}], "]"}]], "Input", \
"HiddenMaterial",
 CellChangeTimes->{{3.3830894634462824`*^9, 3.3830897459168406`*^9}},
 CellID->704187145],

Cell[BoxData[
 RowBox[{"Grid", "[", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"Mouseover", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"data", "=", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"1", "+", 
            RowBox[{"Sin", "[", 
             RowBox[{"i", " ", 
              RowBox[{"r", "/", "10"}]}], "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"r", ",", "1", ",", "100"}], "}"}]}], "]"}], "+", 
         RowBox[{"RandomReal", "[", 
          RowBox[{
           RowBox[{"t", "/", "5"}], ",", "100"}], "]"}]}]}], ";", 
       RowBox[{"ListPlot", "[", 
        RowBox[{"data", ",", 
         RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
         RowBox[{"AxesOrigin", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}]}]}], "]"}]}], ",", 
      RowBox[{"ListPlot", "[", 
       RowBox[{
        RowBox[{"Abs", "[", 
         RowBox[{"Fourier", "[", "data", "]"}], "]"}], ",", 
        RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
        RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}], ",", 
      RowBox[{"ImageSize", "->", "All"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "4"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "1", ",", "4"}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.3672243097547684`*^9, 3.3672243391438875`*^9}, {
  3.3672255997755957`*^9, 3.3672256401331625`*^9}, {3.367225689521575*^9, 
  3.367225845327094*^9}, {3.367225878388113*^9, 3.367225879356821*^9}, {
  3.367225943057091*^9, 3.367225986742633*^9}, {3.3672260753636622`*^9, 
  3.3672261052373238`*^9}, {3.3672267320409*^9, 3.367226732306515*^9}, {
  3.36730879569095*^9, 3.3673088411443653`*^9}, {3.38346996390625*^9, 
  3.383469969921875*^9}, {3.383470018171875*^9, 3.383470027265625*^9}, {
  3.3834777298125*^9, 3.383477754375*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Graphics fully integrated into the whole system, just like any other object\
\>", "Section",
 CellChangeTimes->{{3.38340264803125*^9, 3.383402652015625*^9}, {
  3.4300994458125*^9, 3.43009945765625*^9}}],

Cell["Coin tossing experiments...", "Text",
 CellChangeTimes->{{3.38347709821875*^9, 3.3834771034375*^9}}],

Cell[BoxData[
 RowBox[{"coins", "=", 
  RowBox[{"{", 
   RowBox[{
    GraphicsBox[RasterBox[CompressedData["
1:eJxtegd4G9XW7UAClxYe5fLDpQW4EFogISEkIQ0IIUBCIL0HElJJSO+F9N7s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      "], {{0, 0}, {60, 61}}, {0, 255},
      ColorFunction->RGBColor],
     ImageSize->{60, 61},
     PlotRange->{{0, 60}, {0, 61}}], ",", 
    GraphicsBox[RasterBox[CompressedData["
1:eJxlegd4E+cSrW7ITSWh92ZTQkkgIQUIkAIkN70XLgmhBRJ6Mc24F7nLVXKR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      "], {{0, 0}, {60, 60}}, {0, 255},
      ColorFunction->RGBColor],
     ImageSize->{60, 60},
     PlotRange->{{0, 60}, {0, 60}}]}], "}"}]}]], "Input",
 CellChangeTimes->{
  3.38338362775*^9, {3.38348726809375*^9, 3.38348728109375*^9}, {
   3.383487363265625*^9, 3.38348736684375*^9}, {3.392312950875*^9, 
   3.392312967484375*^9}, {3.43009681028125*^9, 3.430096845953125*^9}, 
   3.432252888453125*^9}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.432252886828125*^9, 3.432252886859375*^9}}],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"Button", "[", 
   RowBox[{"\"\<Toss the coin\>\"", ",", 
    RowBox[{"Print", "[", 
     RowBox[{"coins", "[", 
      RowBox[{"[", 
       RowBox[{"RandomChoice", "[", 
        RowBox[{"{", 
         RowBox[{"1", ",", "2"}], "}"}], "]"}], "]"}], "]"}], "]"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.392312989*^9, 3.39231305575*^9}, {3.392313130140625*^9, 
   3.392313159359375*^9}, 3.3923132038125*^9, {3.392313253578125*^9, 
   3.392313254921875*^9}, 3.4300968504375*^9}],

Cell[BoxData[
 RowBox[{"t", "=", 
  RowBox[{"Apply", "[", 
   RowBox[{"Plus", ",", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"coins", "-", "4"}], ")"}], "2"]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.392314205390625*^9, 3.39231423665625*^9}, {
   3.39231428925*^9, 3.392314289734375*^9}, 3.392314432125*^9, {
   3.43009685675*^9, 3.43009685784375*^9}}],

Cell[BoxData[
 RowBox[{"t", "=", 
  RowBox[{"Expand", "[", "%", "]"}]}]], "Input",
 CellChangeTimes->{{3.392314239875*^9, 3.392314242390625*^9}, {
  3.3923142921875*^9, 3.392314292640625*^9}}],

Cell[BoxData[
 RowBox[{"s", "=", 
  RowBox[{"Apply", "[", 
   RowBox[{"Plus", ",", 
    SuperscriptBox["coins", "2"]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.392314310625*^9, 3.39231437815625*^9}, {
   3.392314415828125*^9, 3.392314421296875*^9}, 3.43009686396875*^9}],

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"t", "\[Equal]", "0"}], ",", 
     RowBox[{"s", "\[Equal]", "1"}]}], "}"}], ",", "coins"}], "]"}]], "Input",\

 CellChangeTimes->{{3.392314246890625*^9, 3.392314294953125*^9}, {
   3.39231433025*^9, 3.39231438334375*^9}, 3.43009686690625*^9}],

Cell[BoxData[
 RowBox[{"Dynamic", "[", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Cos", "[", "x", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
    RowBox[{"ImagePadding", "\[Rule]", "1"}], ",", 
    RowBox[{"Axes", "\[Rule]", "assi"}], ",", 
    RowBox[{"Epilog", "\[Rule]", 
     RowBox[{"Inset", "[", 
      RowBox[{
       RowBox[{"Panel", "[", 
        RowBox[{"Column", "[", 
         RowBox[{"{", 
          RowBox[{"\"\<Draw axes\>\"", ",", 
           RowBox[{"Checkbox", "[", 
            RowBox[{"Dynamic", "[", "assi", "]"}], "]"}]}], "}"}], "]"}], 
        "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"1.5", ",", ".8"}], "}"}]}], "]"}]}]}], "]"}], "]"}]], "Input",\

 CellChangeTimes->{{3.42034851759375*^9, 3.42034868175*^9}, {
  3.4300994751875*^9, 3.430099489796875*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Instantly dynamic", "Section",
 CellChangeTimes->{{3.3672296303171997`*^9, 3.367229632957602*^9}, {
  3.367230067727517*^9, 3.3672300741180606`*^9}, {3.3672306157231307`*^9, 
  3.367230620066882*^9}, {3.383401090625*^9, 3.383401108515625*^9}, {
  3.383401212015625*^9, 3.3834012221875*^9}}],

Cell[CellGroupData[{

Cell["Interact with anything that makes sense", "Subsection",
 CellChangeTimes->{{3.367230636941882*^9, 3.367230646066882*^9}, {
  3.367316378133941*^9, 3.367316392087157*^9}, {3.383401236234375*^9, 
  3.38340125384375*^9}, {3.383469370484375*^9, 3.38346938871875*^9}}],

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"Sort", "[", 
    RowBox[{"RandomReal", "[", 
     RowBox[{
      RowBox[{"StudentTDistribution", "[", "5", "]"}], ",", 
      RowBox[{"{", "100", "}"}]}], "]"}], "]"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "4"}], ",", "4"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.383477024984375*^9, 3.3834770261875*^9}, {
  3.3923128384375*^9, 3.392312907796875*^9}}],

Cell["Adding interaction:", "Text",
 CellChangeTimes->{{3.392312916140625*^9, 3.392312938265625*^9}}],

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Sort", "[", 
      RowBox[{"RandomReal", "[", 
       RowBox[{
        RowBox[{"StudentTDistribution", "[", "5", "]"}], ",", 
        RowBox[{"{", "points", "}"}]}], "]"}], "]"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "4"}], ",", "4"}], "}"}]}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"points", ",", "100", ",", "1000", ",", "10"}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.4300966746875*^9, 3.43009669596875*^9}}],

Cell["A random walk", "Text",
 CellChangeTimes->{{3.430096785171875*^9, 3.430096788140625*^9}}],

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{"Accumulate", "[", 
   RowBox[{"RandomReal", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", "100"}], "]"}], "]"}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"ListLinePlot", "[", 
    RowBox[{"Accumulate", "[", 
     RowBox[{"RandomReal", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", "points"}], "]"}], "]"}],
     "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"points", ",", "100", ",", "1000", ",", "10"}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.4300951346875*^9, 3.430095151953125*^9}, {
  3.43009523353125*^9, 3.4300952355625*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Fast response is needed for instant interactivity", "Section",
 CellChangeTimes->{{3.38340285565625*^9, 3.3834028660625*^9}}],

Cell[CellGroupData[{

Cell["Real-time lighting changes", "Subsubsection",
 CellChangeTimes->{{3.3834683194375*^9, 3.38346832928125*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"myspheres", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"RGBColor", "[", 
        RowBox[{
         RowBox[{"Random", "[", "]"}], ",", 
         RowBox[{"Random", "[", "]"}], ",", 
         RowBox[{"Random", "[", "]"}]}], "]"}], ",", 
       RowBox[{"Specularity", "[", 
        RowBox[{"White", ",", "128"}], "]"}], ",", 
       RowBox[{"Sphere", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", "1"}], "]"}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "10", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "0", ",", "10", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", "0", ",", "10", ",", "4"}], "}"}]}], "]"}]}], ";", 
  RowBox[{"Manipulate", "[", 
   RowBox[{
    RowBox[{"Graphics3D", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"White", ",", 
        RowBox[{"PointSize", "[", ".02", "]"}], ",", 
        RowBox[{"Point", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"t", "[", 
            RowBox[{"[", "1", "]"}], "]"}], ",", 
           RowBox[{"t", "[", 
            RowBox[{"[", "2", "]"}], "]"}], ",", "5"}], "}"}], "]"}], ",", 
        "myspheres"}], "}"}], ",", 
      RowBox[{"Background", "\[Rule]", "Black"}], ",", 
      RowBox[{"Boxed", "\[Rule]", "False"}], ",", 
      RowBox[{"Lighting", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"RGBColor", "[", 
          RowBox[{".3", ",", ".3", ",", ".3"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"White", ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"t", "[", 
                  RowBox[{"[", "1", "]"}], "]"}], ",", 
                 RowBox[{"t", "[", 
                  RowBox[{"[", "2", "]"}], "]"}], ",", "5"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", "2"}],
             "}"}]}], "}"}]}], "}"}]}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "10"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "10"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "10"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "15"}], ",", 
        RowBox[{"-", "15"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"20", ",", "20"}], "}"}]}], "}"}], ",", 
    RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.3673114186938114`*^9, 3.367311580228163*^9}, {
   3.367311612822194*^9, 3.3673116195566125`*^9}, 3.367325457832678*^9, {
   3.3675705465439672`*^9, 3.3675705510608063`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Draft quality for expansive calculations", "Subsubsection",
 CellChangeTimes->{{3.3834694554375*^9, 3.383469464078125*^9}}],

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"fn", "[", 
    RowBox[{
     RowBox[{"Re", "[", 
      RowBox[{"Zeta", "[", 
       RowBox[{"x", "+", 
        RowBox[{"I", " ", "y"}]}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "t"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "6"}], ",", "6"}], "}"}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"fn", ",", 
     RowBox[{"{", 
      RowBox[{"ContourPlot", ",", "Plot3D"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "1", ",", "20"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.38340298675*^9, 3.3834030665*^9}, {3.38346731196875*^9, 
  3.383467312265625*^9}, {3.383467349796875*^9, 3.38346737053125*^9}, {
  3.383467402796875*^9, 3.383467450328125*^9}, {3.383467563015625*^9, 
  3.383467601765625*^9}, {3.38346763634375*^9, 3.38346771*^9}, {
  3.3834677855625*^9, 3.38346786184375*^9}, {3.383477807125*^9, 
  3.38347780971875*^9}, {3.392313541953125*^9, 3.392313545328125*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Integrated data sources", "Section",
 CellChangeTimes->{{3.367230636941882*^9, 3.367230646066882*^9}, {
  3.367316378133941*^9, 3.367316392087157*^9}, {3.383401236234375*^9, 
  3.38340125384375*^9}, {3.383401496*^9, 3.3834015028125*^9}, {
  3.383401544796875*^9, 3.38340156525*^9}, {3.383469673015625*^9, 
  3.383469679203125*^9}, {3.430097465265625*^9, 3.430097470921875*^9}}],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " gives seamless immediate access to an ever-growing library of carefully \
curated and continually updated data maintained by Wolfram \
Research\[LongDash]all with a unified interface allowing complete \
interoperability and tight integration into ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " and its computational and data presentation capabilities. "
}], "Text",
 CellChangeTimes->{{3.404226709609375*^9, 3.40422671159375*^9}, {
  3.43009748396875*^9, 3.4300975038125*^9}}],

Cell[BoxData[
 RowBox[{"Column", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Tooltip", "[", 
     RowBox[{
      RowBox[{"CountryData", "[", 
       RowBox[{"\"\<Slovakia\>\"", ",", "\"\<Flag\>\""}], "]"}], ",", 
      "\"\<Slovakia\>\""}], "]"}], ",", 
    RowBox[{"Tooltip", "[", 
     RowBox[{
      RowBox[{"CountryData", "[", 
       RowBox[{"\"\<CzechRepublic\>\"", ",", "\"\<Flag\>\""}], "]"}], ",", 
      "\"\<Czech Republic\>\""}], "]"}], ",", " ", 
    RowBox[{"Tooltip", "[", 
     RowBox[{
      RowBox[{"CountryData", "[", 
       RowBox[{"\"\<Italy\>\"", ",", "\"\<Flag\>\""}], "]"}], ",", 
      "\"\<Italy\>\""}], "]"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.430097263078125*^9, 3.430097273890625*^9}, {
  3.430097391546875*^9, 3.430097405734375*^9}, {3.430097511796875*^9, 
  3.4300975641875*^9}}],

Cell[BoxData[
 RowBox[{"GraphPlot", "[", 
  RowBox[{
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Thread", "[", 
       RowBox[{"#", "->", 
        RowBox[{"CountryData", "[", 
         RowBox[{"#", ",", "\"\<BorderingCountries\>\""}], "]"}]}], "]"}], 
      "&"}], "/@", 
     RowBox[{"CountryData", "[", "\"\<SouthAmerica\>\"", "]"}]}], "]"}], ",", 
   
   RowBox[{"VertexLabeling", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.382464793484375*^9, 3.382464796125*^9}, {
   3.382464847234375*^9, 3.3824648475625*^9}, 3.382464894203125*^9, {
   3.389516011828125*^9, 3.38951606503125*^9}, {3.389516295734375*^9, 
   3.389516308625*^9}, {3.404275417515625*^9, 3.40427541828125*^9}, {
   3.404275523484375*^9, 3.404275569234375*^9}, {3.4300975786875*^9, 
   3.430097592453125*^9}}],

Cell[BoxData[
 RowBox[{"Graphics", "[", 
  RowBox[{"{", 
   RowBox[{"Gray", ",", 
    RowBox[{
     RowBox[{
      RowBox[{"CountryData", "[", 
       RowBox[{"#", ",", "\"\<SchematicPolygon\>\""}], "]"}], "&"}], "/@", 
     RowBox[{"CountryData", "[", "\"\<Europe\>\"", "]"}]}], ",", "Thick", ",",
     "Red", ",", 
    RowBox[{"Line", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"#", "[", 
        RowBox[{"[", 
         RowBox[{"Last", "[", 
          RowBox[{"FindShortestTour", "[", "#", "]"}], "]"}], "]"}], "]"}], 
       "&"}], "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Reverse", "[", 
         RowBox[{"CountryData", "[", 
          RowBox[{"#", ",", "\"\<CenterCoordinates\>\""}], "]"}], "]"}], 
        "&"}], "/@", 
       RowBox[{"CountryData", "[", "\"\<Europe\>\"", "]"}]}], "]"}], "]"}]}], 
   "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.389516357328125*^9, 3.38951638990625*^9}, {
  3.38951644196875*^9, 3.389516448984375*^9}}],

Cell[BoxData[
 RowBox[{"Button", "[", 
  RowBox[{"\"\<Country data notebook\>\"", ",", 
   RowBox[{"CreateDocument", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"CellGroup", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"TextCell", "[", 
            RowBox[{
             RowBox[{"CountryData", "[", 
              RowBox[{"#", ",", "\"\<Name\>\""}], "]"}], ",", 
             "\"\<Section\>\""}], "]"}], ",", 
           RowBox[{"ExpressionCell", "[", 
            RowBox[{
             RowBox[{"GraphicsRow", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"CountryData", "[", 
                  RowBox[{"#", ",", "\"\<Shape\>\""}], "]"}], ",", 
                 RowBox[{"Quiet", "[", 
                  RowBox[{"DateListPlot", "[", 
                   RowBox[{"CountryData", "[", 
                    RowBox[{"#", ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", "\"\<Population\>\"", "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"1970", ",", "2005"}], "}"}]}], "}"}]}], "]"}], 
                   "]"}], "]"}]}], "}"}], ",", 
               RowBox[{"Frame", "\[Rule]", "All"}], ",", 
               RowBox[{"ImageSize", "->", "450"}]}], "]"}], ",", 
             "\"\<Output\>\""}], "]"}]}], "}"}], ",", "Closed"}], "]"}], 
       "&"}], "/@", 
      RowBox[{"CountryData", "[", "\"\<Europe\>\"", "]"}]}], ",", 
     RowBox[{
     "StyleDefinitions", "\[Rule]", "\"\<Creative/NaturalColor.nb\>\""}]}], 
    "]"}], ",", 
   RowBox[{"Method", "\[Rule]", "\"\<Queued\>\""}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Graphics", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Tooltip", "[", 
      RowBox[{
       RowBox[{"Inset", "[", 
        RowBox[{
         RowBox[{"CountryData", "[", 
          RowBox[{"#", ",", "\"\<Flag\>\""}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Log", "[", 
            RowBox[{"10", ",", 
             RowBox[{"CountryData", "[", 
              RowBox[{"#", ",", "\"\<Population\>\""}], "]"}]}], "]"}], ",", 
           RowBox[{"Log", "[", 
            RowBox[{"10", ",", 
             RowBox[{"CountryData", "[", 
              RowBox[{"#", ",", "\"\<GDP\>\""}], "]"}]}], "]"}]}], "}"}], ",",
          "Center", ",", "0.2"}], "]"}], ",", "#"}], "]"}], "&"}], "/@", 
    RowBox[{"DeleteCases", "[", 
     RowBox[{
      RowBox[{"CountryData", "[", "\"\<Europe\>\"", "]"}], ",", 
      RowBox[{"\"\<VaticanCity\>\"", "|", "\"\<Svalbard\>\""}]}], "]"}]}], 
   ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"PlotRangePadding", "\[Rule]", ".2"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Style", "[", 
       RowBox[{"\"\<Population\>\"", ",", "20"}], "]"}], ",", 
      RowBox[{"Style", "[", 
       RowBox[{"\"\<GDP\>\"", ",", "20"}], "]"}]}], "}"}]}]}], "]"}]], "Input",\

 CellChangeTimes->{
  3.3830550726748734`*^9, {3.383566321578125*^9, 3.38356634065625*^9}, {
   3.383566551640625*^9, 3.3835665815*^9}, {3.38356673875*^9, 
   3.383566784875*^9}, {3.38356699215625*^9, 3.3835669930625*^9}, {
   3.3835670835*^9, 3.383567098203125*^9}, {3.43009704625*^9, 
   3.430097075875*^9}, {3.430097183109375*^9, 3.4300971866875*^9}, {
   3.4300972235625*^9, 3.43009722809375*^9}},
 CellID->547439507],

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "Select", " ", "the", " ", "subset", " ", "of", " ", "the", " ", "data", 
    " ", "according", " ", "to", " ", "the", " ", "checkboxes", " ", "set", 
    " ", "by", " ", "the", " ", "user"}], "*)"}], 
  RowBox[{
   RowBox[{
    RowBox[{"pms", "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{"showconservative", ",", "#", ",", 
               RowBox[{"DeleteCases", "[", 
                RowBox[{"#", ",", 
                 RowBox[{"{", 
                  RowBox[{"___", ",", "\"\<Conservative\>\""}], "}"}]}], 
                "]"}]}], "]"}], "&"}], "@", 
            RowBox[{"If", "[", 
             RowBox[{"showlabour", ",", "#", ",", 
              RowBox[{"DeleteCases", "[", 
               RowBox[{"#", ",", 
                RowBox[{"{", 
                 RowBox[{"___", ",", "\"\<Labour\>\""}], "}"}]}], "]"}]}], 
             "]"}]}], "&"}], "@", 
          RowBox[{"If", "[", 
           RowBox[{"shownationallabour", ",", "#", ",", 
            RowBox[{"DeleteCases", "[", 
             RowBox[{"#", ",", 
              RowBox[{"{", 
               RowBox[{"___", ",", "\"\<National Labour\>\""}], "}"}]}], 
             "]"}]}], "]"}]}], "&"}], "@", 
        RowBox[{"If", "[", 
         RowBox[{"showliberal", ",", "#", ",", 
          RowBox[{"DeleteCases", "[", 
           RowBox[{"#", ",", 
            RowBox[{"{", 
             RowBox[{"___", ",", "\"\<Liberal\>\""}], "}"}]}], "]"}]}], 
         "]"}]}], "&"}], "@", "PrimeMinisterData"}]}], ";", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{"Create", " ", "the", " ", "whole", " ", "graphic"}], "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{"Deploy", "@", 
     RowBox[{"Graphics", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"PrimeMinisterGraphic", "[", 
          RowBox[{"pms", ",", "i", ",", 
           RowBox[{"If", "[", 
            RowBox[{"stack", ",", "i", ",", "1"}], "]"}], ",", "stack", ",", 
           "True"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{
            RowBox[{"Length", "[", "pms", "]"}], "-", "1"}]}], "}"}]}], "]"}],
        ",", 
       RowBox[{"AspectRatio", "\[Rule]", "0.7"}], ",", 
       RowBox[{"Axes", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"True", ",", "False"}], "}"}]}], ",", 
       RowBox[{"FrameTicks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "1900"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"25", ",", "1925"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"50", ",", "1950"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"75", ",", "1975"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"100", ",", "2000"}], "}"}]}], "}"}], ",", "None"}], 
         "}"}]}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"Axes", "\[Rule]", "False"}], ",", 
       RowBox[{"GridLines", "\[Rule]", "None"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"If", "[", 
         RowBox[{"stack", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "120"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.5", ",", 
              RowBox[{
               RowBox[{"Length", "[", "pms", "]"}], "+", "0.5"}]}], "}"}]}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "120"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"1", ",", "2"}], "}"}]}], "}"}]}], "]"}]}], ",", 
       RowBox[{"AxesOrigin", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0"}], "}"}]}], ",", 
       RowBox[{"ImageSize", "\[Rule]", "400"}]}], "]"}]}]}], ",", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Interface", " ", "specification"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"stack", ",", "True", ",", "\"\<show names\>\""}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"True", ",", "False"}], "}"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "showconservative", ",", "True", ",", "\"\<Conservative Party\>\""}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"True", ",", "False"}], "}"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"showlabour", ",", "True", ",", "\"\<Labour Party\>\""}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{"True", ",", "False"}], "}"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"showliberal", ",", "True", ",", "\"\<Liberal Party\>\""}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"True", ",", "False"}], "}"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "shownationallabour", ",", "True", ",", 
       "\"\<National Labour Party\>\""}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"True", ",", "False"}], "}"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Initialization", "\[RuleDelayed]", 
    RowBox[{"(", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"DateToValue", "[", 
        RowBox[{"{", 
         RowBox[{"m_", ",", "yr_"}], "}"}], "]"}], ":=", 
       RowBox[{
        RowBox[{"m", "/", "12"}], "+", "yr", "-", "1900"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
       "Create", " ", "one", " ", "line", " ", "of", " ", "the", " ", 
        "graphic"}], "*)"}], "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"PrimeMinisterGraphic", "[", 
        RowBox[{
        "pmdata_", ",", "pm_", ",", "pos_", ",", "txt_", ",", "tooltip_"}], 
        "]"}], ":=", 
       RowBox[{
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{"tooltip", ",", 
           RowBox[{"Tooltip", "[", 
            RowBox[{"#", ",", 
             RowBox[{"If", "[", 
              RowBox[{"txt", ",", 
               RowBox[{"pmdata", "[", 
                RowBox[{"[", 
                 RowBox[{"pm", ",", "1"}], "]"}], "]"}], ",", 
               RowBox[{"Column", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"pmdata", "[", 
                    RowBox[{"[", 
                    RowBox[{"pm", ",", "4"}], "]"}], "]"}], ",", 
                   RowBox[{"Rasterize", "[", 
                    RowBox[{"pmdata", "[", 
                    RowBox[{"[", 
                    RowBox[{"pm", ",", "1"}], "]"}], "]"}], "]"}]}], "}"}], 
                 ",", "Center"}], "]"}]}], "]"}]}], "]"}], ",", "#"}], "]"}], 
         "&"}], "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Switch", "[", 
           RowBox[{
            RowBox[{"pmdata", "[", 
             RowBox[{"[", 
              RowBox[{"pm", ",", "5"}], "]"}], "]"}], ",", 
            "\"\<Conservative\>\"", ",", "Blue", ",", "\"\<Labour\>\"", ",", 
            "Red", ",", "\"\<Liberal\>\"", ",", "Yellow", ",", 
            "\"\<National Labour\>\"", ",", "Orange"}], "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"Polygon", "[", 
           RowBox[{"{", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"DateToValue", "[", 
                RowBox[{"pmdata", "[", 
                 RowBox[{"[", 
                  RowBox[{"pm", ",", "2"}], "]"}], "]"}], "]"}], ",", "pos"}],
               "}"}], ",", "\[IndentingNewLine]", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"DateToValue", "[", 
                RowBox[{"pmdata", "[", 
                 RowBox[{"[", 
                  RowBox[{"pm", ",", "3"}], "]"}], "]"}], "]"}], ",", "pos"}],
               "}"}], ",", "\[IndentingNewLine]", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"DateToValue", "[", 
                RowBox[{"pmdata", "[", 
                 RowBox[{"[", 
                  RowBox[{"pm", ",", "3"}], "]"}], "]"}], "]"}], ",", 
               RowBox[{"pos", "+", "1"}]}], "}"}], ",", "\[IndentingNewLine]",
              
             RowBox[{"{", 
              RowBox[{
               RowBox[{"DateToValue", "[", 
                RowBox[{"pmdata", "[", 
                 RowBox[{"[", 
                  RowBox[{"pm", ",", "2"}], "]"}], "]"}], "]"}], ",", 
               RowBox[{"pos", "+", "1"}]}], "}"}], ",", "\[IndentingNewLine]",
              
             RowBox[{"{", 
              RowBox[{
               RowBox[{"DateToValue", "[", 
                RowBox[{"pmdata", "[", 
                 RowBox[{"[", 
                  RowBox[{"pm", ",", "2"}], "]"}], "]"}], "]"}], ",", "pos"}],
               "}"}]}], "}"}], "]"}], ",", "Black", ",", 
          RowBox[{"If", "[", 
           RowBox[{"txt", ",", 
            RowBox[{"Text", "[", 
             RowBox[{
              RowBox[{"\"\< \>\"", "<>", 
               RowBox[{"pmdata", "[", 
                RowBox[{"[", 
                 RowBox[{"pm", ",", "4"}], "]"}], "]"}]}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"DateToValue", "[", 
                 RowBox[{"pmdata", "[", 
                  RowBox[{"[", 
                   RowBox[{"pm", ",", "3"}], "]"}], "]"}], "]"}], ",", 
                RowBox[{"pos", "+", "0.5"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], ",", 
            RowBox[{"{", "}"}]}], "]"}]}], "}"}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
       "The", " ", "historical", " ", "data", " ", "on", " ", "all", " ", 
        "the", " ", "PMs"}], "*)"}], "\[IndentingNewLine]", 
      RowBox[{"PrimeMinisterData", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           GraphicsBox[RasterBox[CompressedData["
1:eJx112fPV8UWBXCS+wVMUIqISJN2lSrSRZDepCNYKQpGRKRKL0HFxEoRQm+J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             "], {{0, 0}, {40., 47.}}, {0, 255},
             ColorFunction->RGBColor],
            ImageSize->40,
            PlotRange->{{0, 40.}, {0, 47.}}], ",", 
           RowBox[{"{", 
            RowBox[{"7", ",", "1902"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"12", ",", "1905"}], "}"}], ",", "\"\<Arthur Balfour\>\"",
            ",", "\"\<Conservative\>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           GraphicsBox[RasterBox[CompressedData["
1:eJxt2FevVscVBmCk/JLc5SZ/gEuEAIEQKBTZYJrpmGaqKaaG3pvpptl0gwEb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             "], {{0, 0}, {40., 45.}}, {0, 255},
             ColorFunction->RGBColor],
            ImageSize->40,
            PlotRange->{{0, 40.}, {0, 45.}}], ",", 
           RowBox[{"{", 
            RowBox[{"12", ",", "1905"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"4", ",", "1908"}], "}"}], ",", 
           "\"\<Sir Henry Campbell-Bannerman\>\"", ",", "\"\<Liberal\>\""}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           GraphicsBox[RasterBox[CompressedData["
1:eJxN2GVzFkkUBWCq9hMeWFg8OEGDu7sFd4cgwXVxdwkW3LUKfgNf+WX7bJ/K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             "], {{0, 0}, {40., 55.}}, {0, 255},
             ColorFunction->RGBColor],
            ImageSize->40,
            PlotRange->{{0, 40.}, {0, 55.}}], ",", 
           RowBox[{"{", 
            RowBox[{"4", ",", "1908"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"12", ",", "1916"}], "}"}], ",", "\"\<H. H. Asqith\>\"", 
           ",", "\"\<Liberal\>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           GraphicsBox[RasterBox[CompressedData["
1:eJyN2fvzj2UaB3Az+1OoFcturF0itA5rWYfkUCo55ZxTNodFUjlVqEipcQjF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             "], {{0, 0}, {40., 63.}}, {0, 255},
             ColorFunction->RGBColor],
            ImageSize->40,
            PlotRange->{{0, 40.}, {0, 63.}}], ",", 
           RowBox[{"{", 
            RowBox[{"12", ",", "1916"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"10", ",", "1922"}], "}"}], ",", 
           "\"\<David Lloyd George\>\"", ",", "\"\<Liberal\>\""}], "}"}], ",",
          
         RowBox[{"{", 
          RowBox[{
           GraphicsBox[RasterBox[CompressedData["
1:eJxt2eevVlUWBnCT+S+MX+bbCFfAgaHcCyIw2Csogl0sYEFU7GLD3iCxxoYV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             "], {{0, 0}, {40., 61.}}, {0, 255},
             ColorFunction->RGBColor],
            ImageSize->40,
            PlotRange->{{0, 40.}, {0, 61.}}], ",", 
           RowBox[{"{", 
            RowBox[{"10", ",", "1922"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"5", ",", "1923"}], "}"}], ",", 
           "\"\<Andrew Bonar Law\>\"", ",", "\"\<Conservative\>\""}], "}"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{
           GraphicsBox[RasterBox[CompressedData["
1:eJw9V1eMXOd5NZDHJI7sOBIkSiLFuruzbXZ6r3fu9F5unTu9977T2+5s5xYu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             "], {{0, 0}, {40., 55.}}, {0, 255},
             ColorFunction->RGBColor],
            ImageSize->40,
            PlotRange->{{0, 40.}, {0, 55.}}], ",", 
           RowBox[{"{", 
            RowBox[{"5", ",", "1923"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "1924"}], "}"}], ",", "\"\<Stanley Baldwin\>\"",
            ",", "\"\<Conservative\>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           GraphicsBox[RasterBox[CompressedData["
1:eJyFWAdUVOe6/U+ZPnPm1DnTOzAMXVBEiopgwxYRFbGABUERrCgKiCgoiiKK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             "], {{0, 0}, {40., 56.}}, {0, 255},
             ColorFunction->RGBColor],
            ImageSize->40,
            PlotRange->{{0, 40.}, {0, 56.}}], ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "1924"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"10", ",", "1924"}], "}"}], ",", 
           "\"\<Ramsay MacDonald\>\"", ",", "\"\<Labour\>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           GraphicsBox[RasterBox[CompressedData["
1:eJw9V1eMXOd5NZDHJI7sOBIkSiLFuruzbXZ6r3fu9F5unTu9977T2+5s5xYu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             "], {{0, 0}, {40., 55.}}, {0, 255},
             ColorFunction->RGBColor],
            ImageSize->40,
            PlotRange->{{0, 40.}, {0, 55.}}], ",", 
           RowBox[{"{", 
            RowBox[{"10", ",", "1924"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"6", ",", "1929"}], "}"}], ",", "\"\<Stanley Baldwin\>\"",
            ",", "\"\<Conservative\>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           GraphicsBox[RasterBox[CompressedData["
1:eJyFWAdUVOe6/U+ZPnPm1DnTOzAMXVBEiopgwxYRFbGABUERrCgKiCgoiiKK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             "], {{0, 0}, {40., 56.}}, {0, 255},
             ColorFunction->RGBColor],
            ImageSize->40,
            PlotRange->{{0, 40.}, {0, 56.}}], ",", 
           RowBox[{"{", 
            RowBox[{"6", ",", "1929"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"8", ",", "1931"}], "}"}], ",", 
           "\"\<Ramsay MacDonald\>\"", ",", "\"\<Labour\>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           GraphicsBox[RasterBox[CompressedData["
1:eJyFWAdUVOe6/U+ZPnPm1DnTOzAMXVBEiopgwxYRFbGABUERrCgKiCgoiiKK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             "], {{0, 0}, {40., 56.}}, {0, 255},
             ColorFunction->RGBColor],
            ImageSize->40,
            PlotRange->{{0, 40.}, {0, 56.}}], ",", 
           RowBox[{"{", 
            RowBox[{"8", ",", "1931"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"6", ",", "1935"}], "}"}], ",", 
           "\"\<Ramsay MacDonald\>\"", ",", "\"\<National Labour\>\""}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           GraphicsBox[RasterBox[CompressedData["
1:eJw9V1eMXOd5NZDHJI7sOBIkSiLFuruzbXZ6r3fu9F5unTu9977T2+5s5xYu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             "], {{0, 0}, {40., 55.}}, {0, 255},
             ColorFunction->RGBColor],
            ImageSize->40,
            PlotRange->{{0, 40.}, {0, 55.}}], ",", 
           RowBox[{"{", 
            RowBox[{"6", ",", "1935"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"5", ",", "1937"}], "}"}], ",", "\"\<Stanley Baldwin\>\"",
            ",", "\"\<Conservative\>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           GraphicsBox[RasterBox[CompressedData["
1:eJyd2HfMVlUSBnCT/c+CsuACLiuiSHVXQZr0IgiCoCBRkSYqUpQiYiD0EpCg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             "], {{0, 0}, {40., 52.}}, {0, 255},
             ColorFunction->RGBColor],
            ImageSize->40,
            PlotRange->{{0, 40.}, {0, 52.}}], ",", 
           RowBox[{"{", 
            RowBox[{"5", ",", "1937"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"5", ",", "1940"}], "}"}], ",", 
           "\"\<Neville Chamberlain\>\"", ",", "\"\<Conservative\>\""}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           GraphicsBox[RasterBox[CompressedData["
1:eJx12Pnzl+MaB/Bmzm+0aU+L6qS0KJFIqyXF2KJ9cpAtpXIktNmGIirKWipa
ZCkyZV/GMDR+CDOJw4jG9Js/4pzXed7zuefx/XLNfJ65n/tz3/f72q/rfnrP
WXT1nH+0aNFimN9pfv8fv//++w8//PCiRYsWLlw4f/78BQsW3F5R8wGaX9Ht
f0ULKmryWqeFDbrzzjsfeuihtWvXjh8/vm/fvv379+/du/epFfXp08er5z8b
1LciC3r16pWZ/Nu3QXZ51mfq5F8HnlbR6aefPnz48LfffvuOO+7IgT179hw0
aNDAgQMNvJ5yyindu3fv0aOHV2MzxmZ6VtSjIvMZl0ETymJ7QWAVDwMGDCDp
66+/vnPnzssuu8xfgwcPnjBhwplnntm5c+euXbsG5eSKwkC3bt3Me2beIGvy
b8bd/orCLd6gE3ncuHHPPPPMSy+99MQTT8yaNQv60KFDzz77bCJ36NDBSihd
unSpY4Ulg64VFbi/w82ywjnp+vXrN3bs2BdffJGJX3vttR07dixbtgwzbHTx
xReDhtipU6cuFf0dbvcGFdCT/0xdGxTlkIWtx4wZ8/zzz4N+9dVXX375ZQxM
nDgR1ogRIwhu0LmiiBzccBJZwlLYKIjWF7guNSp2YWK4ZFy3bt3evXvhbtiw
4d577+VslGwloI4dO9ZFRp0qCpbJwlVdxiwLbucGFZGDu2bNGmI+++yzmzZt
gvv4449fcskl1lA4N8NApwYVcerMFJGLDxhksZVFY81xFy9ePGfOHIaePHny
o48+On369AkVXX755QKtTZs29gLCQIRqgluUmWMtsLJt27aWeWbZX+Kec845
bN2+fXtbli9fvm3btlWrVhFfXnJCx4r8265du9goIuRZJM04dhEOl156Kfcw
06pVq5NOOimLm+CeccYZ8VsLBNfUqVNvuukmMYUfMxCht68oh4eTfhUVrwsD
eBP7XOWPP/44dOjQK6+8cuONN2IgnhC2yQh39OjRVsYi0U+riqg3oI4KaGQP
5y1bthTpUUiRN4yx1H9r9Ntvv23ZsgWE0+IeUgfcUaNG1XFDQSliNsE1wNiU
KVPIxfcyiayhRgLKA5999tkbb7zxwAMPLFmy5IorrpAeLUskNsGNyaLDJohN
cD0pQay9++67t9566wknnJC91JiN0J1JNMuIWRwyuNFzHbd4S4QqGq7jxpqs
YCz6PvjgA0m++HzQLY4vRY3FsiWXBnfYsGFZELi4vb1tKyquFYpCrIRl7yef
fPLII4/Yno15FvdOFJdsZiaFKbhDhgwx066iZIkkuiRbKKyZUMqxkdqr8Qsv
vHD8+PHZs2fba0tcqx5f9Sxa6oL8DJfdRZO8IVdcdNFFkyZNuuqqq8TRtdde
e80111x44YXqdevWrXNmyQPktX3jxo379++//vrri7qKsM0zZ4pCwZWQtSW3
3HLL3Llzb7vttvQhJuVt82ZuuOEGDgk6Thup6R//yih1pWIGzjiDUrVLQQxu
Whq4OivND1Dpgn+mgzID/a677rr77rsNzj///JI6iksn/0SxUaAFzXXbvO5L
OPKGlkPtmzlzJrkkaoIT898VAV1ekRxuWVyreI4nD+GWWiOgciNLJU4LbhBD
TXDlMf/KAEwJ/V8VMe7sijBz8803Y4ataTvBBRQDDpEW/HXWWWc5irruuece
a/wbxAJd77WKnhkoVjNvu1eZGT/nnXcef8OMssj3VCuTwaVqAxA8yr/pAwWy
9ZywFMRQsWxANTPWWElRSQUyz4knnmgMmmPTGzhiTps2LbLTBohkCQsYYuXK
ldzjyiuvxDB+EpvpqdJhFssGuk9FkVe+Sv9GhDYVOdY55557Llnk4asbNGPG
DOUAw2qWFnTPnj3vvPPOxx9/bDBv3jznODwVJyIHNxqOws3AdTh5lUtH4cFk
PU1ZpkSSC5ag5nvYIBrry/lfffXVU089JfO7a6xfv16ntGLFClJQV9Dr2o6t
DYCmb7/gggvwWXwgTUJyoyfnpLqRI0dyZitFkyf3/vDDD9977z11Yfv27Rpg
gUbhytB1112X84lcQjhUMpXeiWWJQyhwlBxJ6dkTYlKisXMshk7zpH766afl
KC23JCm3KHwGBw4coHlJJvcCVq4nW2Q+lwVHQeSuvMj5pIPYuqLU6HJziYG4
K7tws927d3/66acfffSR7lekW8C4OMEPB+B4Tg4uOFjpfuNy5LUg5oObuCjC
wrUramGOXKkGVCSLvvXWW59//vnBgwe//fbbrVu3cvvnnnsOG/fdd5/TZAOl
uVdF/SvCWHCx7ZVxuYESED3HoEAzwEApLtGYAMcwXJc4LvTmm29+/fXXjz32
mNb3iy++cJm9//77uUrEgeJ8PGDVOBUwzDMW55RtLCvyFhO3rFFKpOgmCAcW
tm4xMhXXkkh1+2zNn92z5ElCYc8TDzQphXpNqwnXq8InGcr8yVdFyWnqwMkh
MXc0YEZxdGkFx415LyWLKc5MCQqTsYhLpXOm5OnJ1mRMW5WLAFxuL+Fj3nh0
g7AXHmABjbkxQyeC5csvvzxU0Xfffee5a9cuFZPUTCYJ0G06RgPBElwyEj+g
dCsYZdfFFT355JP4JwVj4Zl7ky64NOxJdp65efPmb7755vvvv/9PRUePHv3x
xx/37dun0SK1fF7yA5Tc35EBBiDG4nBVPWZiFCpSSujcwIJg5RkTk5d1XCWA
wtIV//7777/88otXXi2BuF8I7ZQ/HNJtcAdVBDfl0jzNwF26dCmgcqmkTIqN
I8WsEGN0Z65evfrw4cM//PDDTz/9BPrXX38l8pEjR4jsakNR+dRAq4MbNKSi
4ttCkr8pMayTPjYtRKyZJjbjPGNuSUPGAEpkwh47dsxAEDEQdcneTAwaLojB
fybQxKcKbChw1nO8XB4TxeWmEKlLmfB0INcStowL/eeff6ZkHq4u6Iuk7lJe
URJXMXEcDC7BlTO4ojJ1Kgm5fkMpCg9Bt4v3UqzypzpIF4JXpaAKgiRYCJtn
ca1AewoWgiupfCny5srWHBdWoPMvByCL3kMJePDBB93C1AVh6MzkXowVxSZv
DKyRNeZtF0TkTdXIraFcWMrNN2yk+S+flahUOyR2nBz1OpCL8lsOQxZl3SBm
TW43SB9FXnFkAf3ka0y92S5fJ8qNPoXVMx/QjMHlIuzYBGlwnTlixAgSET+4
UXVcnbz0LFHbnrrZs0Hl41v5RpQWlGP0blDqS3qV5N7oNjS0ooyjdpR6FHnp
qmzv06B8gcz55ftk+XSZ13hO5C2OlJitx28sHq7iALGvRgJueM63zSYfOU9t
Rqlo9EmZTk7IFBSqjqQZU35ejdPkcH643CMZLHuLORIOEaRORTTmY6Pk/7pH
Df8z4Q2EeRlyZEXTp09XTFVhgaCxHF9RxmMrSoUaVZHBmIoyRmnzVEC7jLVM
+QClwMnVaUG9TmyQLkhmlqzcxdya/weQitlv
             "], {{0, 0}, {40., 49.}}, {0, 255},
             ColorFunction->RGBColor],
            ImageSize->40,
            PlotRange->{{0, 40.}, {0, 49.}}], ",", 
           RowBox[{"{", 
            RowBox[{"5", ",", "1940"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"7", ",", "1945"}], "}"}], ",", 
           "\"\<Winston Churchill\>\"", ",", "\"\<Conservative\>\""}], "}"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{
           GraphicsBox[RasterBox[CompressedData["
1:eJx12AnUT+UWBnBDpUgIRShEESlKppSQqcyXUDdCGhAKSSVDhiJTiTI0mGcp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             "], {{0, 0}, {40., 55.}}, {0, 255},
             ColorFunction->RGBColor],
            ImageSize->40,
            PlotRange->{{0, 40.}, {0, 55.}}], ",", 
           RowBox[{"{", 
            RowBox[{"7", ",", "1945"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"10", ",", "1951"}], "}"}], ",", "\"\<Clement Attlee\>\"",
            ",", "\"\<Labour\>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           GraphicsBox[RasterBox[CompressedData["
1:eJx12Pnzl+MaB/Bmzm+0aU+L6qS0KJFIqyXF2KJ9cpAtpXIktNmGIirKWipa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             "], {{0, 0}, {40., 49.}}, {0, 255},
             ColorFunction->RGBColor],
            ImageSize->40,
            PlotRange->{{0, 40.}, {0, 49.}}], ",", 
           RowBox[{"{", 
            RowBox[{"10", ",", "1951"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"5", ",", "1955"}], "}"}], ",", 
           "\"\<Winston Churchill\>\"", ",", "\"\<Conservative\>\""}], "}"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{
           GraphicsBox[RasterBox[CompressedData["
1:eJxt2gnwllPfB3Ae+74vr52X8CJvWaNNheyUSCJEKVIUyZKYkgpF9q1oVVoQ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             "], {{0, 0}, {40., 106.}}, {0, 255},
             ColorFunction->RGBColor],
            ImageSize->40,
            PlotRange->{{0, 40.}, {0, 106.}}], ",", 
           RowBox[{"{", 
            RowBox[{"5", ",", "1955"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "1957"}], "}"}], ",", 
           "\"\<Sir Anthony Eden\>\"", ",", "\"\<Conservative\>\""}], "}"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{
           GraphicsBox[RasterBox[CompressedData["
1:eJxt2PnXj9UaBnBrnb/kpDJmdo6jzCRjkbHMKjNxOGQ40pwhU5FCoZAGmSss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             "], {{0, 0}, {40., 51.}}, {0, 255},
             ColorFunction->RGBColor],
            ImageSize->40,
            PlotRange->{{0, 40.}, {0, 51.}}], ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "1957"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"10", ",", "1963"}], "}"}], ",", 
           "\"\<Harold Macmillan\>\"", ",", "\"\<Conservative\>\""}], "}"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{
           GraphicsBox[RasterBox[CompressedData["
1:eJxtlwdYVNe2x0+ZM72eOdOH6cgA0kVUbEERFERBKVKkBVCkSRHpvcMAQwfp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             "], {{0, 0}, {40., 56.}}, {0, 255},
             ColorFunction->RGBColor],
            ImageSize->40,
            PlotRange->{{0, 40.}, {0, 56.}}], ",", 
           RowBox[{"{", 
            RowBox[{"10", ",", "1963"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"10", ",", "1964"}], "}"}], ",", 
           "\"\<Sir Alec Douglas Home\>\"", ",", "\"\<Conservative\>\""}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           GraphicsBox[RasterBox[CompressedData["
1:eJw9l2dUk+na72dvW3qll0BCEkpCgISE9N57J4QOAiJdRbGhY0HsjqOoOIoi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             "], {{0, 0}, {40., 55.}}, {0, 255},
             ColorFunction->RGBColor],
            ImageSize->40,
            PlotRange->{{0, 40.}, {0, 55.}}], ",", 
           RowBox[{"{", 
            RowBox[{"10", ",", "1964"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"6", ",", "1970"}], "}"}], ",", "\"\<Harold Wilson\>\"", 
           ",", "\"\<Labour\>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           GraphicsBox[RasterBox[CompressedData["
1:eJw9lwdwW2d6riWKXRIpNgBsYAEIEpXovXeCIEiQIAg2gOiVaASIDgIgAPYi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             "], {{0, 0}, {40., 55.}}, {0, 255},
             ColorFunction->RGBColor],
            ImageSize->40,
            PlotRange->{{0, 40.}, {0, 55.}}], ",", 
           RowBox[{"{", 
            RowBox[{"6", ",", "1970"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"3", ",", "1974"}], "}"}], ",", "\"\<Edward Heath\>\"", 
           ",", "\"\<Conservative\>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           GraphicsBox[RasterBox[CompressedData["
1:eJw9l2dUk+na72dvW3qll0BCEkpCgISE9N57J4QOAiJdRbGhY0HsjqOoOIoi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             "], {{0, 0}, {40., 55.}}, {0, 255},
             ColorFunction->RGBColor],
            ImageSize->40,
            PlotRange->{{0, 40.}, {0, 55.}}], ",", 
           RowBox[{"{", 
            RowBox[{"3", ",", "1974"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"4", ",", "1976"}], "}"}], ",", "\"\<Harold Wilson\>\"", 
           ",", "\"\<Labour\>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           GraphicsBox[RasterBox[CompressedData["
1:eJyN2fnXl+MWBvBGjYTScIqkVBoMJScZKhmLIkLDKpI0SGUeiyahKFIyJWOh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             "], {{0, 0}, {40., 58.}}, {0, 255},
             ColorFunction->RGBColor],
            ImageSize->40,
            PlotRange->{{0, 40.}, {0, 58.}}], ",", 
           RowBox[{"{", 
            RowBox[{"4", ",", "1976"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"5", ",", "1979"}], "}"}], ",", "\"\<James Callaghan\>\"",
            ",", "\"\<Labour\>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           GraphicsBox[RasterBox[CompressedData["
1:eJw92EXPFkEWBWCSWbNjRVgwhAUJCyBIIBA0OAR3d3d3d9fB3WVwdxtgIIQA
AUJY8UvmmTrhreTr9Ntddc8950pVf/8cPaP36H9UqVKlnr86/v5/37x581at
WjVp0sSN66hRo65fv/769etHjx49ePDA9dWrV/8t4/379y9fvjxw4MCuXbsO
HTq0adOmlStXTps2bfjw4Vu3brXq3r17d+/evXbt2sWLF0+fPr1+/frFixe7
uXnz5syZM83Zs2fPjBkzQPTt27dTp05wmzVr1rhx47Zt2+7fvx/W/fv3/13G
3r17ody6dYs1FubOnVu/fv1atWo1atRo8uTJ0KdMmdKwYcN69eqNHDly3759
V65cgWL+8ePH4V66dOnMmTOMTJ8+fcmSJeYDHTp06KxZs7p3796uXTuIDRo0
8PDw4cMnTpyI567r1q3j87Fjx+bMmdO+ffuaNWvWrl2bt4MHD+7Xrx8n+bN0
6VJC8WT+/PmrV6/mz7/K2Lx58+3bt588ecJzQMuWLUMEugno9+7du0OHDnDp
vHbt2rNnz27YsAE1lO/cuWMCjkeOHBk4cGC1atVMW7NmDTueMNWnTx8u3bhx
gzVeTZo0adWqVezwwQ0KiD9+/Hjbtm0jRozgBi7CxNSAAQP69+9P6pYtW3IA
nDAxCxprXNDs1auXtzVq1KhatSq5xE5YGSEpaDpT0sMFCxaMHTt23rx548aN
I3vXrl0FFMGDBw+OGTOmZ8+efgLlA5dWrFhhGt06d+5sCSDKMGjCjh07LNm+
fbtVLVq0QJY1oREjipkM7vLlyyTauXOn+6NHj5Ji9uzZ48ePF7suXbp069aN
/nXq1KGGt+fPnz937pyZ9AEkfBMnTpSTPLlehufIitTo0aOln7yFbsKiRYvc
JHAcdi8QV69eJTW+buQPKUhkMg+Fr3r16k2bNoXlLTrMWoXUhQsXtmzZYjKV
EATKK8uBbty4kYzsU+Dhw4dW8dlysUDZHBakq1oDyo5Qnjx50ioKCIeAClDd
unWnTp0KVwUBhcjg8uXLN5axuQz604EpN7izL8rK4fnz50rj2bNn0GU4+6Yx
At1k6Yq1J1QiO+fpw+Fhw4aJqQqVLV7RhFACpwQ8AYGvupN7nGEN5d27d8tq
ZhcuXOhGOUOUIV5JSD/dBNpbNkGLF1BXec5nJYBvjx49UKYS98wHjQVNWJYS
WW648Qo6HwCZzwLZkVVT1LacnpfKOHXqlHtXdihAB87wLV1CRWsjCmTIkCF0
EyMzPUcQ3x1lWM5VpkyAK2rWipqHZOEPRERulsFtT8wkGqaAwiJtSvSt4rDY
qS+NRWVdLINNS+ASEx3546HJFoYFvizz35N4hSyI1BfLbsBZ60phZFmw0M9A
W05GhaagtCY/+UY3TGWR4PJKBbEGN3nOcwFyjy877lFzT/bYd3XPEy4xdacM
TywBbQK12REpNYKUMmTTz7QCNSvbRUHHiDhJm0TBzGQpcdzLZBz5bMLTp0/l
lZ985hWghIA+kYspP0GrBdLp2LKIh+bDXV5GemDIwiWmhXQQAhyRkjOsAeKt
Vzqt58y61+V0IanIJnR5zlVGkkV8VrBc1cEQlBWqRpcDaqOR6kqM5QQOHUBA
LblXhudArRIvN8hiZ5omo0bEiJOA0p+VOcfYMZ8gKXAOi6mgKFhVCZcCQPEN
rsGmyUxB4TBqlrtyA8E3b96w/OLFC5ZVhwBp7yjI0ihMLr5hzTEaSkivJJUM
JDLZTbYj6/YdO3a0JUXkXJUA38xxL1t44gmhOPCfMogvTNo+sozr2PIWKZSh
mw/amYQ1bkgnuGonTZvmmqStU9/muQlCltOFVEHWW/OjKrIc9lO+mUB8yzlM
NFJQz1FBdxKdc2VwgG+mMbu7DOVDRpmMtd2qWxm6qNLIHsRJnsM1RyqSlGiM
oMkxvDBFB33nk5wQeKUv2Wpt4vYCycMrmnNY4OSVqDGVPgOXZToDlZY0ZDZt
kG8WShvzhTgnNHUkXeWh+7dv3ypJm7WZQsAT241jQ6BFkKoyHBcGozMRsh3s
KUNRyy5XoMyalh1QLKSca9zO1ol1DmnOlrqffZkP2QJyoJK07OOYjSN7Fo4o
y2qU089B5CeX4EohOoPwEF/xcqyyKlUM3TWbr7XOUTLZKhlIfGcq8lqebcJI
LpmTXsEmy+mKKRx2uJ1t3So+BFfuSVex4LPyic6K6PPnz+ZISFdr4RJZvBSF
UzTKgGQaZYASkz85C1X6v1U5prrJLobOzjIsUR2CKPSsecIx0n38+PH379/a
phDECGs00bVAE59EcgA6CzqwTDYt7Ro7tXCrjAous1JI3LknS5lVI3BxGVWG
REXEwi9fvuRzwJUFUrAAyHzQdh+FL+IU421SK50h/R+KeAU3G5w5IuJ8onL5
L69IzX+xmzBhAlzEBV3srFJfLEgqcUTKkYaT5mgFcozznAQEAtn01creIWFc
czJPMhNQkhNqaRmkZooDopzTqR2cYzxUStJSDtMTO75pX9zzxF7PWyFjM8JC
DM2kqCGXtPGHZeR0oatUDtVYI0K3tWW4Dy5v3717x5Rp2YJ5aH8hck68QKOh
kW4J61EZ2WtgPS4jD3OGkY20AipkDJIRWSLLYX1JGn/48EFWi2yOTD4bdRgZ
CNQquDy58XcgG9ZhmsgGWifUh/mf/ISLrLYThdHnvwRr06aNDzEB/fHjhw9S
NkXNzdevXyWkKlY7lvjq4TBTlaQCHSCqJqb5qTYVZvaOZFf6mOWizH+VQlK7
np6sz/z8+ZPn2Va4JNbyTXBz8ueeglI1uKRkco2qKZykMWi4nOcwdFkqpqCR
hQsRdNQWRDdKSSHrt75ETCM1l3y15YvG11Dr1q3FnYzgkksIVnArlQVLjCgs
RvJZdJSeRCI1UtIbKc6gT0bcOfnt27dPnz6x6TmRTdPcZLXdwVeJDYLP4RiC
lfLxEFy6Vr6LZZQzNsuyRasUZYgUsE3QxMwEHRFh+vXrl9SiZFKLY1KLMvq2
DV0DsTD1kjqK2jm6ICtJLDRBOKwVF0XqnobiSFLlj6AlnPTQE/ZZ+/Pnz/fv
3/O1ovQ854+giHgaNd0q5Yk1CMWSpCIs3Jw5bVXMSlcZApdxdjAlOAtOejkC
2Th4ItCWSKc0SXxJbab+NmjQIIIjnr4RaLiUsaTSuzjAmoBiB5erGo7tgxGp
lUOgQfb8n8QcLklaoZT8fPZTapmMrCMExRSU5ebrpWlZSaocZkitfLzKnis9
2HFaEBrs8h2xqQzNFuV83nJPoJWYIOohkiH/G0GTVlqlq7fcS6OAwn5aRI6m
CRmHT5chRpRR8mqBbnZqibG1DNCuKItFthVNCW6DBg3krZq1FzikOUuTS3O2
0EzOM0jSJ3+HE2aOaqAhomla+FIPBQ9pK4gsbCkj/2TAVwVJe3GXBgHSzZSM
6GjOGrjIEpnBw2WYnGTOoTr/E8OaeoKLBVxqk5GfntBZ/ZI6oALtxqvUIIex
ZvxEGV4JMeL81OsO/h3JGaxz7DHSh/O5GgVy6gOdfzJgpHjzz4fo7CaHBz7L
CsTz+ckZBOnD1YDmPwn5PMlNZUCx1VLAWrUAl/O8ymeO51zFNyltbCuj8k8Y
0I7TWhzu+ddB4LzdV0bIAiJjel3u85N96f2yDJ7kkxwj+qdFBxEcLnvLQM01
H4ARDS4KrOVACDGkjpVxvIy8dRNqVKKYjQxlLNIWXIU+u3/UI2/+KRFG4RI6
SZ7Y52rSOHHPPz1ypoWVm8Qxpf2+jP8BndDgwQ==
             "], {{0, 0}, {40., 47.}}, {0, 255},
             ColorFunction->RGBColor],
            ImageSize->40,
            PlotRange->{{0, 40.}, {0, 47.}}], ",", 
           RowBox[{"{", 
            RowBox[{"5", ",", "1979"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"10", ",", "1990"}], "}"}], ",", 
           "\"\<Margaret Thatcher\>\"", ",", "\"\<Conservative\>\""}], "}"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{
           GraphicsBox[RasterBox[CompressedData["
1:eJxdmHdUU9m3x39rvb/f+v1m3swokuTem94LvaMUUUBaICQkoUnvvUoRAQUi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             "], {{0, 0}, {40., 52.}}, {0, 255},
             ColorFunction->RGBColor],
            ImageSize->40,
            PlotRange->{{0, 40.}, {0, 52.}}], ",", 
           RowBox[{"{", 
            RowBox[{"10", ",", "1990"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"5", ",", "1997"}], "}"}], ",", "\"\<John Major\>\"", 
           ",", "\"\<Conservative\>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           GraphicsBox[RasterBox[CompressedData["
1:eJx1mAdYFNcWx7eXmd1pW2Z7n91l2UYHpUmxYFcsYI3G2EVQkSKi2BC7PuwF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             "], {{0, 0}, {40., 50.}}, {0, 255},
             ColorFunction->RGBColor],
            ImageSize->40,
            PlotRange->{{0, 40.}, {0, 50.}}], ",", 
           RowBox[{"{", 
            RowBox[{"5", ",", "1997"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"12", ",", "2007"}], "}"}], ",", "\"\<Tony Blair\>\"", 
           ",", "\"\<Labour\>\""}], "}"}], ",", "Null"}], "}"}]}], " ", ";"}],
      "\[IndentingNewLine]", ")"}]}], ",", 
   RowBox[{"ControllerLinking", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.35696210375764*^9, 3.379330237020219*^9, {3.379457501534375*^9, 
   3.37945750439375*^9}, {3.379457745003125*^9, 3.379457749284375*^9}, {
   3.37945787745625*^9, 3.37945795139375*^9}, {3.379458415440625*^9, 
   3.379458415440625*^9}, {3.381485669109375*^9, 3.381485669109375*^9}, 
   3.381485939984375*^9, {3.381486022390625*^9, 3.381486029953125*^9}, {
   3.383470173734375*^9, 3.38347025846875*^9}, {3.432253727390625*^9, 
   3.43225373553125*^9}},
 CellID->81406683]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example of data analysis and dynamic interaction", "Section",
 CellChangeTimes->{{3.40422518640625*^9, 3.404225212390625*^9}, {
  3.43009896309375*^9, 3.43009897184375*^9}, {3.430099603328125*^9, 
  3.430099608125*^9}}],

Cell[TextData[{
 "Thanks to the complete integration of all ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s functionalities, we can analyse, manipulate and change data in just one \
box.\nIn this example there is a InterpolatingPolynomial applied on some \
starting points, then its graphic result and an interactive panel which let \
us to change \"on the fly\" pre-existing values or add new ones."
}], "Text",
 CellChangeTimes->{{3.4300990214375*^9, 3.430099112625*^9}, 
   3.430101867171875*^9}],

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{"InterpolatingPolynomial", "[", 
       RowBox[{"pts", ",", "x"}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "10"}], ",", "10"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Filling", "\[Rule]", "Axis"}], ",", 
     RowBox[{"FillingStyle", "\[Rule]", "LightGreen"}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "400"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"pts", ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Random", "[", "]"}], ",", 
           RowBox[{"Random", "[", "]"}]}], "}"}], ",", 
         RowBox[{"{", "5", "}"}]}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "10"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "10"}], "}"}], ",", "Locator", ",", 
     RowBox[{"LocatorAutoCreate", "\[Rule]", "True"}]}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.420349817125*^9, 3.42034991996875*^9}, {
   3.4203499663125*^9, 3.42035000328125*^9}, {3.420350044421875*^9, 
   3.42035021440625*^9}, {3.420350294078125*^9, 3.4203502964375*^9}, {
   3.420350353546875*^9, 3.420350414984375*^9}, {3.430099117*^9, 
   3.430099127265625*^9}, 3.4322537484375*^9}],

Cell["Here there is also the FindShortestTour included", "Text",
 CellChangeTimes->{{3.43009916525*^9, 3.430099180515625*^9}}],

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"ListLinePlot", "[", 
    RowBox[{
     RowBox[{"pts", "[", 
      RowBox[{"[", 
       RowBox[{"Last", "[", 
        RowBox[{"FindShortestTour", "[", "pts", "]"}], "]"}], "]"}], "]"}], 
     ",", 
     RowBox[{"ImageSize", "\[Rule]", "400"}], ",", 
     RowBox[{"Axes", "\[Rule]", "False"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"pts", ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Random", "[", "]"}], ",", 
           RowBox[{"Random", "[", "]"}]}], "}"}], ",", 
         RowBox[{"{", "10", "}"}]}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "10"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "10"}], "}"}], ",", "Locator", ",", 
     RowBox[{"LocatorAutoCreate", "\[Rule]", "True"}]}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.420349817125*^9, 3.42034991996875*^9}, {
   3.4203499663125*^9, 3.42035000328125*^9}, {3.420350044421875*^9, 
   3.42035021440625*^9}, {3.420350294078125*^9, 3.4203502964375*^9}, {
   3.420350353546875*^9, 3.420350414984375*^9}, {3.421570955703125*^9, 
   3.421571066046875*^9}, 3.432253764234375*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["A descriptive Statistics Example", "Section",
 CellChangeTimes->{{3.36889059291711*^9, 3.36889060294848*^9}, {
  3.43010027459375*^9, 3.43010027646875*^9}}],

Cell[CellGroupData[{

Cell["A Dataset", "Subsection",
 CellChangeTimes->{{3.36897442005254*^9, 3.36897442559945*^9}}],

Cell["\<\
The following data are winning Maryland Pick\[Hyphen]3 numbers gathered over \
a 32\[Hyphen]week period in 1989 and 1990. The data are based on the Lottery \
data set from NIST's online Dataset Archives.\
\>", "Text",
 CellChangeTimes->{{3.36897391331699*^9, 3.36897392398886*^9}, {
  3.36897395481699*^9, 3.36897404217636*^9}, {3.36897409855136*^9, 
  3.36897413548886*^9}, {3.36897432750507*^9, 3.36897433539575*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Import", "[", 
    RowBox[{
     RowBox[{"ToFileName", "[", 
      RowBox[{
       RowBox[{"NotebookDirectory", "[", "]"}], ",", 
       "\"\<lotterydigits.txt\>\""}], "]"}], ",", "\"\<Table\>\""}], "]"}]}], 
  ";"}]], "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.36890100683407*^9, {3.3689011899452*^9, 3.3689011949598*^9}, {
   3.36890149530476*^9, 3.36890150024131*^9}, {3.36897200999396*^9, 
   3.36897205326097*^9}, 3.36897755573837*^9, {3.36897759945544*^9, 
   3.36897760642392*^9}}],

Cell["There are 218 data elements represented as a list of digits.", "Text",
 CellChangeTimes->{{3.36897414975449*^9, 3.36897421595761*^9}}],

Cell[BoxData[
 RowBox[{"Dimensions", "[", "data", "]"}]], "Input",
 CellChangeTimes->{{3.36897206538635*^9, 3.36897206854271*^9}}],

Cell["Here are the first 5 winners.", "Text",
 CellChangeTimes->{{3.36897422158261*^9, 3.3689742468483*^9}}],

Cell[BoxData[
 RowBox[{"data", "[", 
  RowBox[{"[", 
   RowBox[{"1", ";;", "5"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.36897219032781*^9, 3.36897219282784*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Some Qualitative Analyses", "Subsection",
 CellChangeTimes->{{3.36897443619327*^9, 3.36897444245893*^9}, 
   3.36897754537939*^9}],

Cell["\<\
A question of interest may be: Were the Pick\[Hyphen]3 results fair?  That is \
to say, were the winning numbers roughly evenly distributed, or is there \
evidence that some numbers occurred with noticeably higher frequency.\
\>", "Text",
 CellChangeTimes->{{3.36897454239707*^9, 3.36897458910049*^9}, {
  3.36897463271015*^9, 3.36897469449179*^9}, {3.3689747388827*^9, 
  3.36897483666458*^9}, {3.36897781344903*^9, 3.36897783602672*^9}}],

Cell["\<\
An initial qualitative investigation is likely to include some descriptive \
plots.\
\>", "Text",
 CellChangeTimes->{{3.36897484493026*^9, 3.36897489069618*^9}}],

Cell[CellGroupData[{

Cell["Distribution of Digits", "Subsubsection",
 CellChangeTimes->{{3.36897517997928*^9, 3.36897520021378*^9}}],

Cell[BoxData[
 RowBox[{"<<", "StatisticalPlots`"}]], "Input",
 CellChangeTimes->{{3.36897209610609*^9, 3.36897210044998*^9}}],

Cell["\<\
Box plots for the three digits might be used to access the location and \
spread of the three digits treated independently.\
\>", "Text",
 CellChangeTimes->{{3.36897489882123*^9, 3.36897492247763*^9}, {
  3.36897496122788*^9, 3.36897500311877*^9}}],

Cell[BoxData[
 RowBox[{"BoxWhiskerPlot", "[", "data", "]"}]], "Input",
 CellChangeTimes->{{3.36897212059125*^9, 3.36897212523202*^9}}],

Cell["\<\
Pie charts and bar charts could also be used to describe the frequency of \
individual digits.\
\>", "Text",
 CellChangeTimes->{{3.36897501613448*^9, 3.36897505525973*^9}}],

Cell[BoxData[
 RowBox[{"<<", "BarCharts`"}]], "Input",
 CellChangeTimes->{{3.36897271851297*^9, 3.36897272640375*^9}, 
   3.43010005696875*^9}],

Cell[BoxData[
 RowBox[{"<<", "PieCharts`"}]], "Input",
 CellChangeTimes->{{3.36897271851297*^9, 3.36897272640375*^9}, {
  3.43010005696875*^9, 3.43010006453125*^9}}],

Cell["This gives a list of the counts for the first digits.", "Text",
 CellChangeTimes->{{3.36897505824412*^9, 3.36897510255691*^9}}],

Cell[BoxData[
 RowBox[{"digit1", "=", 
  RowBox[{"Sort", "[", 
   RowBox[{"Tally", "[", 
    RowBox[{"data", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "1"}], "]"}], "]"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.3689727942488*^9, 3.3689728046865*^9}, {
  3.36897447638102*^9, 3.36897447906854*^9}}],

Cell["\<\
Pie and bar charts of the counts do not appear to show any large biases in \
the first digit.\
\>", "Text",
 CellChangeTimes->{{3.36897511296322*^9, 3.36897514282279*^9}, {
  3.36897623232976*^9, 3.36897624057981*^9}}],

Cell[BoxData[
 RowBox[{"PieChart", "[", 
  RowBox[{
   RowBox[{"digit1", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2"}], "]"}], "]"}], ",", 
   RowBox[{"PieLabels", "->", 
    RowBox[{"digit1", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "1"}], "]"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.36897277243588*^9, 3.36897277277964*^9}, {
  3.36897281029599*^9, 3.36897281784301*^9}, {3.36897284915611*^9, 
  3.36897285689063*^9}}],

Cell[BoxData[
 RowBox[{"BarChart", "[", 
  RowBox[{
   RowBox[{"digit1", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2"}], "]"}], "]"}], ",", 
   RowBox[{"BarLabels", "->", 
    RowBox[{"digit1", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "1"}], "]"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.3689727315601*^9, 3.36897276245132*^9}, {
  3.36897305667572*^9, 3.36897307256665*^9}}],

Cell["\<\
Similar counts could be obtained for the second and third digits.\
\>", "Text",
 CellChangeTimes->{{3.36897625515803*^9, 3.36897627664254*^9}}],

Cell[BoxData[
 RowBox[{"digit2", "=", 
  RowBox[{"Sort", "[", 
   RowBox[{"Tally", "[", 
    RowBox[{"data", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.3689727942488*^9, 3.3689728046865*^9}, {
  3.36897447638102*^9, 3.36897447906854*^9}, {3.3689752581829*^9, 
  3.36897526187043*^9}}],

Cell[BoxData[
 RowBox[{"digit3", "=", 
  RowBox[{"Sort", "[", 
   RowBox[{"Tally", "[", 
    RowBox[{"data", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "3"}], "]"}], "]"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.36897526437044*^9, 3.36897527382363*^9}}],

Cell["\<\
The counts of 12 and 30 look a little suspicious, but simulations show those \
counts are not really that extreme.\
\>", "Text",
 CellChangeTimes->{{3.36897628814262*^9, 3.36897636267435*^9}, 
   3.36897779387128*^9}],

Cell["\<\
This approximates the probability of observing a smallest count less than or \
equal to 12. \
\>", "Text",
 CellChangeTimes->{{3.36897636915876*^9, 3.36897640208085*^9}, {
  3.36897665623872*^9, 3.36897665870749*^9}, {3.36897778326211*^9, 
  3.36897778365273*^9}}],

Cell[BoxData[
 RowBox[{"<<", "MultivariateStatistics`"}]], "Input",
 CellChangeTimes->{{3.36897775366893*^9, 3.36897775882508*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Count", "[", 
   RowBox[{
    RowBox[{"RandomInteger", "[", 
     RowBox[{
      RowBox[{"MultinomialDistribution", "[", 
       RowBox[{"218", ",", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"1", "/", "10"}], ",", 
          RowBox[{"{", "10", "}"}]}], "]"}]}], "]"}], ",", "10000"}], "]"}], 
    ",", 
    RowBox[{"_", "?", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"Min", "[", "#", "]"}], "<=", "12"}], "&"}], ")"}]}]}], "]"}],
   "/", "10000."}]], "Input",
 CellChangeTimes->{{3.36897594023414*^9, 3.36897606068804*^9}}],

Cell["\<\
This approximates the probability of observing a largest count greater than \
or equal to 30. \
\>", "Text",
 CellChangeTimes->{{3.36897636915876*^9, 3.36897642064347*^9}, {
  3.36897664031675*^9, 3.36897664436365*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Count", "[", 
   RowBox[{
    RowBox[{"RandomInteger", "[", 
     RowBox[{
      RowBox[{"MultinomialDistribution", "[", 
       RowBox[{"218", ",", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"1", "/", "10"}], ",", 
          RowBox[{"{", "10", "}"}]}], "]"}]}], "]"}], ",", "10000"}], "]"}], 
    ",", 
    RowBox[{"_", "?", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"Max", "[", "#", "]"}], ">=", "30"}], "&"}], ")"}]}]}], "]"}],
   "/", "10000."}]], "Input",
 CellChangeTimes->{{3.36897607478188*^9, 3.36897609129761*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Some \"traditional\" aspects", "Section",
 CellChangeTimes->{{3.3608526396718802`*^9, 3.3608526408750014`*^9}, {
  3.383473177296875*^9, 3.383473191625*^9}, {3.4300978661875*^9, 
  3.430097874578125*^9}, {3.430099763453125*^9, 3.43009980603125*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["FindFit examples",
 FontColor->RGBColor[
  0.9714045929655909, 0.6775158312352179, 0.07415884641794461]]], "Subsection",\

 CellChangeTimes->{
  3.3824524252213373`*^9, {3.404024652336375*^9, 3.404024657711375*^9}, {
   3.40403729665625*^9, 3.40403729790625*^9}, {3.404038024171875*^9, 
   3.404038032703125*^9}, {3.404039231640625*^9, 3.404039243578125*^9}, {
   3.40403933546875*^9, 3.40403933828125*^9}, {3.404039502296875*^9, 
   3.4040395046875*^9}, {3.404039549015625*^9, 3.404039558203125*^9}, {
   3.404040062578125*^9, 3.40404006315625*^9}, {3.40422624646875*^9, 
   3.404226252796875*^9}, {3.40422629659375*^9, 3.40422630109375*^9}, {
   3.4167198813125*^9, 3.41671988540625*^9}, {3.41672206309375*^9, 
   3.416722066046875*^9}, {3.430097883625*^9, 3.43009788578125*^9}}],

Cell[BoxData[
 RowBox[{"??", "FindFit"}]], "Input",
 CellChangeTimes->{{3.430097906890625*^9, 3.430097911375*^9}}],

Cell["A first example", "Text",
 CellChangeTimes->{{3.430097918375*^9, 3.430097925453125*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"t", ",", 
       RowBox[{
        RowBox[{"\[Piecewise]", GridBox[{
           {
            FractionBox[
             RowBox[{"Sin", "[", 
              RowBox[{"0.1`", " ", "t"}], "]"}], 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"0.04`", " ", "t"}]]], 
            RowBox[{"t", "\[GreaterEqual]", "0"}]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{1.}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.84]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
            "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}]}], "+", 
        RowBox[{"RandomReal", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "0.01`"}], ",", "0.01`"}], "}"}], "]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", 
       RowBox[{"-", "5"}], ",", "150"}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"model", "=", 
   RowBox[{"Which", "[", 
    RowBox[{
     RowBox[{"t", "<", "0"}], ",", "0", ",", "True", ",", 
     FractionBox[
      RowBox[{"Sin", "[", 
       RowBox[{"b", " ", "t"}], "]"}], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "a"}], " ", "t"}]]]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.41672209290625*^9, 3.416722104765625*^9}}],

Cell[BoxData[
 RowBox[{"sol", "=", 
  RowBox[{"FindFit", "[", 
   RowBox[{"data", ",", "model", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        StyleBox["a",
         FontColor->RGBColor[1, 0, 0]], ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        StyleBox["b",
         FontColor->RGBColor[1, 0, 0]], ",", "1"}], "}"}]}], "}"}], ",", 
    RowBox[{"{", "t", "}"}], ",", 
    RowBox[{"MaxIterations", "\[Rule]", "200"}]}], "]"}]}]], "Input"],

Cell["This shows the final result compared with experimental data", "Text",
 CellChangeTimes->{{3.430097934953125*^9, 3.43009794771875*^9}}],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"model", "/.", "\[InvisibleSpace]", "sol"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", 
       RowBox[{"-", "5"}], ",", "150"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Red"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"data", ",", 
     RowBox[{"Joined", "\[Rule]", "False"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"PointSize", "[", "0.008`", "]"}], "}"}]}]}], "]"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.416721724984375*^9, 3.416721775078125*^9}, {
  3.4167218420625*^9, 3.41672184803125*^9}, {3.4167221253125*^9, 
  3.41672215334375*^9}}],

Cell["Another example.", "Text",
 CellChangeTimes->{{3.430097959734375*^9, 3.43009798171875*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"MyFunction", "[", 
   RowBox[{"a_", ",", " ", "b_", ",", " ", "c_", ",", " ", "x_"}], "]"}], " ",
   ":=", " ", 
  RowBox[{"a", " ", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"x", " ", ">", " ", "0"}], ",", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"b", " ", "x"}], "]"}], ",", " ", 
     RowBox[{"Exp", "[", 
      RowBox[{"c", " ", "x"}], "]"}]}], "]"}]}]}]], "Input"],

Cell["Here I make a list of values adding also a random component", "Text",
 CellChangeTimes->{{3.43009798925*^9, 3.4300980016875*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Epsilon]", "=", "0.1`"}], ",", 
      RowBox[{"a", "=", "1.2`"}], ",", 
      RowBox[{"b", "=", "3.4`"}], ",", 
      RowBox[{"c", "=", "0.98`"}]}], "}"}], ",", 
    RowBox[{"data", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{
          RowBox[{"MyFunction", "[", 
           RowBox[{"a", ",", "b", ",", "c", ",", "x"}], "]"}], "+", 
          RowBox[{"\[Epsilon]", " ", 
           RowBox[{"RandomReal", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.5`"}], ",", "0.5`"}], "}"}], "]"}]}]}]}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "5"}], ",", "5", ",", "0.1`"}], "}"}]}], "]"}]}]}], 
   "]"}], ";"}]], "Input"],

Cell["FindFit is used to find the data fitting", "Text",
 CellChangeTimes->{{3.430098008234375*^9, 3.43009801471875*^9}}],

Cell[BoxData[
 RowBox[{"fit", " ", "=", " ", 
  RowBox[{"FindFit", "[", 
   RowBox[{"data", ",", " ", 
    RowBox[{"MyFunction", "[", 
     RowBox[{"a", ",", "b", ",", " ", "c", ",", " ", "x"}], "]"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        StyleBox["a",
         FontColor->RGBColor[1, 0, 0]], ",", "1"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{
        StyleBox["b",
         FontColor->RGBColor[1, 0, 0]], ",", "3"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{
        StyleBox["c",
         FontColor->RGBColor[1, 0, 0]], ",", " ", "1"}], "}"}]}], "}"}], ",", 
    "x"}], "]"}]}]], "Input"],

Cell["This is the graphical result", "Text",
 CellChangeTimes->{{3.430098017921875*^9, 3.430098021828125*^9}}],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"ListPlot", "[", "data", "]"}], ",", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"MyFunction", "[", 
        RowBox[{"a", ",", "b", ",", "c", ",", "x"}], "]"}], "/.", 
       "\[InvisibleSpace]", "fit"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", 
        RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"RGBColor", "[", 
        RowBox[{"0", ",", "1", ",", "0"}], "]"}]}]}], "]"}]}], "}"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.4167217096875*^9, 3.41672171134375*^9}}],

Cell[TextData[{
 "How we can discover intermediate steps? The option ",
 Cell[BoxData[
  ButtonBox["EvaluationMonitor",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/EvaluationMonitor"]], "Text"],
 " does this for us"
}], "Text",
 CellChangeTimes->{{3.416722370125*^9, 3.41672239859375*^9}, {
  3.4300980299375*^9, 3.4300980503125*^9}}],

Cell[BoxData[
 RowBox[{"Options", "[", "FindFit", "]"}]], "Input",
 CellChangeTimes->{{3.416722302921875*^9, 3.41672230628125*^9}}],

Cell[BoxData[
 RowBox[{"Reap", "[", 
  RowBox[{"FindFit", "[", 
   RowBox[{"data", ",", " ", 
    RowBox[{"MyFunction", "[", 
     RowBox[{"a", ",", "b", ",", " ", "c", ",", " ", "x"}], "]"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        StyleBox["a",
         FontColor->RGBColor[1, 0, 0]], ",", "1"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{
        StyleBox["b",
         FontColor->RGBColor[1, 0, 0]], ",", "3"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{
        StyleBox["c",
         FontColor->RGBColor[1, 0, 0]], ",", " ", "1"}], "}"}]}], "}"}], ",", 
    "x", ",", 
    RowBox[{"EvaluationMonitor", "\[RuleDelayed]", 
     RowBox[{"Sow", "[", 
      RowBox[{"{", 
       RowBox[{"a", ",", "b", ",", "c"}], "}"}], "]"}]}]}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.41672231403125*^9, 3.416722343546875*^9}, {
  3.416722424890625*^9, 3.416722429328125*^9}}],

Cell[TextData[{
 "There are many other ways to further investigate the intermediate steps and \
internal algorithms behaviour. ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " provides many tools and in some cases additional documentation and/or \
packages to allow users \"to explore and drive\" the computation of their \
data. \nThis is an example of additional functions provided by the package ",
 "Optimization`UnconstrainedProblems`"
}], "Text",
 CellChangeTimes->{{3.416721935109375*^9, 3.4167219440625*^9}, {
  3.430098068609375*^9, 3.430098174078125*^9}}],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<Optimization`UnconstrainedProblems`\>\"", 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"FindMinimumPlot", "[", 
  RowBox[{
   RowBox[{"x", " ", 
    RowBox[{"Sin", "[", 
     RowBox[{"x", " ", "+", " ", "1"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.416721966125*^9, 3.41672196715625*^9}, {3.4167222295*^9,
   3.416722243015625*^9}, {3.430098183546875*^9, 3.430098235546875*^9}}],

Cell[BoxData[
 RowBox[{"FindMinimumPlot", "[", 
  RowBox[{
   RowBox[{"x", " ", 
    RowBox[{"Sin", "[", 
     RowBox[{"x", " ", "+", " ", "1"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "20"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.41672197159375*^9, 3.416721972609375*^9}, 
   3.41672247859375*^9, 3.43009819296875*^9}],

Cell["\<\
Another example of EvaluationMonitor within the NIntegrate.
This is the function we want to integrate\
\>", "Text",
 CellChangeTimes->{{3.430098249015625*^9, 3.430098287*^9}}],

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{
   SuperscriptBox[
    RowBox[{"Abs", "[", 
     RowBox[{"x", "-", "y"}], "]"}], 
    RowBox[{"3", "/", "2"}]], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", "0", ",", "1"}], "}"}], ",", 
   RowBox[{"PlotPoints", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"50", ",", "50"}], "}"}]}], ",", 
   RowBox[{"ViewPoint", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0.906", ",", " ", 
      RowBox[{"-", "1.672"}], ",", " ", "1.590"}], "}"}]}]}], "]"}]], "Input",\

 CellChangeTimes->{3.42027388815625*^9},
 CellTags->"NIntegrate"],

Cell["\<\
This is the graphic of points used by NIntegrte when the method used is the \
default Multidimensional \
\>", "Text",
 CellChangeTimes->{{3.430098293859375*^9, 3.430098319765625*^9}},
 CellTags->"NIntegrate"],

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"xys", "=", 
    RowBox[{
     RowBox[{"Reap", "[", 
      RowBox[{"NIntegrate", "[", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Abs", "[", 
          RowBox[{"x", "-", "y"}], "]"}], 
         RowBox[{"3", "/", "2"}]], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "0", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"y", ",", "0", ",", "1"}], "}"}], ",", 
        RowBox[{"EvaluationMonitor", "\[RuleDelayed]", 
         RowBox[{"Sow", "[", 
          RowBox[{"{", 
           RowBox[{"x", ",", "y"}], "}"}], "]"}]}]}], "]"}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"2", ",", "1"}], "]"}], "]"}]}], ",", " ", 
   RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", 
    RowBox[{"\"\<Number of points:\>\"", "<>", " ", 
     RowBox[{"ToString", "[", 
      RowBox[{"Length", "[", "xys", "]"}], "]"}]}]}]}], "]"}]], "Input",
 CellChangeTimes->{3.420273894953125*^9},
 CellTags->"NIntegrate"],

Cell["\<\
Here is the same for the GaussKronrod method\
\>", "Text",
 CellChangeTimes->{{3.430098327546875*^9, 3.430098336375*^9}},
 CellTags->"NIntegrate"],

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"xys", "=", 
    RowBox[{
     RowBox[{"Reap", "[", 
      RowBox[{"NIntegrate", "[", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Abs", "[", 
          RowBox[{"x", "-", "y"}], "]"}], 
         RowBox[{"3", "/", "2"}]], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "0", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"y", ",", "0", ",", "1"}], "}"}], ",", 
        RowBox[{"Method", "\[Rule]", "GaussKronrod"}], ",", 
        RowBox[{"EvaluationMonitor", "\[RuleDelayed]", 
         RowBox[{"Sow", "[", 
          RowBox[{"{", 
           RowBox[{"x", ",", "y"}], "}"}], "]"}]}]}], "]"}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"2", ",", "1"}], "]"}], "]"}]}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", 
    RowBox[{"\"\<Number of points:\>\"", "<>", 
     RowBox[{"ToString", "[", 
      RowBox[{"Length", "[", "xys", "]"}], "]"}]}]}]}], "]"}]], "Input",
 CellChangeTimes->{3.4202738998125*^9},
 CellTags->"NIntegrate"],

Cell["And finallt the Montecarlo method", "Text",
 CellChangeTimes->{{3.430098353765625*^9, 3.4300983609375*^9}}],

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"xys", "=", 
    RowBox[{
     RowBox[{"Reap", "[", 
      RowBox[{"NIntegrate", "[", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Abs", "[", 
          RowBox[{"x", "-", "y"}], "]"}], 
         RowBox[{"3", "/", "2"}]], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "0", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"y", ",", "0", ",", "1"}], "}"}], ",", 
        RowBox[{"Method", "\[Rule]", "MonteCarlo"}], ",", 
        RowBox[{"EvaluationMonitor", "\[RuleDelayed]", 
         RowBox[{"Sow", "[", 
          RowBox[{"{", 
           RowBox[{"x", ",", "y"}], "}"}], "]"}]}]}], "]"}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"2", ",", "1"}], "]"}], "]"}]}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", 
    RowBox[{"\"\<Number of points:\>\"", "<>", 
     RowBox[{"ToString", "[", 
      RowBox[{"Length", "[", "xys", "]"}], "]"}]}]}]}], "]"}]], "Input",
 CellChangeTimes->{3.420273902390625*^9},
 CellTags->"NIntegrate"],

Cell["\<\
There is also another intereting function named Monitor, that provides a \
temporary image of what is happening during a calculation\
\>", "Text",
 CellChangeTimes->{{3.4300983926875*^9, 3.43009842409375*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"values", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Monitor", "[", 
  RowBox[{
   RowBox[{"NIntegrate", "[", 
    RowBox[{
     RowBox[{"Sqrt", "[", 
      RowBox[{"x", 
       RowBox[{"(", 
        RowBox[{"1", "-", "x"}], ")"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"EvaluationMonitor", "\[RuleDelayed]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Pause", "[", "0.025", "]"}], ";", 
        RowBox[{"AppendTo", "[", 
         RowBox[{"values", ",", "x"}], "]"}], ";"}], ")"}]}]}], "]"}], ",", 
   RowBox[{"ListPlot", "[", "values", "]"}]}], "]"}]}], "Input"],

Cell["Monitor NDSolve using an extrapolation method:", "Text",
 CellChangeTimes->{{3.430098484078125*^9, 3.43009848678125*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"values1", "=", 
   RowBox[{"{", "}"}]}], ";", 
  RowBox[{"values2", "=", 
   RowBox[{"{", "}"}]}], ";", 
  RowBox[{"Monitor", "[", 
   RowBox[{
    RowBox[{"NDSolve", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"x", "''"}], "[", "t", "]"}], "+", 
          RowBox[{"Sin", "[", 
           RowBox[{"x", "[", "t", "]"}], "]"}]}], "\[Equal]", "0"}], ",", 
        RowBox[{
         RowBox[{"x", "[", "0", "]"}], "\[Equal]", "1"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"x", "'"}], "[", "0", "]"}], "\[Equal]", "0"}]}], "}"}], 
      ",", "x", ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", 
        RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
      RowBox[{"EvaluationMonitor", "\[RuleDelayed]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"AppendTo", "[", 
          RowBox[{"values1", ",", 
           RowBox[{"{", 
            RowBox[{"t", ",", 
             RowBox[{"x", "[", "t", "]"}]}], "}"}]}], "]"}], ";", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"values2", ",", 
           RowBox[{"{", 
            RowBox[{"t", ",", 
             RowBox[{
              RowBox[{"x", "'"}], "[", "t", "]"}]}], "}"}]}], "]"}], ";", 
         RowBox[{"Pause", "[", "0.05", "]"}], ";"}], ")"}]}], ",", " ", 
      RowBox[{"Method", "\[Rule]", "\"\<Extrapolation\>\""}]}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"{", 
      RowBox[{"values1", ",", "values2"}], "}"}], "]"}]}], "]"}]}]], "Input"],

Cell["Steps in parameter space for a nonlinear fit:", "Text",
 CellID->735994752],

Cell[BoxData[{
 RowBox[{
  RowBox[{"data", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.18", ",", 
       RowBox[{"-", "0.13"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.84", ",", 
       RowBox[{"-", "0.06"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.05", ",", "0.88"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.24", ",", 
       RowBox[{"-", "0.63"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.67", ",", "0.93"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.05", ",", "0.88"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.65", ",", "0.92"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.01", ",", "0.99"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.17", ",", 
       RowBox[{"-", "0.04"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.23", ",", 
       RowBox[{"-", "0.55"}]}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lp", " ", "=", " ", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"data", ",", " ", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], ";"}]}], "Input",
 CellContext->"Global`",
 CellID->37843928],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"model", "[", 
    RowBox[{"{", 
     RowBox[{"a_", ",", " ", "k_", ",", " ", "w_", ",", " ", "p_"}], "}"}], 
    "]"}], " ", "=", " ", 
   RowBox[{"a", " ", 
    RowBox[{"Exp", "[", 
     RowBox[{
      RowBox[{"-", "k"}], " ", "x"}], "]"}], " ", 
    RowBox[{"Sin", "[", 
     RowBox[{
      RowBox[{"w", " ", "x"}], " ", "+", "p"}], "]"}]}]}], ";"}]], "Input",
 CellContext->"Global`",
 CellID->67367124],

Cell["\<\
Monitor the evolution of the model over the steps with a graph:\
\>", "Text",
 CellID->205567056],

Cell[BoxData[
 RowBox[{"Monitor", "[", 
  RowBox[{
   RowBox[{"FindFit", "[", 
    RowBox[{"data", ",", " ", 
     RowBox[{"model", "[", 
      RowBox[{"{", 
       RowBox[{"a", ",", "k", ",", "w", ",", "p"}], "}"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"a", ",", "k", ",", "w", ",", "p"}], "}"}], ",", "x", ",", " ", 
     
     RowBox[{"StepMonitor", "\[RuleDelayed]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"vars", "=", 
         RowBox[{"{", 
          RowBox[{"a", ",", "k", ",", "w", ",", "p"}], "}"}]}], ";", 
        RowBox[{"Pause", "[", "0.3", "]"}], ";"}], ")"}]}]}], "]"}], ",", 
   RowBox[{"Show", "[", 
    RowBox[{"lp", ",", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"model", "[", "vars", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]}], "]"}]}], 
  "]"}]], "Input",
 CellContext->"Global`",
 CellID->262267683],

Cell[TextData[{
 "Implement a simple LU decomposition with a slowdown parameter ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]], "InlineMath"],
 ":"
}], "Text",
 CellID->238179222],

Cell[BoxData[
 RowBox[{
  RowBox[{"LU", "[", 
   RowBox[{"A_", ",", 
    RowBox[{"p_:", "0"}]}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"m", ",", "n", ",", "L", ",", "U"}], "}"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m", ",", "n"}], "}"}], "=", 
      RowBox[{"Dimensions", "[", "A", "]"}]}], ";", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"L", ",", "U"}], "}"}], "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"IdentityMatrix", "[", "n", "]"}], ",", "A"}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Pause", "[", "p", "]"}], ";", 
        RowBox[{
         RowBox[{"L", "[", 
          RowBox[{"[", 
           RowBox[{
            RowBox[{"k", ";;", "n"}], ",", "k"}], "]"}], "]"}], "=", " ", 
         RowBox[{
          RowBox[{"U", "[", 
           RowBox[{"[", 
            RowBox[{
             RowBox[{"k", ";;", "n"}], ",", "k"}], "]"}], "]"}], "/", 
          RowBox[{"U", "[", 
           RowBox[{"[", 
            RowBox[{"k", ",", "k"}], "]"}], "]"}]}]}], ";", 
        RowBox[{
         RowBox[{"U", "[", 
          RowBox[{"[", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"k", "+", "1"}], ")"}], ";;", "n"}], ",", 
            RowBox[{"k", ";;", "n"}]}], "]"}], "]"}], "=", 
         RowBox[{
          RowBox[{"U", "[", 
           RowBox[{"[", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"k", "+", "1"}], ")"}], ";;", "n"}], ",", 
             RowBox[{"k", ";;", "n"}]}], "]"}], "]"}], "-", 
          RowBox[{
           RowBox[{"L", "[", 
            RowBox[{"[", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"k", "+", "1"}], ")"}], ";;", "n"}], ",", 
              RowBox[{"{", "k", "}"}]}], "]"}], "]"}], ".", 
           RowBox[{"U", "[", 
            RowBox[{"[", 
             RowBox[{
              RowBox[{"{", "k", "}"}], ",", 
              RowBox[{"k", ";;", "n"}]}], "]"}], "]"}]}]}]}], ";"}], 
       "\[IndentingNewLine]", ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", 
         RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"L", ",", "U"}], "}"}]}]}], "]"}]}]], "Input",
 CellContext->"Global`",
 CellID->446643489],

Cell[TextData[{
 "Monitor an algorithm animation using ",
 Cell[BoxData[
  ButtonBox["MatrixForm",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/MatrixForm"]], "InlineFormula"],
 " or ",
 Cell[BoxData[
  ButtonBox["MatrixPlot",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/MatrixPlot"]], "InlineFormula"],
 ": "
}], "Text",
 CellID->291328065],

Cell[BoxData[
 RowBox[{"Monitor", "[", 
  RowBox[{
   RowBox[{"LU", "[", 
    RowBox[{
     RowBox[{"RandomInteger", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "10"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", "10"}], "}"}]}], "]"}], ",", "1"}], "]"}], ",", 
   RowBox[{"MatrixForm", "/@", 
    RowBox[{"{", 
     RowBox[{"L", ",", "U"}], "}"}]}]}], "]"}]], "Input",
 CellContext->"Global`",
 CellChangeTimes->{{3.430098584203125*^9, 3.4300986048125*^9}},
 CellID->218644546],

Cell[BoxData[
 RowBox[{"Monitor", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"LU", "[", 
     RowBox[{
      RowBox[{"RandomReal", "[", 
       RowBox[{"1", ",", 
        RowBox[{"{", 
         RowBox[{"100", ",", "100"}], "}"}]}], "]"}], ",", ".3"}], "]"}], 
    ";"}], ",", 
   RowBox[{"MatrixPlot", "/@", 
    RowBox[{"{", 
     RowBox[{"L", ",", "U"}], "}"}]}]}], "]"}]], "Input",
 CellContext->"Global`",
 CellChangeTimes->{{3.430098627890625*^9, 3.4300986295*^9}},
 CellID->157417187]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Everything fits with everything", "Section",
 CellChangeTimes->{{3.383474295640625*^9, 3.38347430890625*^9}, {
  3.383485542578125*^9, 3.383485546546875*^9}}],

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"DynamicModule", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"lastpt", "=", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"Graphics", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"PointSize", "[", "0.1", "]"}], ",", 
         RowBox[{"Point", "[", 
          RowBox[{"Dynamic", "[", 
           RowBox[{
            RowBox[{"Refresh", "[", 
             RowBox[{
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{"pt", "=!=", "lastpt"}], ",", 
                RowBox[{
                 RowBox[{"AppendTo", "[", 
                  RowBox[{"contents", ",", 
                   RowBox[{"{", 
                    RowBox[{"pt", ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}], "]"}], ";", 
                 RowBox[{"lastpt", "=", "pt"}]}]}], "]"}], ",", 
              RowBox[{"TrackedSymbols", "\[Rule]", 
               RowBox[{"{", "pt", "}"}]}]}], "]"}], ";", 
            RowBox[{"contents", "=", 
             RowBox[{"Map", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "2"}], "]"}], "]"}], "\[GreaterEqual]", 
                   "0"}], ",", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "-", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], ",", 
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "+", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "0.001"}], "}"}]}]}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", "0"}], "}"}], 
                    ",", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"1", ",", 
                    RowBox[{"-", "0.8"}]}], "}"}], 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}]}], "]"}], "&"}],
                ",", "contents"}], "]"}]}], ";", 
            RowBox[{"Map", "[", 
             RowBox[{"First", ",", "contents"}], "]"}]}], "]"}], "]"}]}], 
        "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"pt", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", "Locator", ",", 
     RowBox[{"Appearance", "\[Rule]", "None"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"contents", ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "None"}], ",", 
     RowBox[{"Appearance", "\[Rule]", "None"}]}], "}"}], ",", 
   RowBox[{"SynchronousUpdating", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.35757176568782*^9, 3.36464078446118*^9, {3.36510392139063*^9, 
   3.36510392609375*^9}, {3.36510401103125*^9, 3.36510403064063*^9}, {
   3.378652983954333*^9, 3.378653169610583*^9}, {3.378653362423083*^9, 
   3.3786533627512074`*^9}, {3.382088123296875*^9, 3.382088124265625*^9}, {
   3.38208821371875*^9, 3.382088214765625*^9}, {3.383485555515625*^9, 
   3.3834855569375*^9}, {3.38348577234375*^9, 3.383485791078125*^9}},
 CellID->4681751]
}, Open  ]],

Cell[CellGroupData[{

Cell["Other examples (from demonstrations.wolfram.com )", "Section",
 CellChangeTimes->{{3.3673241014333706`*^9, 3.367324107839662*^9}, {
   3.383474201171875*^9, 3.38347420534375*^9}, {3.39231469609375*^9, 
   3.392314698203125*^9}, {3.392316139203125*^9, 3.392316148296875*^9}, 
   3.430099625984375*^9}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`A$$ = 0.446, $CellContext`B$$ = 
    2.1420000000000003`, $CellContext`babyArea$$ = 
    1.5773206533261932`, $CellContext`babyLinear$$ = 
    0.3594350914562736, $CellContext`CC$$ = 
    3.141592653589793, $CellContext`mamaArea$$ = 
    11.216502423652932`, $CellContext`mamaLinear$$ = 
    0.9584935772167297, $CellContext`papaArea$$ = 
    25.23713045321909, $CellContext`papaLinear$$ = 
    1.4377403658250945`, $CellContext`radio$$ = 2, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`radio$$], 1, "Linear Element"}, {
      1 -> "AB", 2 -> "BC", 3 -> "CA", 4 -> "Perimeter", 5 -> 
       "A Bisector"}}, {{
       Hold[$CellContext`A$$], 0.2, "Vertex A"}, 1.4707963267948965`, 0}, {{
       Hold[$CellContext`B$$], 1.5707963267948966`, "Vertex B"}, 
      3.041592653589793, 1.5707963267948966`}, {{
       Hold[$CellContext`CC$$], 4.360336558432794, "Vertex C"}, Pi, 
      6.183185307179587}, {{
       Hold[$CellContext`mamaArea$$], 17.410732826967497`, ""}, 
      Blank[], 
      Blank[]}, {{
       Hold[$CellContext`papaArea$$], 39.17414886067688, ""}, 
      Blank[], 
      Blank[]}, {{
       Hold[$CellContext`babyArea$$], 2.448384303792305, ""}, 
      Blank[], 
      Blank[]}, {{
       Hold[$CellContext`mamaLinear$$], 1.2659626133539164`, ""}, 
      Blank[], 
      Blank[]}, {{
       Hold[$CellContext`papaLinear$$], 1.8989439200308746`, ""}, 
      Blank[], 
      Blank[]}, {{
       Hold[$CellContext`babyLinear$$], 0.47473598000771866`, ""}, 
      Blank[], 
      Blank[]}}, Typeset`size$$ = {397., {187.5, 192.5}}, Typeset`update$$ = 
    0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`radio$4377$$ = False, $CellContext`A$4378$$ = 
    0, $CellContext`B$4379$$ = 0, $CellContext`CC$4380$$ = 
    0, $CellContext`mamaArea$4381$$ = 0, $CellContext`papaArea$4382$$ = 
    0, $CellContext`babyArea$4383$$ = 0, $CellContext`mamaLinear$4384$$ = 
    0, $CellContext`papaLinear$4385$$ = 0, $CellContext`babyLinear$4386$$ = 
    0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`A$$ = 0.2, $CellContext`B$$ = 
        1.5707963267948966`, $CellContext`babyArea$$ = 
        2.448384303792305, $CellContext`babyLinear$$ = 
        0.47473598000771866`, $CellContext`CC$$ = 
        4.360336558432794, $CellContext`mamaArea$$ = 
        17.410732826967497`, $CellContext`mamaLinear$$ = 
        1.2659626133539164`, $CellContext`papaArea$$ = 
        39.17414886067688, $CellContext`papaLinear$$ = 
        1.8989439200308746`, $CellContext`radio$$ = 1}, 
      "ControllerVariables" :> {
        Hold[$CellContext`radio$$, $CellContext`radio$4377$$, False], 
        Hold[$CellContext`A$$, $CellContext`A$4378$$, 0], 
        Hold[$CellContext`B$$, $CellContext`B$4379$$, 0], 
        Hold[$CellContext`CC$$, $CellContext`CC$4380$$, 0], 
        Hold[$CellContext`mamaArea$$, $CellContext`mamaArea$4381$$, 0], 
        Hold[$CellContext`papaArea$$, $CellContext`papaArea$4382$$, 0], 
        Hold[$CellContext`babyArea$$, $CellContext`babyArea$4383$$, 0], 
        Hold[$CellContext`mamaLinear$$, $CellContext`mamaLinear$4384$$, 0], 
        Hold[$CellContext`papaLinear$$, $CellContext`papaLinear$4385$$, 0], 
        Hold[$CellContext`babyLinear$$, $CellContext`babyLinear$4386$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> ($CellContext`frm[
          Pattern[$CellContext`x, 
           Blank[]]] := 
        NumberForm[$CellContext`x, {4, 
          
          2}]; $CellContext`mamaArea$$ = $CellContext`area[$CellContext`A$$, \
$CellContext`B$$, $CellContext`CC$$, 
          4.]; $CellContext`papaArea$$ = $CellContext`area[$CellContext`A$$, \
$CellContext`B$$, $CellContext`CC$$, 
          6.]; $CellContext`babyArea$$ = $CellContext`area[$CellContext`A$$, \
$CellContext`B$$, $CellContext`CC$$, 1.5]; $CellContext`mamaLinear$$ = 
        Switch[$CellContext`radio$$, 1, 
          Norm[{
             Cos[$CellContext`A$$], 
             Sin[$CellContext`A$$]} - {
            Cos[$CellContext`B$$], 
            Sin[$CellContext`B$$]}], 2, 
          Norm[{
             Cos[$CellContext`B$$], 
             Sin[$CellContext`B$$]} - {
            Cos[$CellContext`CC$$], 
            Sin[$CellContext`CC$$]}], 3, 
          Norm[{
             Cos[$CellContext`CC$$], 
             Sin[$CellContext`CC$$]} - {
            Cos[$CellContext`A$$], 
            Sin[$CellContext`A$$]}], 4, Norm[{
              Cos[$CellContext`A$$], 
              Sin[$CellContext`A$$]} - {
             Cos[$CellContext`B$$], 
             Sin[$CellContext`B$$]}] + Norm[{
              Cos[$CellContext`B$$], 
              Sin[$CellContext`B$$]} - {
             Cos[$CellContext`CC$$], 
             Sin[$CellContext`CC$$]}] + Norm[{
              Cos[$CellContext`CC$$], 
              Sin[$CellContext`CC$$]} - {
             Cos[$CellContext`A$$], 
             Sin[$CellContext`A$$]}], 5, 
          Norm[{
             Cos[$CellContext`A$$], 
             Sin[$CellContext`A$$]} - 0.5 ({
              Cos[$CellContext`B$$], 
              Sin[$CellContext`B$$]} + {
              Cos[$CellContext`CC$$], 
              Sin[$CellContext`CC$$]})]]; $CellContext`papaLinear$$ = (6./
          4) $CellContext`mamaLinear$$; $CellContext`babyLinear$$ = (1.5/
          4) $CellContext`mamaLinear$$; Style[
         Grid[{{
            Graphics[{
              Polygon[{{-10, -10}, {10, -10}, {10, 10}, {-10, 10}}, 
               VertexColors -> {
                 Lighter[Orange, 0.75], 
                 Lighter[Orange, 0.6], 
                 Lighter[Green, 0.75], 
                 Lighter[Blue, 0.75]}], 
              FaceForm[
               Lighter[Yellow, 0.65], 
               Opacity[0.5]], 
              EdgeForm[{
                AbsoluteThickness[3], 
                Lighter[Black, 0.8], 
                Opacity[0.15]}], 
              
              Polygon[{{-5 + 4 Cos[$CellContext`A$$], 5 + 
                 4 Sin[$CellContext`A$$]}, {-5 + 4 Cos[$CellContext`B$$], 5 + 
                 4 Sin[$CellContext`B$$]}, {-5 + 4 Cos[$CellContext`CC$$], 5 + 
                 4 Sin[$CellContext`CC$$]}}], 
              
              Polygon[{{
                5 + 1.5 Cos[$CellContext`A$$], 5 + 
                 1.5 Sin[$CellContext`A$$]}, {
                5 + 1.5 Cos[$CellContext`B$$], 5 + 
                 1.5 Sin[$CellContext`B$$]}, {
                5 + 1.5 Cos[$CellContext`CC$$], 5 + 
                 1.5 Sin[$CellContext`CC$$]}}], 
              
              Polygon[{{
                6 Cos[$CellContext`A$$], -5 + 6 Sin[$CellContext`A$$]}, {
                6 Cos[$CellContext`B$$], -5 + 6 Sin[$CellContext`B$$]}, {
                6 Cos[$CellContext`CC$$], -5 + 6 Sin[$CellContext`CC$$]}}], 
              Style[
               Text[
               "A", {7.2 Cos[$CellContext`A$$], -5 + 
                 7.2 Sin[$CellContext`A$$]}], 24, Red, Italic], 
              Style[
               Text[
               "B", {7.2 Cos[$CellContext`B$$], -5 + 
                 7.2 Sin[$CellContext`B$$]}], 24, Red, Italic], 
              Style[
               Text[
               "C", {7.2 Cos[$CellContext`CC$$], -5 + 
                 7.2 Sin[$CellContext`CC$$]}], 24, Red, Italic], 
              AbsoluteThickness[3], Red, 
              Switch[$CellContext`radio$$, 1, {
                
                Line[{{-5 + 4 Cos[$CellContext`A$$], 5 + 
                   4 Sin[$CellContext`A$$]}, {-5 + 4 Cos[$CellContext`B$$], 5 + 
                   4 Sin[$CellContext`B$$]}}], 
                
                Line[{{5 + 1.5 Cos[$CellContext`A$$], 5 + 
                   1.5 Sin[$CellContext`A$$]}, {
                  5 + 1.5 Cos[$CellContext`B$$], 5 + 
                   1.5 Sin[$CellContext`B$$]}}], 
                
                Line[{{6 Cos[$CellContext`A$$], -5 + 
                   6 Sin[$CellContext`A$$]}, {
                  6 Cos[$CellContext`B$$], -5 + 6 Sin[$CellContext`B$$]}}]}, 
               2, {
                
                Line[{{-5 + 4 Cos[$CellContext`B$$], 5 + 
                   4 Sin[$CellContext`B$$]}, {-5 + 4 Cos[$CellContext`CC$$], 
                   5 + 4 Sin[$CellContext`CC$$]}}], 
                
                Line[{{5 + 1.5 Cos[$CellContext`B$$], 5 + 
                   1.5 Sin[$CellContext`B$$]}, {
                  5 + 1.5 Cos[$CellContext`CC$$], 5 + 
                   1.5 Sin[$CellContext`CC$$]}}], 
                
                Line[{{6 Cos[$CellContext`B$$], -5 + 
                   6 Sin[$CellContext`B$$]}, {
                  6 Cos[$CellContext`CC$$], -5 + 6 Sin[$CellContext`CC$$]}}]},
                3, {
                
                Line[{{-5 + 4 Cos[$CellContext`A$$], 5 + 
                   4 Sin[$CellContext`A$$]}, {-5 + 4 Cos[$CellContext`CC$$], 
                   5 + 4 Sin[$CellContext`CC$$]}}], 
                
                Line[{{5 + 1.5 Cos[$CellContext`A$$], 5 + 
                   1.5 Sin[$CellContext`A$$]}, {
                  5 + 1.5 Cos[$CellContext`CC$$], 5 + 
                   1.5 Sin[$CellContext`CC$$]}}], 
                
                Line[{{6 Cos[$CellContext`A$$], -5 + 
                   6 Sin[$CellContext`A$$]}, {
                  6 Cos[$CellContext`CC$$], -5 + 6 Sin[$CellContext`CC$$]}}]},
                4, {
                
                Line[{{-5 + 4 Cos[$CellContext`A$$], 5 + 
                   4 Sin[$CellContext`A$$]}, {-5 + 4 Cos[$CellContext`B$$], 5 + 
                   4 Sin[$CellContext`B$$]}, {-5 + 4 Cos[$CellContext`CC$$], 
                   5 + 4 Sin[$CellContext`CC$$]}, {-5 + 
                   4 Cos[$CellContext`A$$], 5 + 4 Sin[$CellContext`A$$]}}], 
                
                Line[{{5 + 1.5 Cos[$CellContext`A$$], 5 + 
                   1.5 Sin[$CellContext`A$$]}, {
                  5 + 1.5 Cos[$CellContext`B$$], 5 + 
                   1.5 Sin[$CellContext`B$$]}, {
                  5 + 1.5 Cos[$CellContext`CC$$], 5 + 
                   1.5 Sin[$CellContext`CC$$]}, {
                  5 + 1.5 Cos[$CellContext`A$$], 5 + 
                   1.5 Sin[$CellContext`A$$]}}], 
                
                Line[{{6 Cos[$CellContext`A$$], -5 + 
                   6 Sin[$CellContext`A$$]}, {
                  6 Cos[$CellContext`B$$], -5 + 6 Sin[$CellContext`B$$]}, {
                  6 Cos[$CellContext`CC$$], -5 + 6 Sin[$CellContext`CC$$]}, {
                  6 Cos[$CellContext`A$$], -5 + 6 Sin[$CellContext`A$$]}}]}, 
               5, {
                
                Line[{{-5 + 4 Cos[$CellContext`A$$], 5 + 
                   4 Sin[$CellContext`A$$]}, ({-5 + 4 Cos[$CellContext`B$$], 
                    5 + 4 Sin[$CellContext`B$$]} + {-5 + 
                    4 Cos[$CellContext`CC$$], 5 + 4 Sin[$CellContext`CC$$]})/
                  2.}], 
                
                Line[{{5 + 1.5 Cos[$CellContext`A$$], 5 + 
                   1.5 Sin[$CellContext`A$$]}, ({
                    5 + 1.5 Cos[$CellContext`B$$], 5 + 
                    1.5 Sin[$CellContext`B$$]} + {
                    5 + 1.5 Cos[$CellContext`CC$$], 5 + 
                    1.5 Sin[$CellContext`CC$$]})/2.}], 
                
                Line[{{6 Cos[$CellContext`A$$], -5 + 
                   6 Sin[$CellContext`A$$]}, ({
                    6 Cos[$CellContext`B$$], -5 + 6 Sin[$CellContext`B$$]} + {
                    6 Cos[$CellContext`CC$$], -5 + 6 Sin[$CellContext`CC$$]})/
                  2.}]}]}, ImageSize -> 300, PlotRange -> 10, Frame -> False],
             SpanFromLeft, SpanFromLeft, SpanFromLeft}, {
           "", "Mama", "Papa", "Baby"}, {"Area", 
            $CellContext`frm[$CellContext`mamaArea$$], 
            $CellContext`frm[$CellContext`papaArea$$], 
            $CellContext`frm[$CellContext`babyArea$$]}, {
            
            ReplaceAll[$CellContext`radio$$, {
             1 -> "AB", 2 -> "BC", 3 -> "CA", 4 -> "Perimeter", 5 -> 
              "Bisector", 6 -> "Altitude"}], 
            $CellContext`frm[$CellContext`mamaLinear$$], 
            $CellContext`frm[$CellContext`papaLinear$$], 
            $CellContext`frm[$CellContext`babyLinear$$]}, {
           "Ratio of \!\(\*FractionBox[\(Area\), SuperscriptBox[\((Linear \
Element)\), \(2\)]]\) is the same!!! ", 
            $CellContext`frm[$CellContext`mamaArea$$/$CellContext`mamaLinear$$\
^2], 
            $CellContext`frm[$CellContext`papaArea$$/$CellContext`papaLinear$$\
^2], 
            $CellContext`frm[$CellContext`babyArea$$/$CellContext`babyLinear$$\
^2]}}, Frame -> All, ItemSize -> {{Automatic, {6}}}, Background -> {{
             Lighter[Blue, 0.75]}, {{}, 
             Lighter[Yellow, 0.65], {}, 
             Lighter[Red, 0.5]}}], "Label"]), 
      "Specifications" :> {{{$CellContext`radio$$, 1, "Linear Element"}, {
         1 -> "AB", 2 -> "BC", 3 -> "CA", 4 -> "Perimeter", 5 -> 
          "A Bisector"}, ControlType -> RadioButtonBar}, Delimiter, 
        "None" -> {{$CellContext`A$$, 0.2, "Vertex A"}, 1.4707963267948965`, 
          0}, "None" -> {{$CellContext`B$$, 1.5707963267948966`, "Vertex B"}, 
          3.041592653589793, 1.5707963267948966`}, {{$CellContext`CC$$, 
          4.360336558432794, "Vertex C"}, Pi, 6.183185307179587}, 
        "None" -> {{$CellContext`mamaArea$$, 17.410732826967497`, ""}, 
          Blank[], 
          Blank[], ControlType -> None}, 
        "None" -> {{$CellContext`papaArea$$, 39.17414886067688, ""}, 
          Blank[], 
          Blank[], ControlType -> None}, 
        "None" -> {{$CellContext`babyArea$$, 2.448384303792305, ""}, 
          Blank[], 
          Blank[], ControlType -> None}, 
        "None" -> {{$CellContext`mamaLinear$$, 1.2659626133539164`, ""}, 
          Blank[], 
          Blank[], ControlType -> None}, 
        "None" -> {{$CellContext`papaLinear$$, 1.8989439200308746`, ""}, 
          Blank[], 
          Blank[], ControlType -> None}, 
        "None" -> {{$CellContext`babyLinear$$, 0.47473598000771866`, ""}, 
          Blank[], 
          Blank[], ControlType -> None}}, 
      "Options" :> {
       ControlPlacement -> Bottom, AutorunSequencing -> {1, 2, 3, 4}, 
        Alignment -> Center, 
        TrackedSymbols :> {$CellContext`radio$$, $CellContext`A$$, \
$CellContext`B$$, $CellContext`CC$$}}, 
      "DefaultOptions" :> {ControllerLinking -> True}],
     ImageSizeCache->{443., {277., 282.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>(({$CellContext`frm[
          Pattern[$CellContext`x, 
           Blank[]]] := 
        NumberForm[$CellContext`x, {4, 2}], $CellContext`area[
          Pattern[$CellContext`a, 
           Blank[Real]], 
          Pattern[$CellContext`b, 
           Blank[Real]], 
          Pattern[$CellContext`c, 
           Blank[Real]], 
          Optional[
           Pattern[$CellContext`scale, 
            Blank[Real]], 1.]] := 
        Module[{$CellContext`A, $CellContext`B, 
           C, $CellContext`AB, $CellContext`BC, $CellContext`CA, \
$CellContext`s}, $CellContext`A = $CellContext`scale {
              Cos[$CellContext`a], 
              Sin[$CellContext`a]}; $CellContext`B = $CellContext`scale {
              Cos[$CellContext`b], 
              Sin[$CellContext`b]}; C = $CellContext`scale {
              Cos[$CellContext`c], 
              Sin[$CellContext`c]}; $CellContext`AB = 
           Norm[$CellContext`B - $CellContext`A]; $CellContext`BC = 
           Norm[C - $CellContext`B]; $CellContext`CA = 
           Norm[C - $CellContext`A]; $CellContext`s = ($CellContext`AB + \
$CellContext`BC + $CellContext`CA)/2.; 
          Sqrt[(($CellContext`s ($CellContext`s - $CellContext`AB)) \
($CellContext`s - $CellContext`BC)) ($CellContext`s - $CellContext`CA)]]}; 
      Typeset`initDone$$ = True); ReleaseHold[
       HoldComplete[{$CellContext`area[
           Pattern[$CellContext`a, 
            Blank[Real]], 
           Pattern[$CellContext`b, 
            Blank[Real]], 
           Pattern[$CellContext`c, 
            Blank[Real]], 
           Optional[
            Pattern[$CellContext`scale, 
             Blank[Real]], 1.]] := 
         Module[{A, $CellContext`B, 
            C, $CellContext`AB, $CellContext`BC, $CellContext`CA, \
$CellContext`s}, A = $CellContext`scale {
               Cos[$CellContext`a], 
               Sin[$CellContext`a]}; $CellContext`B = $CellContext`scale {
               Cos[$CellContext`b], 
               Sin[$CellContext`b]}; C = $CellContext`scale {
               Cos[$CellContext`c], 
               Sin[$CellContext`c]}; $CellContext`AB = 
            Norm[$CellContext`B - A]; $CellContext`BC = 
            Norm[C - $CellContext`B]; $CellContext`CA = 
            Norm[C - 
              A]; $CellContext`s = ($CellContext`AB + $CellContext`BC + \
$CellContext`CA)/
             2.; ((($CellContext`s ($CellContext`s - $CellContext`AB)) \
($CellContext`s - $CellContext`BC)) ($CellContext`s - $CellContext`CA))^
            Rational[1, 2]]}]]),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellID->17372954],

Cell[TextData[{
 "Geometric objects that have the same shape and same size are called ",
 StyleBox["congruent",
  FontSlant->"Italic"],
 ". When they have the same shape but different sizes they are called ",
 StyleBox["similar",
  FontSlant->"Italic"],
 ". Here are three similar triangles called Mama Triangle, Papa Triangle, and \
Baby Triangle. You can change the position of their vertices with the \
sliders. Since their angles all change by the same amount they remain \
similar.\n\nBut notice that even though they are different sizes, the ratio \
of their areas to the square of ANY linear element is the same for all three \
triangles (watch the pink line in the table). A teenage Albert Einstein made \
use of this quality in his proof of the Pythagorean theorem."
}], "ManipulateCaption"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`pts$$ = {{-0.614, -0.714}, {-0.758, 
    0.17999999999999994`}, {0.32000000000000006`, -0.16000000000000003`}}, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`pts$$], {{-0.8503076553344728, -1 + 
         2 (Rational[1, 2] + 
           Rational[-1, 4] 3^Rational[1, 2])}, {-0.8503076553344728, 
        0.5157177484499664}, {
        0.6496923446655272, -0.35030765533447283`}}}, {-1, -1}, {1, 1}}}, 
    Typeset`size$$ = {400., {198., 202.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`pts$14163$$ = {0, 0}}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`pts$$ = {{-0.8503076553344728, -1 + 
           2 (Rational[1, 2] + 
             Rational[-1, 4] 3^Rational[1, 2])}, {-0.8503076553344728, 
          0.5157177484499664}, {0.6496923446655272, -0.35030765533447283`}}}, 
      "ControllerVariables" :> {
        Hold[$CellContext`pts$$, $CellContext`pts$14163$$, {0, 0}]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> (
       If[Length[$CellContext`pts$$] < 1, $CellContext`pts$$ = {{0, 0}}]; 
       Graphics[{Gray, 
          Map[Arrow, 
           Partition[
            Join[$CellContext`pts$$, {
              First[$CellContext`pts$$]}], 2, 1]], Black, 
          $CellContext`markangles[$CellContext`pts$$, -1], Red, 
          Map[Point, $CellContext`pts$$]}, ImageSize -> {400, 400}, PlotLabel -> 
         Grid[
           $CellContext`preplotlab[$CellContext`pts$$, {"A", "B", "C"}]], 
         PlotRangePadding -> 0.2]), 
      "Specifications" :> {{{$CellContext`pts$$, {{-0.8503076553344728, -1 + 
            2 (Rational[1, 2] + 
              Rational[-1, 4] 3^Rational[1, 2])}, {-0.8503076553344728, 
           0.5157177484499664}, {
           0.6496923446655272, -0.35030765533447283`}}}, {-1, -1}, {1, 1}, 
         ControlType -> Locator, LocatorAutoCreate -> False, Appearance -> 
         Graphics[{
            Opacity[0], 
            Disk[{0, 0}, 1]}, ImageSize -> 60]}}, "Options" :> {}, 
      "DefaultOptions" :> {ControllerLinking -> True}],
     ImageSizeCache->{446., {225., 230.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>(({$CellContext`markangles[
          Pattern[$CellContext`pts, 
           Blank[]], 
          Pattern[$CellContext`start, 
           Blank[]]] := MapIndexed[{
           Circle[
            Part[#, 1], 1/4, 
            Part[#, 2]], 
           Text[
            Style[
             Row[{
               Round[Dot[
                  Part[#, 2], {-1, 1}]/Degree], "\[Degree]"}], Background -> 
             White], Part[#, 1] + (1/8) ({
               Cos[#], 
               Sin[#]}& )[
               Mean[
                Part[#, 2]]]], 
           Text[
            Style[
             $CellContext`pointname[Part[#2, 1] + $CellContext`start], Bold, 
             Background -> White], Part[#, 1] + (1/8) ({
               Cos[#], 
               Sin[#]}& )[Pi + Mean[
                 Part[#, 2]]]]}& , 
          Map[{
            Part[#, 2], 
            $CellContext`angle[#]}& , 
           Partition[
            Join[{
              Last[$CellContext`pts]}, $CellContext`pts, {
              First[$CellContext`pts]}], 3, 1]]], $CellContext`pointname[
          Pattern[$CellContext`p, 
           Blank[]]] := StringJoin[
          Part[
           CharacterRange["A", "Z"], 1 + 
           IntegerDigits[$CellContext`p, 26]]], $CellContext`angle[{
           Pattern[$CellContext`a, 
            Blank[]], 
           Pattern[$CellContext`b, 
            Blank[]], 
           Pattern[$CellContext`c, 
            Blank[]]}] := (If[Part[#, 1] < Part[#, 2], #, {
           Part[#, 1], 2 Pi + Part[#, 2]}]& )[
          Arg[
           Dot[
            
            N[{$CellContext`a - $CellContext`b, $CellContext`c - \
$CellContext`b}], {1, I}]]], $CellContext`preplotlab[
          Pattern[$CellContext`pts, 
           Blank[]], 
          Pattern[$CellContext`labs, 
           Blank[]]] := With[{$CellContext`as = Map[Dot[
               $CellContext`angle[#], {-1, 1}]/Degree& , 
             Partition[
              Join[{
                Last[$CellContext`pts]}, $CellContext`pts, {
                First[$CellContext`pts]}], 3, 1]]}, 
          Append[
           Transpose[{
             Map[StringJoin["\[Angle]", 
               StringJoin[#], " ="]& , 
              Partition[
               Join[{
                 Last[$CellContext`labs]}, $CellContext`labs, {
                 First[$CellContext`labs]}], 3, 1]], 
             Map[Row[{#, "\[Degree]"}]& , $CellContext`as]}], {"  total  =", 
            Row[{
              Total[$CellContext`as], "\[Degree]"}]}]]}; 
      Typeset`initDone$$ = True); ReleaseHold[
       HoldComplete[{$CellContext`pointname[
           Pattern[$CellContext`p, 
            Blank[]]] := StringJoin[
           Part[
            CharacterRange["A", "Z"], 1 + 
            IntegerDigits[$CellContext`p, 26]]], $CellContext`angle[{
            Pattern[$CellContext`a, 
             Blank[]], 
            Pattern[$CellContext`b, 
             Blank[]], 
            Pattern[$CellContext`c, 
             Blank[]]}] := (If[Part[#, 1] < Part[#, 2], #, {
            Part[#, 1], 2 Pi + Part[#, 2]}]& )[
           Arg[
            Dot[
             
             N[{$CellContext`a - $CellContext`b, $CellContext`c - \
$CellContext`b}], {1, I}]]], $CellContext`markangles[
           Pattern[$CellContext`pts, 
            Blank[]], 
           Pattern[$CellContext`start, 
            Blank[]]] := MapIndexed[{
            Circle[
             Part[#, 1], 1/4, 
             Part[#, 2]], 
            Text[
             Style[
              Row[{
                Round[Dot[
                   Part[#, 2], {-1, 1}]/Degree], "\[Degree]"}], Background -> 
              White], Part[#, 1] + (1/8) ({
                Cos[#], 
                Sin[#]}& )[
                Mean[
                 Part[#, 2]]]], 
            Text[
             Style[
              $CellContext`pointname[Part[#2, 1] + $CellContext`start], Bold, 
              Background -> White], Part[#, 1] + (1/8) ({
                Cos[#], 
                Sin[#]}& )[Pi + Mean[
                  Part[#, 2]]]]}& , 
           Map[{
             Part[#, 2], 
             $CellContext`angle[#]}& , 
            Partition[
             Join[{
               Last[$CellContext`pts]}, $CellContext`pts, {
               First[$CellContext`pts]}], 3, 1]]], $CellContext`preplotlab[
           Pattern[$CellContext`pts, 
            Blank[]], 
           Pattern[$CellContext`labs, 
            Blank[]]] := With[{$CellContext`as = Map[Dot[
                $CellContext`angle[#], {-1, 1}]/Degree& , 
              Partition[
               Join[{
                 Last[$CellContext`pts]}, $CellContext`pts, {
                 First[$CellContext`pts]}], 3, 1]]}, 
           Append[
            Transpose[{
              Map[StringJoin["\[Angle]", 
                StringJoin[#], " ="]& , 
               Partition[
                Join[{
                  Last[$CellContext`labs]}, $CellContext`labs, {
                  First[$CellContext`labs]}], 3, 1]], 
              Map[Row[{#, "\[Degree]"}]& , $CellContext`as]}], {
            "  total  =", 
             Row[{
               Total[$CellContext`as], "\[Degree]"}]}]]}]]),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellID->269087347],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`rad$$ = False, $CellContext`\[Theta]$$ = 
    180, Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`\[Theta]$$], 120, "angle type"}, {
      45 -> "acute", 90 -> "right", 120 -> "obtuse", 180 -> "straight", 230 -> 
       "reflex", 360 -> "full"}}, {{
       Hold[$CellContext`\[Theta]$$], 120, "choose an angle"}, 0, 360, 1}, {{
       Hold[$CellContext`rad$$], False, "show radians"}, {True, False}}}, 
    Typeset`size$$ = {400., {209., 213.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`\[Theta]$108535$$ = 0, $CellContext`rad$108536$$ = 
    False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`rad$$ = False, $CellContext`\[Theta]$$ = 
        120}, "ControllerVariables" :> {
        Hold[$CellContext`\[Theta]$$, $CellContext`\[Theta]$108535$$, 0], 
        Hold[$CellContext`rad$$, $CellContext`rad$108536$$, False]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Graphics[{
         Thickness[0.01], 
         RGBColor[0, 0.4, 0.78], 
         Line[5 {{1, 0}, {0, 0}, {
             Cos[$CellContext`\[Theta]$$ Degree], 
             Sin[$CellContext`\[Theta]$$ Degree]}}], 
         Thickness[0.005], 
         Circle[{0, 0}, 1, {0, $CellContext`\[Theta]$$ Degree}], 
         Text[
          Style[
           StringJoin[
            If[$CellContext`rad$$, 
             ToString[
              
              NumberForm[$CellContext`\[Theta]$$ (Pi/180.), {3, 2}, 
               NumberPadding -> {"", "0"}]], 
             ToString[$CellContext`\[Theta]$$]], 
            If[$CellContext`rad$$, " radians", "\[Degree]"]], "Section"], 2 {
            Cos[$CellContext`\[Theta]$$ (Degree/2)], 
            Sin[$CellContext`\[Theta]$$ (Degree/2)]}]}, PlotRange -> 
        5 {{-1, 1}, {-1, 1}}, PlotLabel -> Style[
          StringJoin[
           
           Which[$CellContext`\[Theta]$$ < 90, 
            "acute", $CellContext`\[Theta]$$ == 90, "right", 
            180 > $CellContext`\[Theta]$$ > 90, 
            "obtuse", $CellContext`\[Theta]$$ == 180, "straight", 
            180 < $CellContext`\[Theta]$$ < 360, 
            "reflex", $CellContext`\[Theta]$$ == 360, "full", True, ""], 
           " angle"], "Label", 18], ImageSize -> 400], 
      "Specifications" :> {{{$CellContext`\[Theta]$$, 120, "angle type"}, {
         45 -> "acute", 90 -> "right", 120 -> "obtuse", 180 -> "straight", 
          230 -> "reflex", 360 -> "full"}, ControlType -> 
         Setter}, {{$CellContext`\[Theta]$$, 120, "choose an angle"}, 0, 360, 
         1}, {{$CellContext`rad$$, False, "show radians"}, {True, False}}}, 
      "Options" :> {AutorunSequencing -> {{1, 10}}}, 
      "DefaultOptions" :> {ControllerLinking -> True}],
     ImageSizeCache->{446., {273., 278.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellID->354054674]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1272, 903},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
ShowSelection->True,
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (May 21, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "S0.4.1"->{
  Cell[251665, 4596, 134, 2, 29, "Text",
   CellTags->{"S0.4.1", "1.5"}]},
 "1.5"->{
  Cell[251665, 4596, 134, 2, 29, "Text",
   CellTags->{"S0.4.1", "1.5"}]},
 "Plot"->{
  Cell[252705, 4628, 821, 21, 47, "Text",
   CellTags->"Plot"],
  Cell[253529, 4651, 463, 14, 44, "Input",
   CellTags->"Plot"],
  Cell[253995, 4667, 317, 10, 29, "Text",
   CellTags->"Plot"],
  Cell[254315, 4679, 528, 15, 33, "Input",
   CellTags->"Plot"],
  Cell[254880, 4699, 214, 6, 71, "Section",
   CellTags->"Plot"],
  Cell[255097, 4707, 663, 17, 49, "Text",
   CellTags->"Plot"],
  Cell[255763, 4726, 262, 9, 51, "MathCaption",
   CellTags->"Plot"],
  Cell[256028, 4737, 469, 15, 54, "Input",
   CellTags->"Plot"],
  Cell[256500, 4754, 383, 8, 29, "Text",
   CellTags->"Plot"],
  Cell[256886, 4764, 377, 8, 43, "MathCaption",
   CellTags->"Plot"],
  Cell[257266, 4774, 873, 29, 54, "Input",
   CellTags->"Plot"],
  Cell[259690, 4855, 234, 6, 71, "Section",
   CellTags->"Plot"],
  Cell[259927, 4863, 503, 11, 47, "Text",
   CellTags->"Plot"],
  Cell[260433, 4876, 270, 6, 43, "MathCaption",
   CellTags->"Plot"],
  Cell[260947, 4894, 434, 14, 43, "Input",
   CellTags->"Plot"],
  Cell[261418, 4913, 195, 6, 71, "Section",
   CellTags->"Plot"],
  Cell[261616, 4921, 469, 10, 47, "Text",
   CellTags->"Plot"],
  Cell[262088, 4933, 336, 10, 43, "MathCaption",
   CellTags->"Plot"],
  Cell[262427, 4945, 264, 8, 31, "Input",
   CellTags->"Plot"],
  Cell[262694, 4955, 381, 11, 43, "MathCaption",
   CellTags->"Plot"],
  Cell[263078, 4968, 817, 21, 92, "Input",
   CellTags->"Plot"],
  Cell[264891, 5022, 133, 5, 71, "Section",
   CellTags->"Plot"],
  Cell[265027, 5029, 466, 13, 29, "Text",
   CellTags->"Plot"],
  Cell[265496, 5044, 357, 11, 31, "Input",
   CellTags->"Plot"],
  Cell[265856, 5057, 213, 5, 43, "MathCaption",
   CellTags->"Plot"],
  Cell[268051, 5122, 444, 10, 43, "MathCaption",
   CellTags->"Plot"],
  Cell[268498, 5134, 539, 17, 31, "Input",
   CellTags->"Plot"],
  Cell[270011, 5185, 124, 2, 71, "Section",
   CellTags->"Plot"],
  Cell[270138, 5189, 736, 21, 47, "Text",
   CellTags->"Plot"],
  Cell[270877, 5212, 69, 2, 31, "Input",
   CellTags->"Plot"],
  Cell[270949, 5216, 499, 14, 31, "Input",
   CellTags->"Plot"]},
 "NIntegrate"->{
  Cell[516740, 10059, 641, 20, 33, "Input",
   CellTags->"NIntegrate"],
  Cell[517384, 10081, 218, 5, 29, "Text",
   CellTags->"NIntegrate"],
  Cell[517605, 10088, 1040, 28, 55, "Input",
   CellTags->"NIntegrate"],
  Cell[518648, 10118, 156, 4, 29, "Text",
   CellTags->"NIntegrate"],
  Cell[518807, 10124, 1089, 29, 55, "Input",
   CellTags->"NIntegrate"],
  Cell[520015, 10158, 1089, 29, 55, "Input",
   CellTags->"NIntegrate"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"S0.4.1", 565923, 11308},
 {"1.5", 566008, 11311},
 {"Plot", 566094, 11314},
 {"NIntegrate", 568158, 11377}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 183, 3, 83, "Title"],
Cell[776, 28, 216, 3, 23, "Author"],
Cell[995, 33, 249, 6, 39, "Affiliation"],
Cell[CellGroupData[{
Cell[1269, 43, 147, 2, 71, "Section"],
Cell[1419, 47, 1912, 30, 209, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3368, 82, 143, 2, 71, "Section"],
Cell[3514, 86, 448, 11, 36, "Subsection"],
Cell[3965, 99, 354, 9, 28, "Subsection"],
Cell[4322, 110, 375, 9, 28, "Subsection"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4734, 124, 257, 7, 71, "Section"],
Cell[CellGroupData[{
Cell[5016, 135, 196, 3, 36, "Subsection"],
Cell[5215, 140, 211342, 3466, 456, "Graphics"]
}, Open  ]],
Cell[CellGroupData[{
Cell[216594, 3611, 222, 3, 36, "Subsection"],
Cell[216819, 3616, 207, 2, 28, "Subsubsection"],
Cell[217029, 3620, 245, 4, 22, "Subsubsection"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[217323, 3630, 312, 7, 71, "Section"],
Cell[217638, 3639, 128, 2, 36, "Subsection"],
Cell[CellGroupData[{
Cell[217791, 3645, 275, 3, 28, "Subsection"],
Cell[218069, 3650, 320, 7, 47, "Text"],
Cell[218392, 3659, 636, 14, 31, "Input"],
Cell[219031, 3675, 276, 6, 29, "Text"],
Cell[219310, 3683, 861, 19, 31, "Input"],
Cell[220174, 3704, 114, 3, 29, "Text"],
Cell[220291, 3709, 418, 8, 31, "Input"],
Cell[220712, 3719, 488, 12, 65, "Text"],
Cell[221203, 3733, 269, 6, 31, "Input"],
Cell[221475, 3741, 529, 9, 65, "Text"],
Cell[222007, 3752, 486, 14, 52, "Input"],
Cell[222496, 3768, 82, 1, 29, "Text"],
Cell[222581, 3771, 367, 8, 31, "Input"],
Cell[222951, 3781, 73, 1, 29, "Text"],
Cell[223027, 3784, 577, 20, 35, "Input"],
Cell[223607, 3806, 118, 3, 29, "Text"],
Cell[223728, 3811, 432, 13, 31, "Input"],
Cell[224163, 3826, 687, 21, 31, "Input"],
Cell[224853, 3849, 289, 9, 31, "Input"],
Cell[225145, 3860, 79, 1, 29, "Text"],
Cell[225227, 3863, 1345, 32, 112, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[226621, 3901, 149, 2, 71, "Section"],
Cell[CellGroupData[{
Cell[226795, 3907, 299, 4, 36, "Subsection"],
Cell[227097, 3913, 299, 5, 28, "Subsubsection"],
Cell[CellGroupData[{
Cell[227421, 3922, 256, 3, 22, "Subsubsection"],
Cell[227680, 3927, 69, 1, 31, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[227798, 3934, 311, 5, 36, "Subsection"],
Cell[228112, 3941, 372, 5, 28, "Subsubsection"],
Cell[CellGroupData[{
Cell[228509, 3950, 401, 6, 22, "Subsubsection"],
Cell[228913, 3958, 68, 1, 31, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[229030, 3965, 336, 4, 36, "Subsection"],
Cell[229369, 3971, 3218, 68, 132, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[232636, 4045, 240, 6, 71, "Section"],
Cell[232879, 4053, 1518, 31, 119, "Text"],
Cell[234400, 4086, 187, 4, 45, "Input"],
Cell[234590, 4092, 190, 4, 45, "Input"],
Cell[234783, 4098, 92, 1, 29, "Text"],
Cell[234878, 4101, 172, 4, 31, "Input"],
Cell[235053, 4107, 171, 4, 31, "Input"],
Cell[235227, 4113, 90, 1, 29, "Text"],
Cell[235320, 4116, 342, 9, 31, "Input"],
Cell[235665, 4127, 124, 2, 31, "Input"],
Cell[235792, 4131, 127, 2, 31, "Input"],
Cell[235922, 4135, 370, 6, 47, "Text"],
Cell[236295, 4143, 239, 5, 31, "Input"],
Cell[236537, 4150, 281, 7, 29, "Text"],
Cell[236821, 4159, 258, 5, 29, "Text"],
Cell[237082, 4166, 547, 14, 31, "Input"],
Cell[237632, 4182, 133, 1, 29, "Text"],
Cell[237768, 4185, 127, 2, 31, "Input"],
Cell[237898, 4189, 127, 2, 31, "Input"],
Cell[238028, 4193, 157, 3, 29, "Text"],
Cell[238188, 4198, 260, 7, 31, "Input"],
Cell[238451, 4207, 122, 2, 29, "Text"],
Cell[238576, 4211, 248, 5, 29, "Text"],
Cell[238827, 4218, 386, 12, 52, "Input"],
Cell[239216, 4232, 284, 5, 29, "Text"],
Cell[239503, 4239, 560, 15, 52, "Input"],
Cell[240066, 4256, 98, 1, 29, "Text"],
Cell[240167, 4259, 466, 10, 47, "Text"],
Cell[240636, 4271, 269, 8, 31, "Input"],
Cell[240908, 4281, 250, 8, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[241195, 4294, 271, 7, 71, "Section"],
Cell[CellGroupData[{
Cell[241491, 4305, 141, 2, 36, "Subsection"],
Cell[241635, 4309, 337, 7, 29, "Text"],
Cell[241975, 4318, 765, 23, 33, "Input"],
Cell[242743, 4343, 265, 5, 29, "Text"],
Cell[243011, 4350, 285, 8, 31, "Input"],
Cell[243299, 4360, 363, 7, 29, "Text"],
Cell[243665, 4369, 266, 7, 31, "Input"],
Cell[243934, 4378, 159, 3, 29, "Text"],
Cell[244096, 4383, 1285, 36, 92, "Input"],
Cell[245384, 4421, 357, 6, 29, "Text"],
Cell[245744, 4429, 1888, 47, 72, "Input"],
Cell[247635, 4478, 713, 13, 47, "Text"],
Cell[248351, 4493, 875, 22, 72, "Input"],
Cell[249229, 4517, 96, 1, 29, "Text"],
Cell[249328, 4520, 669, 20, 52, "Input"],
Cell[250000, 4542, 511, 10, 47, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[250560, 4558, 179, 2, 71, "Section"],
Cell[250742, 4562, 210, 6, 31, "Input"],
Cell[250955, 4570, 153, 3, 29, "Text"],
Cell[251111, 4575, 551, 19, 31, "Input"],
Cell[251665, 4596, 134, 2, 29, "Text",
 CellTags->{"S0.4.1", "1.5"}],
Cell[251802, 4600, 828, 23, 31, "Input",
 CellID->596132949],
Cell[252633, 4625, 69, 1, 31, "Input"],
Cell[252705, 4628, 821, 21, 47, "Text",
 CellTags->"Plot"],
Cell[253529, 4651, 463, 14, 44, "Input",
 CellTags->"Plot"],
Cell[253995, 4667, 317, 10, 29, "Text",
 CellTags->"Plot"],
Cell[254315, 4679, 528, 15, 33, "Input",
 CellTags->"Plot"]
}, Open  ]],
Cell[CellGroupData[{
Cell[254880, 4699, 214, 6, 71, "Section",
 CellTags->"Plot"],
Cell[255097, 4707, 663, 17, 49, "Text",
 CellTags->"Plot"],
Cell[255763, 4726, 262, 9, 51, "MathCaption",
 CellTags->"Plot"],
Cell[256028, 4737, 469, 15, 54, "Input",
 CellTags->"Plot"],
Cell[256500, 4754, 383, 8, 29, "Text",
 CellTags->"Plot"],
Cell[256886, 4764, 377, 8, 43, "MathCaption",
 CellTags->"Plot"],
Cell[257266, 4774, 873, 29, 54, "Input",
 CellTags->"Plot"],
Cell[258142, 4805, 172, 2, 43, "MathCaption"],
Cell[258317, 4809, 555, 17, 48, "Input"],
Cell[258875, 4828, 778, 22, 48, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[259690, 4855, 234, 6, 71, "Section",
 CellTags->"Plot"],
Cell[259927, 4863, 503, 11, 47, "Text",
 CellTags->"Plot"],
Cell[260433, 4876, 270, 6, 43, "MathCaption",
 CellTags->"Plot"],
Cell[260706, 4884, 238, 8, 43, "Input"],
Cell[260947, 4894, 434, 14, 43, "Input",
 CellTags->"Plot"]
}, Open  ]],
Cell[CellGroupData[{
Cell[261418, 4913, 195, 6, 71, "Section",
 CellTags->"Plot"],
Cell[261616, 4921, 469, 10, 47, "Text",
 CellTags->"Plot"],
Cell[262088, 4933, 336, 10, 43, "MathCaption",
 CellTags->"Plot"],
Cell[262427, 4945, 264, 8, 31, "Input",
 CellTags->"Plot"],
Cell[262694, 4955, 381, 11, 43, "MathCaption",
 CellTags->"Plot"],
Cell[263078, 4968, 817, 21, 92, "Input",
 CellTags->"Plot"],
Cell[263898, 4991, 160, 2, 43, "MathCaption"],
Cell[264061, 4995, 729, 19, 52, "Input"],
Cell[264793, 5016, 61, 1, 23, "Spacer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[264891, 5022, 133, 5, 71, "Section",
 CellTags->"Plot"],
Cell[265027, 5029, 466, 13, 29, "Text",
 CellTags->"Plot"],
Cell[265496, 5044, 357, 11, 31, "Input",
 CellTags->"Plot"],
Cell[265856, 5057, 213, 5, 43, "MathCaption",
 CellTags->"Plot"],
Cell[266072, 5064, 1976, 56, 92, "Input"],
Cell[268051, 5122, 444, 10, 43, "MathCaption",
 CellTags->"Plot"],
Cell[268498, 5134, 539, 17, 31, "Input",
 CellTags->"Plot"],
Cell[269040, 5153, 159, 2, 43, "MathCaption"],
Cell[269202, 5157, 772, 23, 44, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[270011, 5185, 124, 2, 71, "Section",
 CellTags->"Plot"],
Cell[270138, 5189, 736, 21, 47, "Text",
 CellTags->"Plot"],
Cell[270877, 5212, 69, 2, 31, "Input",
 CellTags->"Plot"],
Cell[270949, 5216, 499, 14, 31, "Input",
 CellTags->"Plot"],
Cell[271451, 5232, 912, 26, 31, "Input"],
Cell[272366, 5260, 243, 5, 29, "Text"],
Cell[272612, 5267, 471, 13, 31, "Input"],
Cell[273086, 5282, 1343, 38, 52, "Input",
 CellID->704187145],
Cell[274432, 5322, 1875, 44, 52, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[276344, 5371, 213, 4, 71, "Section"],
Cell[276560, 5377, 106, 1, 29, "Text"],
Cell[276669, 5380, 26744, 446, 78, "Input"],
Cell[303416, 5828, 92, 1, 31, InheritFromParent],
Cell[303511, 5831, 520, 13, 31, "Input"],
Cell[304034, 5846, 366, 9, 33, "Input"],
Cell[304403, 5857, 192, 4, 31, "Input"],
Cell[304598, 5863, 271, 6, 33, "Input"],
Cell[304872, 5871, 334, 9, 31, "Input"],
Cell[305209, 5882, 860, 24, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[306106, 5911, 296, 4, 71, "Section"],
Cell[CellGroupData[{
Cell[306427, 5919, 269, 3, 36, "Subsection"],
Cell[306699, 5924, 483, 13, 31, "Input"],
Cell[307185, 5939, 101, 1, 29, "Text"],
Cell[307289, 5942, 602, 17, 31, "Input"],
Cell[307894, 5961, 95, 1, 29, "Text"],
Cell[307992, 5964, 246, 8, 31, "Input"],
Cell[308241, 5974, 517, 15, 31, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[308807, 5995, 131, 1, 71, "Section"],
Cell[CellGroupData[{
Cell[308963, 6000, 114, 1, 28, "Subsubsection"],
Cell[309080, 6003, 3112, 86, 92, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[312229, 6094, 129, 1, 28, "Subsubsection"],
Cell[312361, 6097, 1110, 27, 31, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[313520, 6130, 383, 5, 71, "Section"],
Cell[313906, 6137, 552, 12, 47, "Text"],
Cell[314461, 6151, 828, 21, 52, "Input"],
Cell[315292, 6174, 821, 19, 31, "Input"],
Cell[316116, 6195, 964, 27, 52, "Input"],
Cell[317083, 6224, 1694, 42, 112, "Input"],
Cell[318780, 6268, 1744, 44, 52, "Input",
 CellID->547439507],
Cell[320527, 6314, 173268, 3067, 1854, "Input",
 CellID->81406683]
}, Open  ]],
Cell[CellGroupData[{
Cell[493832, 9386, 225, 3, 71, "Section"],
Cell[494060, 9391, 508, 10, 47, "Text"],
Cell[494571, 9403, 1716, 46, 72, "Input"],
Cell[496290, 9451, 126, 1, 29, "Text"],
Cell[496419, 9454, 1299, 35, 52, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[497755, 9494, 162, 2, 71, "Section"],
Cell[CellGroupData[{
Cell[497942, 9500, 95, 1, 36, "Subsection"],
Cell[498040, 9503, 429, 7, 29, "Text"],
Cell[498472, 9512, 563, 15, 31, "Input"],
Cell[499038, 9529, 140, 1, 29, "Text"],
Cell[499181, 9532, 130, 2, 31, "Input"],
Cell[499314, 9536, 108, 1, 29, "Text"],
Cell[499425, 9539, 169, 4, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[499631, 9548, 136, 2, 36, "Subsection"],
Cell[499770, 9552, 449, 7, 29, "Text"],
Cell[500222, 9561, 171, 4, 29, "Text"],
Cell[CellGroupData[{
Cell[500418, 9569, 111, 1, 28, "Subsubsection"],
Cell[500532, 9572, 125, 2, 31, "Input"],
Cell[500660, 9576, 258, 5, 29, "Text"],
Cell[500921, 9583, 134, 2, 31, "Input"],
Cell[501058, 9587, 182, 4, 29, "Text"],
Cell[501243, 9593, 143, 3, 31, "Input"],
Cell[501389, 9598, 165, 3, 31, "Input"],
Cell[501557, 9603, 133, 1, 29, "Text"],
Cell[501693, 9606, 315, 8, 31, "Input"],
Cell[502011, 9616, 228, 5, 29, "Text"],
Cell[502242, 9623, 452, 12, 31, "Input"],
Cell[502697, 9637, 404, 11, 31, "Input"],
Cell[503104, 9650, 153, 3, 29, "Text"],
Cell[503260, 9655, 361, 9, 31, "Input"],
Cell[503624, 9666, 270, 7, 31, "Input"],
Cell[503897, 9675, 227, 5, 29, "Text"],
Cell[504127, 9682, 274, 6, 29, "Text"],
Cell[504404, 9690, 131, 2, 31, "Input"],
Cell[504538, 9694, 609, 19, 31, "Input"],
Cell[505150, 9715, 229, 5, 29, "Text"],
Cell[505382, 9722, 609, 19, 31, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[506052, 9748, 255, 3, 71, "Section"],
Cell[CellGroupData[{
Cell[506332, 9755, 805, 13, 36, "Subsection"],
Cell[507140, 9770, 114, 2, 31, "Input"],
Cell[507257, 9774, 94, 1, 29, "Text"],
Cell[507354, 9777, 1809, 52, 74, "Input"],
Cell[509166, 9831, 493, 15, 31, "Input"],
Cell[509662, 9848, 140, 1, 29, "Text"],
Cell[509805, 9851, 819, 20, 31, "Input"],
Cell[510627, 9873, 97, 1, 29, "Text"],
Cell[510727, 9876, 417, 12, 31, "Input"],
Cell[511147, 9890, 135, 1, 29, "Text"],
Cell[511285, 9893, 881, 27, 31, "Input"],
Cell[512169, 9922, 121, 1, 29, "Text"],
Cell[512293, 9925, 667, 20, 31, "Input"],
Cell[512963, 9947, 110, 1, 29, "Text"],
Cell[513076, 9950, 638, 18, 31, "Input"],
Cell[513717, 9970, 339, 9, 29, "Text"],
Cell[514059, 9981, 131, 2, 31, "Input"],
Cell[514193, 9985, 942, 27, 31, "Input"],
Cell[515138, 10014, 571, 11, 65, "Text"],
Cell[515712, 10027, 103, 2, 31, "Input"],
Cell[515818, 10031, 384, 9, 31, "Input"],
Cell[516205, 10042, 344, 9, 31, "Input"],
Cell[516552, 10053, 185, 4, 47, "Text"],
Cell[516740, 10059, 641, 20, 33, "Input",
 CellTags->"NIntegrate"],
Cell[517384, 10081, 218, 5, 29, "Text",
 CellTags->"NIntegrate"],
Cell[517605, 10088, 1040, 28, 55, "Input",
 CellTags->"NIntegrate"],
Cell[518648, 10118, 156, 4, 29, "Text",
 CellTags->"NIntegrate"],
Cell[518807, 10124, 1089, 29, 55, "Input",
 CellTags->"NIntegrate"],
Cell[519899, 10155, 113, 1, 29, "Text"],
Cell[520015, 10158, 1089, 29, 55, "Input",
 CellTags->"NIntegrate"],
Cell[521107, 10189, 219, 4, 29, "Text"],
Cell[521329, 10195, 700, 20, 52, "Input"],
Cell[522032, 10217, 127, 1, 29, "Text"],
Cell[522162, 10220, 1602, 46, 92, "Input"],
Cell[523767, 10268, 81, 1, 29, "Text",
 CellID->735994752],
Cell[523851, 10271, 1153, 37, 52, "Input",
 CellID->37843928],
Cell[525007, 10310, 453, 15, 31, "Input",
 CellID->67367124],
Cell[525463, 10327, 107, 3, 29, "Text",
 CellID->205567056],
Cell[525573, 10332, 911, 27, 31, "Input",
 CellID->262267683],
Cell[526487, 10361, 183, 6, 29, "Text",
 CellID->238179222],
Cell[526673, 10369, 2450, 75, 92, "Input",
 CellID->446643489],
Cell[529126, 10446, 350, 13, 29, "Text",
 CellID->291328065],
Cell[529479, 10461, 519, 16, 31, "Input",
 CellID->218644546],
Cell[530001, 10479, 488, 16, 31, "Input",
 CellID->157417187]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[530538, 10501, 164, 2, 71, "Section"],
Cell[530705, 10505, 4262, 109, 152, "Input",
 CellID->4681751]
}, Open  ]],
Cell[CellGroupData[{
Cell[535004, 10619, 306, 4, 71, "Section"],
Cell[535313, 10625, 17655, 372, 576, "Output",
 CellID->17372954],
Cell[552971, 10999, 800, 14, 87, "ManipulateCaption"],
Cell[553774, 11015, 8136, 201, 472, "Output",
 CellID->269087347],
Cell[561913, 11218, 3612, 73, 568, "Output",
 CellID->354054674]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
